<?php
/**
 * Plugin Name: DiagnoSEO
 * Plugin URI: https://diagnoseo.com/wordpress-seo-plugin/
 * Description: Powerful SEO plugin for WordPress. The most lightweight and complete SEO solution on the market! It includes best-in-class content analyzer and keyword placement checkpoints.
 * Version: 1.2.31
 * Author: DiagnoSEO
 * Author URI: https://diagnoseo.com/
 * License: GPL
 * License URI: https://www.gnu.org/licenses/gpl-3.0.html
 *
 * @package DiagnoSEO
 */

if ( ! defined( 'ABSPATH' ) ) {
	die;
}

/**
 * Loads the text domain
 */
function diagnoseo_load_textdomain() {
	load_plugin_textdomain( 'diagnoseo', false, basename( dirname( __FILE__ ) ) . 'languages' );
}
add_action( 'init', 'diagnoseo_load_textdomain' );

define( 'DIAGNOSEO_PLUGIN_PATH', plugin_dir_path( __FILE__ ) );
define( 'DIAGNOSEO_PLUGIN_URL', plugin_dir_url( __FILE__ ) );
define( 'DIAGNOSEO_INCLUDES_PATH', DIAGNOSEO_PLUGIN_PATH . 'includes/' );
define( 'DIAGNOSEO_CUSTOMIZE_PATH', DIAGNOSEO_INCLUDES_PATH . 'customize/' );
define( 'DIAGNOSEO_BLOCKS_PATH', DIAGNOSEO_INCLUDES_PATH . 'blocks/' );

// Hack for the notice in widgets page.
remove_filter( 'admin_head', 'wp_check_widget_editor_deps' );

/**
 * Detects type of admin page
 */
function diagnoseo_screen() {
	$screen = get_current_screen();

	$diagnoseo_pages = array(
		'diagnoseo_page_diagnoseo-settings-meta',
		'diagnoseo_page_diagnoseo-settings-schema',
		'diagnoseo_page_diagnoseo-settings-social',
	);

	if ( in_array( $screen->id, $diagnoseo_pages, true ) ) {
		add_action( 'admin_enqueue_scripts', 'diagnoseo_add_admin_style' );
		add_action( 'admin_enqueue_scripts', 'diagnoseo_add_admin_scripts', 10, 1 );
	}

	if ( $screen->is_block_editor ) {
		add_action( 'admin_enqueue_scripts', 'diagnoseo_add_editor_style' );
	}
}
add_action( 'current_screen', 'diagnoseo_screen' );

/**
 * Initiates the plugin
 */
function diagnoseo_init() {
	require_once DIAGNOSEO_INCLUDES_PATH . 'option-defaults.php';
	require_once DIAGNOSEO_INCLUDES_PATH . 'admin-bar-menu.php';

	if ( is_admin() ) {
		global $pagenow;
		$seo_options_not_needed = array(
			'upload.php',
			'media-new.php',
			'options-general.php',
			'options-discussion.php',
			'options-writing.php',
			'options-reading.php',
			'options-media.php',
			'options-privacy.php',
			'edit-tags.php',
			'edit-comments.php',
			'edit.php',
			'index.php',
		);

		require_once DIAGNOSEO_INCLUDES_PATH . 'class-diagnoseo-settings.php';

		$settings = new Diagnoseo_Settings( $diagnoseo_defaults );

		if ( in_array( $pagenow, $seo_options_not_needed, true ) ) {
			return;
		}

		if ( 'post-new.php' !== $pagenow && 'post.php' !== $pagenow ) {
			require_once DIAGNOSEO_INCLUDES_PATH . 'category-links.php';
		}

		if ( ! in_array( $pagenow, array( 'upload.php', 'media-new.php', 'post.php', 'post-new.php', 'customize.php' ), true ) ) {
			require_once DIAGNOSEO_INCLUDES_PATH . 'class-diagnoseo-plugindetector.php';
			require_once DIAGNOSEO_INCLUDES_PATH . 'admin-actions.php';
		}

		if ( 'customize.php' === $pagenow || 'admin-ajax.php' === $pagenow ) {
			require_once DIAGNOSEO_CUSTOMIZE_PATH . 'defaults.php';
			require_once DIAGNOSEO_CUSTOMIZE_PATH . 'customize-utils.php';
			require_once DIAGNOSEO_CUSTOMIZE_PATH . 'breadcrumbs.php';
		}

		// Only settings pages.
		if ( 'admin.php' === $pagenow || 'options.php' === $pagenow ) {
			$page = isset( $_GET['page'] ) ? trim( sanitize_text_field( wp_unslash( $_GET['page'] ) ) ) : ''; // phpcs:ignore

			switch ( $page ) {
				case 'diagnoseo-settings-meta':
					require_once DIAGNOSEO_INCLUDES_PATH . 'assets.php';
					require_once DIAGNOSEO_INCLUDES_PATH . 'utils.php';
					require_once DIAGNOSEO_INCLUDES_PATH . 'class-diagnoseo-metatagsettings.php';
					break;
				case 'diagnoseo-settings-scripts':
					require_once DIAGNOSEO_INCLUDES_PATH . 'class-diagnoseo-scriptsettings.php';
					break;
				case 'diagnoseo-settings-schema':
					require_once DIAGNOSEO_INCLUDES_PATH . 'assets.php';
					require_once DIAGNOSEO_INCLUDES_PATH . 'class-diagnoseo-settingshelper.php';
					require_once DIAGNOSEO_INCLUDES_PATH . 'class-diagnoseo-schemasettings.php';
					break;
				case 'diagnoseo-settings-sitemap':
					require_once DIAGNOSEO_INCLUDES_PATH . 'class-diagnoseo-sitemapsettings.php';
					break;
				case 'diagnoseo-settings-social':
					require_once DIAGNOSEO_INCLUDES_PATH . 'assets.php';
					require_once DIAGNOSEO_INCLUDES_PATH . 'class-diagnoseo-socialsettings.php';
					break;
				case 'diagnoseo-redirections':
					require_once DIAGNOSEO_INCLUDES_PATH . 'assets.php';
					require_once DIAGNOSEO_INCLUDES_PATH . 'class-diagnoseo-settingshelper.php';
					require_once DIAGNOSEO_INCLUDES_PATH . 'class-diagnoseo-redirectionsettings.php';
					break;
				case 'diagnoseo-import-postmeta':
					require_once DIAGNOSEO_INCLUDES_PATH . 'class-diagnoseo-postmetaimport.php';
					break;
				case 'diagnoseo-tools':
					require_once DIAGNOSEO_INCLUDES_PATH . 'class-diagnoseo-toolspage.php';
					break;
				default:
					require_once DIAGNOSEO_INCLUDES_PATH . 'class-diagnoseo-settingshelper.php';
					require_once DIAGNOSEO_INCLUDES_PATH . 'class-diagnoseo-generalsettings.php';
			}
		}

		// Only settings saving.
		if ( 'options.php' === $pagenow && isset( $_POST['option_page'] ) ) { // phpcs:ignore
			switch ( sanitize_text_field( wp_unslash( $_POST['option_page'] ) ) ) { // phpcs:ignore
				case 'diagnoseo_general_options':
					require_once DIAGNOSEO_INCLUDES_PATH . 'class-diagnoseo-settingshelper.php';
					require_once DIAGNOSEO_INCLUDES_PATH . 'class-diagnoseo-generalsettings.php';
					$page = new Diagnoseo_GeneralSettings();
					break;
				case 'diagnoseo_metatag_options':
					require_once DIAGNOSEO_INCLUDES_PATH . 'class-diagnoseo-metatagsettings.php';
					$page = new Diagnoseo_MetaTagSettings( $diagnoseo_defaults );
					break;
				case 'diagnoseo_script_options':
					require_once DIAGNOSEO_INCLUDES_PATH . 'class-diagnoseo-scriptsettings.php';
					$page = new Diagnoseo_ScriptSettings();
					break;
				case 'diagnoseo_schema_options':
					require_once DIAGNOSEO_INCLUDES_PATH . 'class-diagnoseo-settingshelper.php';
					require_once DIAGNOSEO_INCLUDES_PATH . 'class-diagnoseo-schemasettings.php';
					$page = new Diagnoseo_SchemaSettings( $diagnoseo_defaults );
					break;
				case 'diagnoseo_sitemap_options':
					require_once DIAGNOSEO_INCLUDES_PATH . 'class-diagnoseo-sitemapsettings.php';
					$page = new Diagnoseo_SitemapSettings();
					break;
				case 'diagnoseo_social_options':
					require_once DIAGNOSEO_INCLUDES_PATH . 'class-diagnoseo-socialsettings.php';
					$page = new Diagnoseo_SocialSettings();
					break;
			}
		}

		// only post editor.
		if ( 'post-new.php' === $pagenow || 'post.php' === $pagenow ) {
			require_once DIAGNOSEO_INCLUDES_PATH . 'assets.php';
			require_once DIAGNOSEO_INCLUDES_PATH . 'utils.php';
			require_once DIAGNOSEO_INCLUDES_PATH . 'api-endpoints.php';
			require_once DIAGNOSEO_INCLUDES_PATH . 'content-watcher-meta.php';
			require_once DIAGNOSEO_INCLUDES_PATH . 'class-diagnoseo-settingshelper.php';
			require_once DIAGNOSEO_INCLUDES_PATH . 'blocks.php';
			require_once DIAGNOSEO_INCLUDES_PATH . 'metabox-seo-settings.php';
			require_once DIAGNOSEO_INCLUDES_PATH . 'components/class-diagnoseo-formats.php';
			require_once DIAGNOSEO_INCLUDES_PATH . 'css-variables.php';
			require_once DIAGNOSEO_INCLUDES_PATH . 'content-watcher-scripts.php';

			add_action( 'admin_enqueue_scripts', 'diagnoseo_add_editor_style' );
			add_action( 'admin_enqueue_scripts', 'diagnoseo_add_metabox_scripts' );
		}
	} else {
		require_once DIAGNOSEO_INCLUDES_PATH . 'content-watcher-meta.php';
		require_once DIAGNOSEO_CUSTOMIZE_PATH . 'defaults.php';
		require_once DIAGNOSEO_INCLUDES_PATH . 'assets.php';
		require_once DIAGNOSEO_INCLUDES_PATH . 'utils.php';
		require_once DIAGNOSEO_CUSTOMIZE_PATH . 'customize-utils.php';
		require_once DIAGNOSEO_CUSTOMIZE_PATH . 'breadcrumbs.php';
		require_once DIAGNOSEO_INCLUDES_PATH . 'category-links.php';
		require_once DIAGNOSEO_INCLUDES_PATH . 'api-endpoints.php';
		require_once DIAGNOSEO_INCLUDES_PATH . 'css-variables.php';
		require_once DIAGNOSEO_INCLUDES_PATH . 'blocks.php';
		require_once DIAGNOSEO_INCLUDES_PATH . 'actions.php';
		require_once DIAGNOSEO_INCLUDES_PATH . 'class-diagnoseo-scripts.php';
		require_once DIAGNOSEO_INCLUDES_PATH . 'sitemap.php';
		require_once DIAGNOSEO_INCLUDES_PATH . 'structured-data.php';
		require_once DIAGNOSEO_INCLUDES_PATH . 'class-diagnoseo-breadcrumbs.php';
		require_once DIAGNOSEO_INCLUDES_PATH . 'queries.php';
		require_once DIAGNOSEO_INCLUDES_PATH . 'class-diagnoseo-metatags.php';

		$scripts = new Diagnoseo_Scripts();
		$meta    = new Diagnoseo_MetaTags( $diagnoseo_defaults );
		$bc_list = new Diagnoseo_Breadcrumbs();
	}
}

diagnoseo_init();

/**
 * Calls the breadcrumbs rendering method
 */
function diagnoseo_render_breadcrumbs() {
	$bc = new Diagnoseo_Breadcrumbs();
	$bc->build_structured_data();
	$bc->render_breadcrumbs();
}
