<?php
/**
 * Menu in Admin Bar
 *
 * @package DiagnoSEO
 */

if ( ! defined( 'ABSPATH' ) ) {
	die;
}

/**
 * Creates the admin bar menu
 *
 * @param WP_Admin_Bar $admin_bar The Admin Bar.
 */
function diagnoseo_admin_bar_menu( WP_Admin_Bar $admin_bar ) {
	if ( ! current_user_can( 'manage_options' ) ) {
		return;
	}
	$admin_bar->add_menu(
		array(
			'id'     => 'diagnoseo-menu',
			'parent' => null,
			'group'  => null,
			'title'  => '<span class="ab-icon" aria-hidden="true" style="width: 18px; height: 20px;"><svg enable-background="new 0 0 20 20" height="100%" viewBox="0 0 20 20" width="100%" xmlns="http://www.w3.org/2000/svg"><path d="m12.4 5.9 1.8 1.6-4.8 5.5-4.1-3.6 1.7-1.9 2.3 2zm7.4 12.4-1.4 1.7-3.7-3.3c-1.2.8-2.6 1.3-4 1.5-5 .6-9.6-2.9-10.3-7.9-.4-2.4.3-4.8 1.8-6.7s3.7-3.2 6.1-3.5c2.4-.3 4.8.3 6.8 1.8 1.9 1.5 3.1 3.7 3.4 6.1.3 2.6-.5 5.2-2.2 7.2zm-3.6-10c-.4-3.4-3.4-5.9-6.8-5.9-.3 0-.6 0-.9.1-3.7.4-6.3 3.8-5.8 7.5.2 1.8 1.2 3.4 2.6 4.5s3.2 1.6 5 1.4 3.4-1.2 4.5-2.6 1.6-3.2 1.4-5z" fill="#a6a9ab"/></svg></span> DiagnoSEO',
			'href'   => admin_url( 'admin.php?page=diagnoseo-settings' ),
			'meta'   => array(
				'title' => __( 'DiagnoSEO', 'diagnoseo' ),
			),
		)
	);

	$admin_bar->add_menu(
		array(
			'id'     => 'diagnoseo-settings-meta',
			'parent' => 'diagnoseo-menu',
			'group'  => null,
			'title'  => 'Meta tags',
			'href'   => admin_url( 'admin.php?page=diagnoseo-settings-meta' ),
			'meta'   => array(
				'title' => __( 'Meta tag settings', 'diagnoseo' ),
			),
		)
	);
	$admin_bar->add_menu(
		array(
			'id'     => 'diagnoseo-settings-scripts',
			'parent' => 'diagnoseo-menu',
			'group'  => null,
			'title'  => 'Script settings',
			'href'   => admin_url( 'admin.php?page=diagnoseo-settings-scripts' ),
			'meta'   => array(
				'title' => __( 'Scripts in header, content and footer', 'diagnoseo' ),
			),
		)
	);
	$admin_bar->add_menu(
		array(
			'id'     => 'diagnoseo-settings-schema',
			'parent' => 'diagnoseo-menu',
			'group'  => null,
			'title'  => 'Schema settings',
			'href'   => admin_url( 'admin.php?page=diagnoseo-settings-schema' ),
			'meta'   => array(
				'title' => __( 'Schema and structured data settings', 'diagnoseo' ),
			),
		)
	);
	$admin_bar->add_menu(
		array(
			'id'     => 'diagnoseo-settings-sitemap',
			'parent' => 'diagnoseo-menu',
			'group'  => null,
			'title'  => 'Sitemap settings',
			'href'   => admin_url( 'admin.php?page=diagnoseo-settings-sitemap' ),
			'meta'   => array(
				'title' => __( 'Sitemap settings', 'diagnoseo' ),
			),
		)
	);
	$admin_bar->add_menu(
		array(
			'id'     => 'diagnoseo-settings-social',
			'parent' => 'diagnoseo-menu',
			'group'  => null,
			'title'  => 'Social settings',
			'href'   => admin_url( 'admin.php?page=diagnoseo-settings-social' ),
			'meta'   => array(
				'title' => __( 'Social/OpenGraph settings', 'diagnoseo' ),
			),
		)
	);
	$admin_bar->add_menu(
		array(
			'id'     => 'diagnoseo-settings-redirections',
			'parent' => 'diagnoseo-menu',
			'group'  => null,
			'title'  => 'Redirections',
			'href'   => admin_url( 'admin.php?page=diagnoseo-redirections' ),
			'meta'   => array(
				'title' => __( 'Redirection settings', 'diagnoseo' ),
			),
		)
	);
	$admin_bar->add_menu(
		array(
			'id'     => 'diagnoseo-import-postmeta',
			'parent' => 'diagnoseo-menu',
			'group'  => null,
			'title'  => 'Import post meta',
			'href'   => admin_url( 'admin.php?page=diagnoseo-import-postmeta' ),
			'meta'   => array(
				'title' => __( 'Meta tag import for posts and pages', 'diagnoseo' ),
			),
		)
	);
}
add_action( 'admin_bar_menu', 'diagnoseo_admin_bar_menu', 500 );
