<?php
/**
 * REST API endpoints
 *
 * @package DiagnoSEO
 */

if ( ! defined( 'ABSPATH' ) ) {
	die;
}

/**
 * Checks for keyword usage in posts
 *
 * @param WP_REST_Request $request The REST request.
 */
function diagnoseo_posts_with_keyword( WP_REST_Request $request ) {
	$keyword = $request->get_param( 'keyword' );
	$id      = $request->get_param( 'id' );
	return diagnoseo_check_posts_with_keyword( $keyword, $id );
}

/**
 * Registers custom API routes
 */
function diagnoseo_register_api_routes() {
	$namespace = 'diagnoseo/v1';

	register_rest_route(
		$namespace,
		'check-posts-keyword/(?P<keyword>.+)/(?P<id>[0-9]+)',
		array(
			'methods'             => 'GET, POST',
			'callback'            => 'diagnoseo_posts_with_keyword',
			'permission_callback' => '__return_true',
			'args'                => array(
				'keyword' => array(
					'validate_callback'   => function ( $param, $request, $key ) {
						return ! empty( $param );
					},
					'sanitize_callback'   => 'sanitize_text_field',
					'permission_callback' => '__return_true',
				),
				'id'      => array(
					'sanitize_callback'   => 'absint',
					'validate_callback'   => '__return_true',
					'permission_callback' => '__return_true',
				),
			),
		)
	);
}

add_action( 'rest_api_init', 'diagnoseo_register_api_routes' );

/**
 * Counts posts with specified keyword set as focus keyword
 *
 * @param String  $keyword The keyword.
 * @param Integer $id ID of the current.
 */
function diagnoseo_check_posts_with_keyword( $keyword, $id ) {
	$options = array(
		'post_status'         => 'publish',
		'post_type'           => 'any',
		'meta_key'            => 'diagnoseo_meta_keyword', //phpcs:ignore
		'meta_value'          => esc_sql( $keyword ), //phpcs:ignore
		'ignore_sticky_posts' => true,
		'post__not_in'        => array( $id ),
	);
	$query   = new WP_Query( $options );
	$count   = $query->post_count;

	return $query->post_count;
}
