<?php
/**
 * Asset loading
 *
 * @package DiagnoSEO
 */

if ( ! defined( 'ABSPATH' ) ) {
	die;
}
global $pagenow;

/**
 * Adds styles in front-end
 */
function diagnoseo_add_styles() {
	$debug_suffix = WP_DEBUG ? '?v=' . time() : '';

	wp_register_style( 'diagnoseo-css-vars', false, array(), 1 );
	wp_enqueue_style( 'diagnoseo-css-vars' );

	wp_enqueue_style( 'diagnoseo', DIAGNOSEO_PLUGIN_URL . 'css/diagnoseo.css' . $debug_suffix, array(), 1 );
}
add_action( 'wp_enqueue_scripts', 'diagnoseo_add_styles', 1 );

/**
 * Adds js in frontend
 */
function diagnoseo_add_scripts() {
	$debug_suffix = WP_DEBUG ? '?v=' . time() : '';
	wp_enqueue_script( 'diagnoseo-frontend-scripts', DIAGNOSEO_PLUGIN_URL . 'js/diagnoseo-frontend.min.js' . $debug_suffix, array(), '1', true );
}
add_action( 'wp_enqueue_scripts', 'diagnoseo_add_scripts' );

/**
 * Adds styles in admin
 */
function diagnoseo_add_admin_style() {
	$debug_suffix = WP_DEBUG ? '?v=' . time() : '';
	wp_enqueue_style( 'diagnoseo-admin', DIAGNOSEO_PLUGIN_URL . 'css/diagnoseo-admin.css' . $debug_suffix, array(), 1 );
}

/**
 * Adds styles in post/page editor
 */
function diagnoseo_add_editor_style() {
	$debug_suffix = WP_DEBUG ? '?v=' . time() : '';
	wp_enqueue_style( 'diagnoseo-editor', DIAGNOSEO_PLUGIN_URL . 'css/diagnoseo-editor.css' . $debug_suffix, array(), 1 );
}

/**
 * Adds scripts in admin
 *
 * @param String $hook Hook name.
 */
function diagnoseo_add_admin_scripts( $hook ) {
	$debug_suffix = WP_DEBUG ? '?v=' . time() : '';
	wp_enqueue_media();
	wp_enqueue_script( 'wp-api' );
	wp_enqueue_script( 'diagnoseo', DIAGNOSEO_PLUGIN_URL . 'js/diagnoseo.min.js' . $debug_suffix, array( 'wp-api' ), 1, true );
}

/**
 * Adds metabox scripts
 *
 * @param String $hook Hook name.
 */
function diagnoseo_add_metabox_scripts( $hook ) {
	$screen = get_current_screen();
	if ( ! $screen->is_block_editor ) {
		$debug_suffix = WP_DEBUG ? '?v=' . time() : '';
		wp_enqueue_media();
		wp_enqueue_script( 'wp-api' );
		wp_enqueue_script( 'diagnoseo-metaboxes', DIAGNOSEO_PLUGIN_URL . 'js/diagnoseo-editor-metabox.min.js' . $debug_suffix, array( 'wp-api' ), 1, true );
	}
}

/**
 * Adds REST API path in a variable
 */
function diagnoseo_api_url() {
	if ( is_customize_preview() ) {
		return;
	}
	?>
<script>var diagnoseoRestUrl = '<?php echo esc_url( get_rest_url() ); ?>';</script>
	<?php
}
if ( 'post-new.php' === $pagenow || 'post.php' === $pagenow ) {
	add_action( 'admin_enqueue_scripts', 'diagnoseo_api_url', 10 );
}

/**
 * Theme customizer preview scripts
 */
function diagnoseo_add_customizer_refresh_script() {
	$debug_suffix = WP_DEBUG ? '?v=' . time() : '';
	wp_enqueue_script(
		'diagnoseo-customizer-refresh',
		DIAGNOSEO_PLUGIN_URL . '/js/diagnoseo-customizer.min.js' . $debug_suffix,
		array( 'jquery', 'customize-preview' ),
		1,
		true
	);
}
add_action( 'customize_preview_init', 'diagnoseo_add_customizer_refresh_script' );

/**
 * Adds custom css
 *
 * @param String $css Style to display.
 */
function diagnoseo_add_style( $css ) {
	$handle = 'diagnoseo-blocks-custom';
	if ( ! wp_style_is( $handle ) ) {
		wp_register_style( $handle, false, array(), 1 );
		wp_enqueue_style( $handle );
	}
	wp_add_inline_style( $handle, $css );
}
