<?php
/**
 * Block registration
 *
 * @package DiagnoSEO
 */

if ( ! defined( 'ABSPATH' ) ) {
	die;
}


/**
 * Creates block category
 *
 * @param Array  $categories Block categories already registered.
 * @param Object $post Post object.
 */
function diagnoseo_block_categories( $categories, $post ) {
	return array_merge(
		$categories,
		array(
			array(
				'slug'  => 'diagnoseo-blocks',
				'title' => __( 'DiagnoSEO', 'diagnoseo-blocks' ),
			),
		)
	);
}
add_filter( 'block_categories_all', 'diagnoseo_block_categories', 10, 2 );


global $wp_filesystem;
if ( empty( $wp_filesystem ) ) {
	require_once ABSPATH . '/wp-admin/includes/file.php';
	WP_Filesystem();
}

if ( $wp_filesystem->is_dir( DIAGNOSEO_BLOCKS_PATH ) ) {
	$block_dir = opendir( DIAGNOSEO_BLOCKS_PATH );
	$file      = readdir( $block_dir );
	while ( false !== $file ) {
		if ( '.' !== $file && '..' !== $file ) {
			$dir = DIAGNOSEO_BLOCKS_PATH . $file;
			if ( $wp_filesystem->is_dir( $dir ) ) {
				$block_file = $dir . '/' . $file . '.php';
				if ( $wp_filesystem->is_file( $block_file ) ) {
					require_once $block_file;
				}
			}
		}
		$file = readdir( $block_dir );
	}
	closedir( $block_dir );
}

/**
 * Registers blocks
 */
function diagnoseo_register_blocks() {
	$block_list = array(
		'breadcrumbs',
	);

	foreach ( $block_list as $block ) {
		diagnoseo_register_block_script( $block );
		diagnoseo_register_block_type( $block );
	}
}
add_action( 'init', 'diagnoseo_register_blocks' );

/**
 * Registers block js with helper file
 *
 * @param String $slug Block slug.
 */
function diagnoseo_register_block_script( $slug ) {
	if ( ! function_exists( 'wp_register_script' ) ) {
		return;
	}
	$debug_suffix = WP_DEBUG ? '?v=' . time() : '';

	$deps = array(
		'wp-blocks',
		'wp-i18n',
		'wp-element',
		'wp-components',
		'wp-editor',
	);

	wp_register_script(
		'diagnoseo-' . $slug,
		DIAGNOSEO_PLUGIN_URL . 'js/blocks/' . $slug . '.min.js' . $debug_suffix,
		$deps,
		1,
		true
	);
}

/**
 * Registers block type
 *
 * @param String $slug Block slug.
 */
function diagnoseo_register_block_type( $slug ) {
	if ( ! function_exists( 'register_block_type' ) || empty( $slug ) ) {
		return;
	}

	register_block_type(
		'diagnoseo/' . $slug,
		array(
			'editor_script'   => 'diagnoseo-' . $slug,
			'render_callback' => 'diagnoseo_' . str_replace( '-', '_', $slug ),
		)
	);
}
