<?php
/**
 * Breadcrumbs block
 *
 * @package DiagnoSEO
 */

if ( ! defined( 'ABSPATH' ) ) {
	die;
}
$bc_number = 0;

/**
 * Renders the breadcrumbs block
 *
 * @param Array  $attr Block attributes.
 * @param String $content Block content (html).
 */
function diagnoseo_breadcrumbs( $attr, $content = null ) {
	$show_current           = isset( $attr['show_current'] ) ? $attr['show_current'] : true;
	$separator              = isset( $attr['separator'] ) ? $attr['separator'] : get_theme_mod( 'diagnoseo_breadcrumbs_separator', DIAGNOSEO_BREADCRUMBS_SEPARATOR );
	$text_color             = isset( $attr['text_color'] ) ? $attr['text_color'] : '';
	$link_color             = isset( $attr['link_color'] ) ? $attr['link_color'] : '';
	$link_hover_color       = isset( $attr['link_hover_color'] ) ? $attr['link_hover_color'] : '';
	$background_color       = isset( $attr['background_color'] ) ? $attr['background_color'] : '';
	$background_image       = isset( $attr['background_image'] ) ? $attr['background_image'] : '';
	$background_size        = isset( $attr['background_size'] ) ? $attr['background_size'] : '';
	$custom_background_size = isset( $attr['custom_background_size'] ) ? $attr['custom_background_size'] : '';
	$background_repeat      = isset( $attr['background_repeat'] ) ? $attr['background_repeat'] : '';
	$text_align             = isset( $attr['text_align'] ) ? $attr['text_align'] : '';
	$align                  = isset( $attr['align'] ) ? $attr['align'] : '';
	$class                  = isset( $attr['class'] ) ? $attr['class'] : '';
	$id                     = isset( $attr['id'] ) ? $attr['id'] : '';
	$style                  = isset( $attr['style'] ) ? $attr['style'] : '';

	global $bc_number;
	$bc_number ++;

	/* styles */

	$style_props = array(
		$text_color,
		$background_color,
		$background_image,
		$background_size,
		$custom_background_size,
		$style,
	);

	$css = '';

	if ( diagnoseo_any_value_exists( $style_props ) ) {
		$selector = '.diagnoseo-breadcrumbs.diagnoseo-breadcrumbs-' . $bc_number;

		$css .= $selector . '{';
		if ( ! empty( $text_color ) ) {
			$css .= 'color: ' . $text_color . ';';
		}
		if ( ! empty( $background_color ) ) {
			$css .= 'background-color: ' . $background_color . ';';
		}
		if ( ! empty( $background_image ) ) {
			$css .= 'background-image: url(' . $background_image . ');';
			if ( ! empty( $background_size ) ) {
				if ( 'custom' === $background_size ) {
					$css .= 'background-size: ' . $custom_background_size . ';';
				} else {
					$css .= 'background-size: ' . $background_size . ';';
				}
			}
		}
		$css .= $style;
		$css .= '}';
	}

	if ( ! empty( $link_color ) ) {
		$css .= $selector . ' .breadcrumbs-content li a {color: ' . $link_color . '}';
	}
	if ( ! empty( $link_hover_color ) ) {
		$css .= $selector . ' .breadcrumbs-content li a:hover {color: ' . $link_hover_color . '}';
	}

	if ( ! empty( $css ) ) {
		diagnoseo_add_style( $css );
	}

	/* markup */

	$classes = 'diagnoseo-breadcrumbs diagnoseo-breadcrumbs-' . $bc_number;
	if ( ! empty( $backgrund_repeat ) ) {
		$classes .= ' bg-repeat-' . $background_repeat;
	}
	if ( ! empty( $align ) ) {
		$classes .= ' align' . $align;
	}
	if ( ! empty( $text_align ) ) {
		$classes .= ' text-align-' . $text_align;
	}

	$classes .= get_theme_mod( 'diagnoseo_breadcrumbs_border', DIAGNOSEO_BREADCRUMBS_BORDER ) ? ' with-border' : '';
	if ( ! empty( get_theme_mod( 'diagnoseo_breadcrumbs_color' ) ) ) {
		$classes .= ' colored-text';
	}
	if ( ! empty( get_theme_mod( 'diagnoseo_breadcrumbs_link_color' ) ) || ! empty( get_theme_mod( 'diagnoseo_breadcrumbs_link_hover_color' ) ) ) {
		$classes .= ' colored-links';
	}

	$delimiter = '<span class="delimiter" aria-hidden="true">' . esc_html( $separator ) . '</span>';
	$output    = '<nav class="' . esc_attr( $classes ) . '" aria-label="Breadcrumbs">';

	if ( function_exists( 'is_bbpress' ) && is_bbpress() ) {
		$output .= bbp_get_breadcrumb(
			array(
				'before'     => '<div class="breadcrumbs-content">',
				'after'      => '</div>',
				'sep'        => esc_html( $separator ),
				'sep_before' => '<span class="delimiter" aria-hidden="true">',
				'sep_after'  => '</span>',
			)
		);
		$output .= '</nav>';
		return $output;
	}

	$output .= '<ol class="breadcrumbs-content">';

	if ( class_exists( 'Diagnoseo_Breadcrumbs' ) ) {
		$bc = new Diagnoseo_Breadcrumbs();
		$bc->build_structured_data();

		$schema = $bc->get_schema();
		if ( empty( $schema ) ) {
			return;
		}
		$items = $schema->itemListElement; // phpcs:ignore
		$count = count( $items );
		foreach ( $items as $i => $item ) {
			$pos = absint( $item->position );
			if ( $pos < $count ) {
				if ( 1 !== $pos ) {
					$output .= '<li>' . $delimiter . '<a href="' . esc_url( $item->item ) . '">' . esc_html( $item->name ) . '</a></li>';
				} else {
					$output .= '<li><a href="' . esc_url( $item->item ) . '">' . esc_html( $item->name ) . '</a></li>';
				}
			} elseif ( $show_current && $pos === $count ) {
				$output .= '<li>' . $delimiter . '<a href="' . esc_url( $item->item ) . '" class="current" aria-current="location">' . esc_html( $item->name ) . '</a></li>';
			}
		}
	}

	$output .= '</ol>';
	$output .= '</nav>';

	return $output;
}
