<?php
/**
 * Plugin general settings
 *
 * @package DiagnoSEO
 */

if ( ! defined( 'ABSPATH' ) ) {
	die;
}

/**
 * General settings page
 */
class Diagnoseo_GeneralSettings {

	/**
	 * Option group name
	 *
	 * @var $option_group
	 */
	private $option_group = 'diagnoseo_general_options';

	/**
	 * Hooks actions on object creation
	 */
	public function __construct() {
		global $pagenow;
		if ( 'admin.php' === $pagenow || 'options.php' === $pagenow ) {
			add_action( 'admin_init', array( $this, 'register_settings' ) );
		}
	}

	/**
	 * Renders general settings page content
	 */
	public function render() {
		$post_types = Diagnoseo_SettingsHelper::get_post_types();
		?>
		<div class="wrap">
			<h1><?php esc_html_e( 'DiagnoSEO General Options', 'diagnoseo' ); ?></h1>
			<form method="post" action="options.php" class="diagnoseo-settings-form">
			<?php
			settings_fields( 'diagnoseo_general_options' );
			do_settings_sections( 'diagnoseo_general_options' );
			?>
				<?php if ( get_option( 'wp_attachment_pages_enabled' ) ) : ?>
				<div class="diagnoseo-settings-section image-settings">
					<h2><?php esc_html_e( 'Image settings', 'diagnoseo' ); ?></h2>
					<table class="form-table" role="presentation">
						<tbody>
							<tr>
								<th><label for="diagnoseo_redirect_attachment"><?php esc_html_e( 'Redirect attachment page links to image file', 'diagnoseo' ); ?></label></th>
								<td><input type="checkbox" name="diagnoseo_redirect_attachment" id="diagnoseo_redirect_attachment" value="1" <?php checked( 1, get_option( 'diagnoseo_redirect_attachment' ), true ); ?> /></td>
							</tr>
						</tbody>
					</table>
				</div>
				<?php endif; ?>

				<div class="diagnoseo-settings-section content-types">
					<h2><?php esc_html_e( 'Meta robots - indexing settings', 'diagnoseo' ); ?></h2>
					<table class="form-table" role="presentation">
						<tbody>
							<?php
							foreach ( $post_types as $type ) :
								$setting_name = 'diagnoseo_dont_index_' . $type->name;
								$index_name   = 'diagnoseo_' . $type->name . '_index';
								$follow_name  = 'diagnoseo_' . $type->name . '_follow';
								?>
								<tr>
									<th><?php echo esc_html( $type->labels->singular_name ); ?></th>
									<td>
										<select name="<?php echo esc_attr( $index_name ); ?>" id="<?php echo esc_attr( $index_name ); ?>">
											<option value="index" <?php selected( 'index', get_option( $index_name, 'index' ) ); ?>>index (<?php esc_html_e( 'default', 'diagnoseo' ); ?>)</option>
											<option value="noindex" <?php selected( 'noindex', get_option( $index_name, 'index' ) ); ?>>noindex</option>
										</select>
										<select name="<?php echo esc_attr( $follow_name ); ?>" id="<?php echo esc_attr( $follow_name ); ?>">
											<option value="follow" <?php selected( 'follow', get_option( $follow_name, 'follow' ) ); ?>>follow (<?php esc_html_e( 'default', 'diagnoseo' ); ?>)</option>
											<option value="nofollow" <?php selected( 'nofollow', get_option( $follow_name, 'follow' ) ); ?>>nofollow</option>
										</select>
									</td>
								</tr>
								<?php
							endforeach;
							?>
							<tr>
								<th><?php esc_html_e( 'Author', 'diagnoseo' ); ?></th>
								<td>
									<select name="diagnoseo_author_index" id="diagnoseo_author_index">
										<option value="index" <?php selected( 'index', get_option( 'diagnoseo_author_index', 'index' ) ); ?>>index (<?php esc_html_e( 'default', 'diagnoseo' ); ?>)</option>
										<option value="noindex" <?php selected( 'noindex', get_option( 'diagnoseo_author_index', 'index' ) ); ?>>noindex</option>
									</select>
									<select name="diagnoseo_author_follow" id="diagnoseo_author_follow">
										<option value="follow" <?php selected( 'follow', get_option( 'diagnoseo_author_follow', 'follow' ) ); ?>>follow (<?php esc_html_e( 'default', 'diagnoseo' ); ?>)</option>
										<option value="nofollow" <?php selected( 'nofollow', get_option( 'diagnoseo_author_follow', 'follow' ) ); ?>>nofollow</option>
									</select>
								</td>
							</tr>
							<tr>
								<th><?php esc_html_e( 'Tag', 'diagnoseo' ); ?></th>
								<td>
									<select name="diagnoseo_tag_index" id="diagnoseo_tag_index">
										<option value="index" <?php selected( 'index', get_option( 'diagnoseo_tag_index', 'index' ) ); ?>>index (<?php esc_html_e( 'default', 'diagnoseo' ); ?>)</option>
										<option value="noindex" <?php selected( 'noindex', get_option( 'diagnoseo_tag_index', 'index' ) ); ?>>noindex</option>
									</select>
									<select name="diagnoseo_tag_follow" id="diagnoseo_tag_follow">
										<option value="follow" <?php selected( 'follow', get_option( 'diagnoseo_tag_follow', 'follow' ) ); ?>>follow (<?php esc_html_e( 'default', 'diagnoseo' ); ?>)</option>
										<option value="nofollow" <?php selected( 'nofollow', get_option( 'diagnoseo_tag_follow', 'follow' ) ); ?>>nofollow</option>
									</select>
								</td>
							</tr>
							<tr>
								<th><?php esc_html_e( 'Archives', 'diagnoseo' ); ?></th>
								<td>
									<select name="diagnoseo_archive_index" id="diagnoseo_archive_index">
										<option value="index" <?php selected( 'index', get_option( 'diagnoseo_archive_index', 'index' ) ); ?>>index (<?php esc_html_e( 'default', 'diagnoseo' ); ?>)</option>
										<option value="noindex" <?php selected( 'noindex', get_option( 'diagnoseo_archive_index', 'index' ) ); ?>>noindex</option>
									</select>
									<select name="diagnoseo_archive_follow" id="diagnoseo_archive_follow">
										<option value="follow" <?php selected( 'follow', get_option( 'diagnoseo_archive_follow', 'follow' ) ); ?>>follow (<?php esc_html_e( 'default', 'diagnoseo' ); ?>)</option>
										<option value="nofollow" <?php selected( 'nofollow', get_option( 'diagnoseo_archive_follow', 'follow' ) ); ?>>nofollow</option>
									</select>
								</td>
							</tr>
							<tr>
								<th><?php esc_html_e( 'Date archive', 'diagnoseo' ); ?></th>
								<td>
									<select name="diagnoseo_date_archive_index" id="diagnoseo_date_archive_index">
										<option value="index" <?php selected( 'index', get_option( 'diagnoseo_date_archive_index', 'noindex' ) ); ?>>index</option>
										<option value="noindex" <?php selected( 'noindex', get_option( 'diagnoseo_date_archive_index', 'noindex' ) ); ?>>noindex (<?php esc_html_e( 'default', 'diagnoseo' ); ?>)</option>
									</select>
									<select name="diagnoseo_date_archive_follow" id="diagnoseo_date_archive_follow">
										<option value="follow" <?php selected( 'follow', get_option( 'diagnoseo_date_archive_follow', 'follow' ) ); ?>>follow (<?php esc_html_e( 'default', 'diagnoseo' ); ?>)</option>
										<option value="nofollow" <?php selected( 'nofollow', get_option( 'diagnoseo_date_archive_follow', 'follow' ) ); ?>>nofollow</option>
									</select>
								</td>
							</tr>
						</tbody>
					</table>
				</div>

				<div class="diagnoseo-settings-section content-types">
					<h2><?php esc_html_e( 'Link settings', 'diagnoseo' ); ?></h2>
					<table class="form-table" role="presentation">
						<tbody>
							<tr>
								<th><label for="diagnoseo_fix_category_url_base"><?php esc_html_e( 'Remove category base (by default: "/category/") from category links', 'diagnoseo' ); ?></label></th>
								<td><input type="checkbox" name="diagnoseo_fix_category_url_base" id="diagnoseo_fix_category_url_base" value="1" <?php checked( 1, get_option( 'diagnoseo_fix_category_url_base' ), true ); ?> /></td>
							</tr>
							<?php if ( class_exists( 'WooCommerce' ) ) : ?>
							<tr>
								<th><label for="diagnoseo_fix_product_cat_url_base"><?php esc_html_e( 'Remove "/product-category/" from product category links', 'diagnoseo' ); ?></label></th>
								<td><input type="checkbox" name="diagnoseo_fix_product_cat_url_base" id="diagnoseo_fix_product_cat_url_base" value="1" <?php checked( 1, get_option( 'diagnoseo_fix_product_cat_url_base' ), true ); ?> /></td>
							</tr>
							<?php endif; ?>
							<?php do_action( 'diagnoseo_link_settings' ); ?>
						</tbody>
					</table>
				</div>

				<div class="diagnoseo-settings-section">
					<h2><?php esc_html_e( 'Breadcrumbs', 'diagnoseo' ); ?></h2>
					<p><?php esc_html_e( 'Customize breadcrumbs in', 'diagnoseo' ); ?> <a href="<?php echo esc_url( wp_customize_url() ); ?>"><?php esc_html_e( 'Theme Customizer', 'diagnoseo' ); ?></a></p>
				</div>

				<?php do_action( 'diagnoseo_render_general_options' ); ?>

			<?php submit_button(); ?>
			</form>
		</div>
		<?php
	}

	/**
	 * Registers general options
	 */
	public function register_settings() {
		$helper     = new Diagnoseo_SettingsHelper();
		$post_types = Diagnoseo_SettingsHelper::get_post_types();

		add_option( 'diagnoseo_redirect_attachment', get_option( 'wp_attachment_pages_enabled' ) );
		register_setting(
			$this->option_group,
			'diagnoseo_redirect_attachment',
			array(
				'type'         => 'boolean',
				'description'  => __( 'Redirect attachment page links to media file.', 'diagnoseo' ),
				'show_in_rest' => true,
				'default'      => get_option( 'wp_attachment_pages_enabled' ),
			)
		);

		foreach ( $post_types as $type ) {
			$index_name  = 'diagnoseo_' . esc_attr( $type->name ) . '_index';
			$follow_name = 'diagnoseo_' . esc_attr( $type->name ) . '_follow';
			add_option( $index_name, 'index' );
			register_setting(
				$this->option_group,
				$index_name,
				array(
					'type'              => 'string',
					'sanitize_callback' => 'sanitize_text_field',
					'show_in_rest'      => true,
					'default'           => 'index',
				)
			);
			add_option( $follow_name, 'follow' );
			register_setting(
				$this->option_group,
				$follow_name,
				array(
					'type'              => 'string',
					'sanitize_callback' => 'sanitize_text_field',
					'show_in_rest'      => true,
					'default'           => 'follow',
				)
			);
		}

		add_option( 'diagnoseo_author_index', 'index' );
		register_setting(
			$this->option_group,
			'diagnoseo_author_index',
			array(
				'type'              => 'string',
				'sanitize_callback' => 'sanitize_text_field',
				'show_in_rest'      => true,
				'default'           => 'index',
			)
		);
		add_option( 'diagnoseo_author_follow', 'follow' );
		register_setting(
			$this->option_group,
			'diagnoseo_author_follow',
			array(
				'type'              => 'string',
				'sanitize_callback' => 'sanitize_text_field',
				'show_in_rest'      => true,
				'default'           => 'follow',
			)
		);
		add_option( 'diagnoseo_tag_index', 'index' );
		register_setting(
			$this->option_group,
			'diagnoseo_tag_index',
			array(
				'type'              => 'string',
				'sanitize_callback' => 'sanitize_text_field',
				'show_in_rest'      => true,
				'default'           => 'index',
			)
		);
		add_option( 'diagnoseo_tag_follow', 'follow' );
		register_setting(
			$this->option_group,
			'diagnoseo_tag_follow',
			array(
				'type'              => 'string',
				'sanitize_callback' => 'sanitize_text_field',
				'show_in_rest'      => true,
				'default'           => 'follow',
			)
		);

		add_option( 'diagnoseo_date_archive_index', 'noindex' );
		register_setting(
			$this->option_group,
			'diagnoseo_date_archive_index',
			array(
				'type'              => 'string',
				'sanitize_callback' => 'sanitize_text_field',
				'show_in_rest'      => true,
				'default'           => 'noindex',
			)
		);
		add_option( 'diagnoseo_date_archive_follow', 'follow' );
		register_setting(
			$this->option_group,
			'diagnoseo_date_archive_follow',
			array(
				'type'              => 'string',
				'sanitize_callback' => 'sanitize_text_field',
				'show_in_rest'      => true,
				'default'           => 'follow',
			)
		);
		add_option( 'diagnoseo_archive_index', 'index' );
		register_setting(
			$this->option_group,
			'diagnoseo_archive_index',
			array(
				'type'              => 'string',
				'sanitize_callback' => 'sanitize_text_field',
				'show_in_rest'      => true,
				'default'           => 'index',
			)
		);
		add_option( 'diagnoseo_archive_follow', 'follow' );
		register_setting(
			$this->option_group,
			'diagnoseo_archive_follow',
			array(
				'type'              => 'string',
				'sanitize_callback' => 'sanitize_text_field',
				'show_in_rest'      => true,
				'default'           => 'follow',
			)
		);
		add_option( 'diagnoseo_fix_category_url_base', false );
		register_setting(
			$this->option_group,
			'diagnoseo_fix_category_url_base',
			array(
				'type'        => 'boolean',
				'description' => __( 'Remove "/category/" from category links', 'diagnoseo' ),
				'default'     => false,
			)
		);

		add_option( 'diagnoseo_sitemap_lastmod', true );
		register_setting(
			$this->option_group,
			'diagnoseo_sitemap_lastmod',
			array(
				'type'        => 'boolean',
				'description' => __( 'Add post last modified date to WP sitemap', 'diagnoseo' ),
				'default'     => true,
			)
		);

		if ( class_exists( 'WooCommerce' ) ) {
			add_option( 'diagnoseo_fix_product_cat_url_base', false );
			register_setting(
				$this->option_group,
				'diagnoseo_fix_product_cat_url_base',
				array(
					'type'        => 'boolean',
					'description' => __( 'Remove "/product-category/" from category links', 'diagnoseo' ),
					'default'     => false,
				)
			);
		}

		do_action( 'diagnoseo_register_general_options' );
	}
}
