<?php
/**
 * Metatag settings
 *
 * @package DiagnoSEO
 */

if ( ! defined( 'ABSPATH' ) ) {
	die;
}
/**
 * Meta tag settings page
 */
class Diagnoseo_MetaTagSettings {

	/**
	 * Allowed option html
	 *
	 * @var $options_allowed
	 */
	public $options_allowed = array(
		'option' => array(
			'value' => array(),
		),
	);

	/**
	 * Default option values
	 *
	 * @var $defaults
	 */
	public $defaults = array();

	/**
	 * Hooks actions on object creation
	 *
	 * @param Array $defaults Associative array of default option values.
	 */
	public function __construct( $defaults ) {
		add_action( 'admin_init', array( $this, 'register_settings' ) );
		$this->defaults = $defaults;
	}

	/**
	 * Renders the meta tag settings page
	 */
	public function render() {

		$title_vars         = array(
			'<option value="">' . __( 'Select variable', 'diagnoseo' ) . '</option>',
			'<option value="%sep%">' . __( 'Separator', 'diagnoseo' ) . '</option>',
			'<option value="%title%">' . __( 'Post/page title', 'diagnoseo' ) . '</option>',
			'<option value="%page%">' . __( 'Page number', 'diagnoseo' ) . '</option>',
			'<option value="%sitename%">' . __( 'Site title', 'diagnoseo' ) . '</option>',
			'<option value="%tagline%">' . __( 'Tagline', 'diagnoseo' ) . '</option>',
			'<option value="%currentyear%">' . __( 'Current year', 'diagnoseo' ) . '</option>',
			'<option value="%currentmonth%">' . __( 'Current month', 'diagnoseo' ) . '</option>',
		);
		$archive_title_vars = array(
			'<option value="">' . __( 'Select variable', 'diagnoseo' ) . '</option>',
			'<option value="%sep%">' . __( 'Separator', 'diagnoseo' ) . '</option>',
			'<option value="%title%">' . __( 'Category/tag name', 'diagnoseo' ) . '</option>',
			'<option value="%page%">' . __( 'Page number', 'diagnoseo' ) . '</option>',
			'<option value="%sitename%">' . __( 'Site title', 'diagnoseo' ) . '</option>',
			'<option value="%tagline%">' . __( 'Tagline', 'diagnoseo' ) . '</option>',
			'<option value="%currentyear%">' . __( 'Current year', 'diagnoseo' ) . '</option>',
			'<option value="%currentmonth%">' . __( 'Current month', 'diagnoseo' ) . '</option>',
		);
		$date_title_vars    = array(
			'<option value="">' . __( 'Select variable', 'diagnoseo' ) . '</option>',
			'<option value="%sep%">' . __( 'Separator', 'diagnoseo' ) . '</option>',
			'<option value="%date%">' . __( 'Date', 'diagnoseo' ) . '</option>',
			'<option value="%title%">' . __( 'Archive title', 'diagnoseo' ) . '</option>',
			'<option value="%page%">' . __( 'Page number', 'diagnoseo' ) . '</option>',
			'<option value="%sitename%">' . __( 'Site title', 'diagnoseo' ) . '</option>',
			'<option value="%tagline%">' . __( 'Tagline', 'diagnoseo' ) . '</option>',
		);

		$descr_vars         = array(
			'<option value="">' . __( 'Select variable', 'diagnoseo' ) . '</option>',
			'<option value="%excerpt%">' . __( 'Excerpt', 'diagnoseo' ) . '</option>',
			'<option value="%sep%">' . __( 'Separator', 'diagnoseo' ) . '</option>',
			'<option value="%title%">' . __( 'Post/page title', 'diagnoseo' ) . '</option>',
			'<option value="%sitename%">' . __( 'Site title', 'diagnoseo' ) . '</option>',
			'<option value="%tagline%">' . __( 'Tagline', 'diagnoseo' ) . '</option>',
			'<option value="%currentyear%">' . __( 'Current year', 'diagnoseo' ) . '</option>',
			'<option value="%currentmonth%">' . __( 'Current month', 'diagnoseo' ) . '</option>',
		);
		$archive_descr_vars = array(
			'<option value="">' . __( 'Select variable', 'diagnoseo' ) . '</option>',
			'<option value="%excerpt%">' . __( 'Category description', 'diagnoseo' ) . '</option>',
			'<option value="%sep%">' . __( 'Separator', 'diagnoseo' ) . '</option>',
			'<option value="%title%">' . __( 'Category/tag name', 'diagnoseo' ) . '</option>',
			'<option value="%sitename%">' . __( 'Site title', 'diagnoseo' ) . '</option>',
			'<option value="%tagline%">' . __( 'Tagline', 'diagnoseo' ) . '</option>',
			'<option value="%currentyear%">' . __( 'Current year', 'diagnoseo' ) . '</option>',
			'<option value="%currentmonth%">' . __( 'Current month', 'diagnoseo' ) . '</option>',
		);
		$date_descr_vars    = array(
			'<option value="">' . __( 'Select variable', 'diagnoseo' ) . '</option>',
			'<option value="%sep%">' . __( 'Separator', 'diagnoseo' ) . '</option>',
			'<option value="%date%">' . __( 'Date', 'diagnoseo' ) . '</option>',
			'<option value="%title%">' . __( 'Archive title', 'diagnoseo' ) . '</option>',
			'<option value="%sitename%">' . __( 'Site title', 'diagnoseo' ) . '</option>',
			'<option value="%tagline%">' . __( 'Tagline', 'diagnoseo' ) . '</option>',
		);
		?>
		<div class="wrap">
			<h1><?php esc_html_e( 'Meta Tag Options', 'diagnoseo' ); ?></h1>
			<form method="post" action="options.php" class="diagnoseo-settings-form">
			<?php
			settings_fields( 'diagnoseo_metatag_options' );
			do_settings_sections( 'diagnoseo_metatag_options' );
			?>
				<div class="diagnoseo-settings-section">
					<div class="diagnoseo-settings">
						<h2><?php esc_html_e( 'Separator', 'diagnoseo' ); ?></h2>
						<p><?php esc_html_e( 'A character or short string that separates parts of meta tag content', 'diagnoseo' ); ?></p>
						<table class="form-table" role="presentation">
							<tbody>
								<tr>
									<th><label for="diagnoseo_separator"><?php esc_html_e( 'Separator', 'diagnoseo' ); ?></label></th>
									<td class="meta-template">
										<input type="text" id="diagnoseo_separator" name="diagnoseo_separator" value="<?php echo esc_attr( get_option( 'diagnoseo_separator', $this->defaults['diagnoseo_separator'] ) ); ?>" class="small-text" />
									</td>
								</tr>
							</tbody>
						</table>
					</div>
				</div>
				<div class="diagnoseo-settings-section">
					<div class="diagnoseo-settings">
						<h2><?php esc_html_e( 'Home page meta tags', 'diagnoseo' ); ?></h2>
						<p><?php esc_html_e( 'May be overwritten by settings of the page set as home page.', 'diagnoseo' ); ?></p>
						<table class="form-table" role="presentation">
							<tbody>
								<tr>
									<th><label for="diagnoseo_home_title"><?php esc_html_e( 'Home page title', 'diagnoseo' ); ?></label></th>
									<td class="meta-template">
										<input type="text" id="diagnoseo_home_title" name="diagnoseo_home_title" value="<?php echo esc_attr( get_option( 'diagnoseo_home_title', $this->defaults['diagnoseo_home_title'] ) ); ?>" placeholder="<?php echo esc_attr( $this->defaults['diagnoseo_home_title'] ); ?>" class="regular-text" />
										<select class="choose-variable"><?php echo wp_kses( implode( ' ', $title_vars ), $this->options_allowed ); ?></select> <button class="button button-secondary add-variable"><?php esc_html_e( 'Insert', 'diagnoseo' ); ?>
									</td>
								</tr>
								<tr>
									<th><label for="diagnoseo_post_description_template"><?php esc_html_e( 'Home page description', 'diagnoseo' ); ?></label></th>
									<td class="meta-template">
										<textarea id="diagnoseo_home_description" name="diagnoseo_home_description" rows="6" class="regular-text"><?php echo esc_html( get_option( 'diagnoseo_home_description', $this->defaults['diagnoseo_home_description'] ) ); ?></textarea>
										<select class="choose-variable"><?php echo wp_kses( implode( '', $descr_vars ), $this->options_allowed ); ?></select> <button class="button button-secondary add-variable"><?php esc_html_e( 'Insert', 'diagnoseo' ); ?>
									</td>
								</tr>
							</tbody>
						</table>

					</div>
					<?php
					$front_id       = get_option( 'page_on_front' );
					$post           = empty( $front_id ) ? null : get_post( $front_id );
					$post_title     = empty( $post ) ? '' : get_the_title( $post );
					$title_fallback = empty( $post_title ) ? $this->defaults['diagnoseo_home_title'] : $post_title . ' - ' . get_bloginfo( 'name' );
					$excerpt        = empty( $post ) ? '' : get_the_excerpt( $post );
					if ( empty( $excerpt ) ) {
						$words   = explode( ' ', empty( $post ) ? '' : wp_strip_all_tags( $post->post_content ) );
						$words   = array_splice( $words, 0, 55 );
						$excerpt = implode( ' ', $words );
					}
					$canonical_fallback   = get_home_url( '/' );
					$title                = get_option( 'diagnoseo_home_title', $this->defaults['diagnoseo_home_title'] );
					$description          = get_option( 'diagnoseo_home_description', $this->defaults['diagnoseo_home_description'] );
					$preview_title        = empty( $title ) ? $title_fallback : $title;
					$preview_descr        = empty( $description ) ? $excerpt : $description;
					$remove_category_base = get_option( 'diagnoseo_fix_category_url_base' );
					$separator            = get_option( 'diagnoseo_separator', $this->defaults['diagnoseo_separator'] );
					?>
					<div class="diagnoseo-preview" data-excerpt="<?php echo esc_attr( $excerpt ); ?>" data-separator="<?php echo esc_attr( $separator ); ?>" data-post-title="<?php echo esc_attr( $post_title ); ?>" data-site="<?php echo esc_attr( get_bloginfo( 'name' ) ); ?>" data-site-tagline="<?php echo esc_attr( get_bloginfo( 'description' ) ); ?>">
						<h4><?php esc_html_e( 'Desktop Snippet Preview', 'diagnoseo' ); ?></h4>
						<div class="search-results">
							<div class="search-result">
								<div class="search-result-url"><?php echo wp_kses_post( diagnoseo_canonical_preview( $canonical_fallback ) ); ?></div>
								<div class="search-result-title" data-fallback="<?php echo esc_attr( $title_fallback ); ?>"><?php echo esc_html( $preview_title ); ?></div>
								<div class="search-result-descr" data-fallback="<?php echo esc_attr( $excerpt ); ?>"><?php echo esc_html( diagnoseo_truncate_text( $preview_descr, 158 ) ); ?></div>
							</div>
							<div class="text-measuring">
								<div class="title-sample"><?php echo esc_html( $preview_title ); ?></div>
								<div class="description-sample"><?php echo esc_html( $preview_descr ); ?></div>
							</div>
						</div>
						<h4><?php esc_html_e( 'Mobile Snippet Preview', 'diagnoseo' ); ?></h4>
						<div class="search-results">
							<div class="search-result mobile">
								<div class="search-result-url"><img src="<?php echo esc_url( DIAGNOSEO_PLUGIN_URL ); ?>/assets/favicon.png" class="url-icon" width="16" height="16" /><?php echo wp_kses_post( diagnoseo_canonical_preview( $canonical_fallback ) ); ?></div>
								<div class="search-result-title" data-fallback="<?php echo esc_attr( $title_fallback ); ?>"><?php echo esc_html( $preview_title ); ?></div>
								<div class="search-result-descr" data-fallback="<?php echo esc_attr( $excerpt ); ?>"><?php echo esc_html( diagnoseo_truncate_text( $preview_descr, 158 ) ); ?></div>
							</div>
						</div>
					</div>
				</div>

				<div class="diagnoseo-settings-section meta-patterns">
					<div class="diagnoseo-settings">
						<h2><?php esc_html_e( 'Posts', 'diagnoseo' ); ?></h2>
						<p><?php esc_html_e( 'May be overwritten by post settings.', 'diagnoseo' ); ?></p>
						<table class="form-table" role="presentation">
							<tbody>
								<tr>
									<th><label for="diagnoseo_post_title_template"><?php esc_html_e( 'Title tag', 'diagnoseo' ); ?></label></th>
									<td class="meta-template">
										<input type="text" id="diagnoseo_post_title_template" name="diagnoseo_post_title_template" value="<?php echo esc_attr( get_option( 'diagnoseo_post_title_template', $this->defaults['diagnoseo_post_title_template'] ) ); ?>" class="regular-text" />
										<select class="choose-variable"><?php echo wp_kses( implode( ' ', $title_vars ), $this->options_allowed ); ?></select> <button class="button button-secondary add-variable"><?php esc_html_e( 'Insert', 'diagnoseo' ); ?>
									</td>
								</tr>
								<tr>
									<th><label for="diagnoseo_post_description_template"><?php esc_html_e( 'Meta description', 'diagnoseo' ); ?></label></th>
									<td class="meta-template">
										<textarea id="diagnoseo_post_description_template" name="diagnoseo_post_description_template" rows="3" class="regular-text"><?php echo esc_textarea( get_option( 'diagnoseo_post_description_template', $this->defaults['diagnoseo_post_description_template'] ) ); ?></textarea>
										<select class="choose-variable"><?php echo wp_kses( implode( '', $descr_vars ), $this->options_allowed ); ?></select> <button class="button button-secondary add-variable"><?php esc_html_e( 'Insert', 'diagnoseo' ); ?>
									</td>
								</tr>
							</tbody>
						</table>
					</div>
					<div class="diagnoseo-settings">
						<h2><?php esc_html_e( 'Pages', 'diagnoseo' ); ?></h2>
						<p><?php esc_html_e( 'May be overwritten by page settings.', 'diagnoseo' ); ?></p>
						<table class="form-table" role="presentation">
							<tbody>
								<tr>
									<th><label for="diagnoseo_page_title_template"><?php esc_html_e( 'Title tag', 'diagnoseo' ); ?></label></th>
									<td class="meta-template">
										<input type="text" id="diagnoseo_page_title_template" name="diagnoseo_page_title_template" value="<?php echo esc_attr( get_option( 'diagnoseo_page_title_template', $this->defaults['diagnoseo_page_title_template'] ) ); ?>" class="regular-text" />
										<select class="choose-variable"><?php echo wp_kses( implode( ' ', $title_vars ), $this->options_allowed ); ?></select> <button class="button button-secondary add-variable"><?php esc_html_e( 'Insert', 'diagnoseo' ); ?>
									</td>
								</tr>
								<tr>
									<th><label for="diagnoseo_page_description_template"><?php esc_html_e( 'Meta description', 'diagnoseo' ); ?></label></th>
									<td class="meta-template">
										<textarea id="diagnoseo_page_description_template" name="diagnoseo_page_description_template" rows="3" class="regular-text"><?php echo esc_textarea( get_option( 'diagnoseo_page_description_template', $this->defaults['diagnoseo_page_description_template'] ) ); ?></textarea>
										<select class="choose-variable"><?php echo wp_kses( implode( '', $descr_vars ), $this->options_allowed ); ?></select> <button class="button button-secondary add-variable"><?php esc_html_e( 'Insert', 'diagnoseo' ); ?>
									</td>
								</tr>
							</tbody>
						</table>
					</div>
					<div class="diagnoseo-settings">
						<h2><?php esc_html_e( 'Categories', 'diagnoseo' ); ?></h2>
						<table class="form-table" role="presentation">
							<tbody>
								<tr>
									<th><label for="diagnoseo_category_title_template"><?php esc_html_e( 'Title tag', 'diagnoseo' ); ?></label></th>
									<td class="meta-template">
										<input type="text" id="diagnoseo_category_title_template" name="diagnoseo_category_title_template" value="<?php echo esc_attr( get_option( 'diagnoseo_category_title_template', $this->defaults['diagnoseo_category_title_template'] ) ); ?>" class="regular-text" />
										<select class="choose-variable"><?php echo wp_kses( implode( '', $archive_title_vars ), $this->options_allowed ); ?></select> <button class="button button-secondary add-variable"><?php esc_html_e( 'Insert', 'diagnoseo' ); ?>
									</td>
								</tr>
								<tr>
									<th><label for="diagnoseo_category_description_template"><?php esc_html_e( 'Meta description', 'diagnoseo' ); ?></label></th>
									<td class="meta-template">
										<textarea id="diagnoseo_category_description_template" name="diagnoseo_category_description_template" rows="3" class="regular-text"><?php echo esc_textarea( get_option( 'diagnoseo_category_description_template', $this->defaults['diagnoseo_category_description_template'] ) ); ?></textarea>
										<select class="choose-variable"><?php echo wp_kses( implode( '', $archive_descr_vars ), $this->options_allowed ); ?></select> <button class="button button-secondary add-variable"><?php esc_html_e( 'Insert', 'diagnoseo' ); ?>
									</td>
								</tr>
							</tbody>
						</table>
					</div>
					<div class="diagnoseo-settings">
						<h2><?php esc_html_e( 'Tags', 'diagnoseo' ); ?></h2>
						<table class="form-table" role="presentation">
							<tbody>
								<tr>
									<th><label for="diagnoseo_archive_title_template"><?php esc_html_e( 'Title tag', 'diagnoseo' ); ?></label></th>
									<td class="meta-template">
										<input type="text" id="diagnoseo_archive_title_template" name="diagnoseo_archive_title_template" value="<?php echo esc_html( get_option( 'diagnoseo_archive_title_template', $this->defaults['diagnoseo_archive_title_template'] ) ); ?>" class="regular-text" />
										<select class="choose-variable"><?php echo wp_kses( implode( '', $archive_title_vars ), $this->options_allowed ); ?></select> <button class="button button-secondary add-variable"><?php esc_html_e( 'Insert', 'diagnoseo' ); ?>
									</td>
								</tr>
								<tr>
									<th><label for="diagnoseo_archive_description_template"><?php esc_html_e( 'Meta description', 'diagnoseo' ); ?></label></th>
									<td class="meta-template">
										<textarea id="diagnoseo_archive_description_template" name="diagnoseo_archive_description_template" rows="3" class="regular-text"><?php echo esc_textarea( get_option( 'diagnoseo_archive_description_template', $this->defaults['diagnoseo_archive_description_template'] ) ); ?></textarea>
										<select class="choose-variable"><?php echo wp_kses( implode( '', $archive_descr_vars ), $this->options_allowed ); ?></select> <button class="button button-secondary add-variable"><?php esc_html_e( 'Insert', 'diagnoseo' ); ?>
									</td>
								</tr>
							</tbody>
						</table>
					</div>
					<div class="diagnoseo-settings">
						<h2><?php esc_html_e( 'Date archives', 'diagnoseo' ); ?></h2>
						<table class="form-table" role="presentation">
							<tbody>
								<tr>
									<th><label for="diagnoseo_date_title_template"><?php esc_html_e( 'Title tag', 'diagnoseo' ); ?></label></th>
									<td class="meta-template">
										<input type="text" id="diagnoseo_date_title_template" name="diagnoseo_date_title_template" value="<?php echo esc_html( get_option( 'diagnoseo_date_title_template', $this->defaults['diagnoseo_date_title_template'] ) ); ?>" class="regular-text" />
										<select class="choose-variable"><?php echo wp_kses( implode( '', $date_title_vars ), $this->options_allowed ); ?></select> <button class="button button-secondary add-variable"><?php esc_html_e( 'Insert', 'diagnoseo' ); ?>
									</td>
								</tr>
								<tr>
									<th><label for="diagnoseo_date_description_template"><?php esc_html_e( 'Meta description', 'diagnoseo' ); ?></label></th>
									<td class="meta-template">
										<textarea id="diagnoseo_date_description_template" name="diagnoseo_date_description_template" rows="3" class="regular-text"><?php echo esc_textarea( get_option( 'diagnoseo_date_description_template', $this->defaults['diagnoseo_date_description_template'] ) ); ?></textarea>
										<select class="choose-variable"><?php echo wp_kses( implode( '', $date_descr_vars ), $this->options_allowed ); ?></select> <button class="button button-secondary add-variable"><?php esc_html_e( 'Insert', 'diagnoseo' ); ?>
									</td>
								</tr>
							</tbody>
						</table>
					</div>
					<div class="diagnoseo-settings">
						<h2><?php esc_html_e( 'Archives', 'diagnoseo' ); ?></h2>
						<table class="form-table" role="presentation">
							<tbody>
								<tr>
									<th><label for="diagnoseo_archive_title_template"><?php esc_html_e( 'Title tag', 'diagnoseo' ); ?></label></th>
									<td class="meta-template">
										<input type="text" id="diagnoseo_archive_title_template" name="diagnoseo_archive_title_template" value="<?php echo esc_html( get_option( 'diagnoseo_archive_title_template', $this->defaults['diagnoseo_archive_title_template'] ) ); ?>" class="regular-text" />
										<select class="choose-variable"><?php echo wp_kses( implode( '', $archive_title_vars ), $this->options_allowed ); ?></select> <button class="button button-secondary add-variable"><?php esc_html_e( 'Insert', 'diagnoseo' ); ?>
									</td>
								</tr>
								<tr>
									<th><label for="diagnoseo_archive_description_template"><?php esc_html_e( 'Meta description', 'diagnoseo' ); ?></label></th>
									<td class="meta-template">
										<textarea id="diagnoseo_archive_description_template" name="diagnoseo_archive_description_template" rows="3" class="regular-text"><?php echo esc_textarea( get_option( 'diagnoseo_archive_description_template', $this->defaults['diagnoseo_archive_description_template'] ) ); ?></textarea>
										<select class="choose-variable"><?php echo wp_kses( implode( '', $archive_descr_vars ), $this->options_allowed ); ?></select> <button class="button button-secondary add-variable"><?php esc_html_e( 'Insert', 'diagnoseo' ); ?>
									</td>
								</tr>
							</tbody>
						</table>
					</div>

					<?php if ( class_exists( 'MultiBuilder' ) ) : ?>

						<div class="diagnoseo-settings">
							<h2><?php esc_html_e( 'Projects', 'diagnoseo' ); ?></h2>
							<p><?php esc_html_e( 'May be overwritten by project settings.', 'diagnoseo' ); ?></p>
							<table class="form-table" role="presentation">
								<tbody>
									<tr>
										<th><label for="diagnoseo_project_title_template"><?php esc_html_e( 'Title tag', 'diagnoseo' ); ?></label></th>
										<td class="meta-template">
											<input type="text" id="diagnoseo_project_title_template" name="diagnoseo_project_title_template" value="<?php echo esc_attr( get_option( 'diagnoseo_project_title_template', $this->defaults['diagnoseo_project_title_template'] ) ); ?>" class="regular-text" />
											<select class="choose-variable"><?php echo wp_kses( implode( ' ', $title_vars ), $this->options_allowed ); ?></select> <button class="button button-secondary add-variable"><?php esc_html_e( 'Insert', 'diagnoseo' ); ?>
										</td>
									</tr>
									<tr>
										<th><label for="diagnoseo_project_description_template"><?php esc_html_e( 'Meta description', 'diagnoseo' ); ?></label></th>
										<td class="meta-template">
											<textarea id="diagnoseo_project_description_template" name="diagnoseo_project_description_template" rows="3" class="regular-text"><?php echo esc_textarea( get_option( 'diagnoseo_project_description_template', $this->defaults['diagnoseo_project_description_template'] ) ); ?></textarea>
											<select class="choose-variable"><?php echo wp_kses( implode( '', $descr_vars ), $this->options_allowed ); ?></select> <button class="button button-secondary add-variable"><?php esc_html_e( 'Insert', 'diagnoseo' ); ?>
										</td>
									</tr>
								</tbody>
							</table>
						</div>
						<div class="diagnoseo-settings">
							<h2><?php esc_html_e( 'Project categories', 'diagnoseo' ); ?></h2>
							<table class="form-table" role="presentation">
								<tbody>
									<tr>
										<th><label for="diagnoseo_project_category_title_template"><?php esc_html_e( 'Title tag', 'diagnoseo' ); ?></label></th>
										<td class="meta-template">
											<input type="text" id="diagnoseo_project_category_title_template" name="diagnoseo_project_category_title_template" value="<?php echo esc_attr( get_option( 'diagnoseo_project_category_title_template', $this->defaults['diagnoseo_project_category_title_template'] ) ); ?>" class="regular-text" />
											<select class="choose-variable"><?php echo wp_kses( implode( '', $descr_vars ), $this->options_allowed ); ?></select> <button class="button button-secondary add-variable"><?php esc_html_e( 'Insert', 'diagnoseo' ); ?>
										</td>
									</tr>
									<tr>
										<th><label for="diagnoseo_project_category_description_template"><?php esc_html_e( 'Meta description', 'diagnoseo' ); ?></label></th>
										<td class="meta-template">
											<textarea id="diagnoseo_project_category_description_template" name="diagnoseo_project_category_description_template" rows="3" class="regular-text"><?php echo esc_textarea( get_option( 'diagnoseo_project_category_description_template', $this->defaults['diagnoseo_project_category_description_template'] ) ); ?></textarea>
											<select class="choose-variable"><?php echo wp_kses( implode( '', $archive_descr_vars ), $this->options_allowed ); ?></select> <button class="button button-secondary add-variable"><?php esc_html_e( 'Insert', 'diagnoseo' ); ?>
										</td>
									</tr>
								</tbody>
							</table>
						</div>

					<?php endif; ?>

					<?php do_action( 'diagnoseo_render_meta_options' ); ?>

					<?php if ( class_exists( 'WooCommerce' ) && ! function_exists( 'diagnoseo_pro_init' ) ) : ?>
					<div class="diagnoseo-settings in-pro">
						<h2><?php esc_html_e( 'Products', 'diagnoseo' ); ?> (<a href="https://diagnoseo.com/wordpress-seo-plugin/?utm_source=wp&utm_medium=link&utm_campaign=available_in_pro" target="_blank" rel="noreferrer noopener"><?php esc_html_e( 'Available in Pro', 'diagnoseo' ); ?></a>)</h2>
						<p><?php esc_html_e( 'May be overwritten by post settings.', 'diagnoseo' ); ?></p>
						<table class="form-table" role="presentation">
							<tbody>
								<tr>
									<th><label for="diagnoseo_product_title_template"><?php esc_html_e( 'Title tag', 'diagnoseo' ); ?></label></th>
									<td class="meta-template">
										<input disabled type="text" id="diagnoseo_product_title_template" name="diagnoseo_product_title_template" value="<?php echo esc_attr( get_option( 'diagnoseo_product_title_template' ) ); ?>" class="regular-text" />
										<select disabled class="choose-variable"><?php echo wp_kses( implode( ' ', $title_vars ), $this->options_allowed ); ?></select> <button disabled class="button button-secondary add-variable-pro"><?php esc_html_e( 'Insert', 'diagnoseo' ); ?>
									</td>
								</tr>
								<tr>
									<th><label for="diagnoseo_product_description_template"><?php esc_html_e( 'Meta description', 'diagnoseo' ); ?></label></th>
									<td class="meta-template">
										<textarea disabled id="diagnoseo_product_description_template" name="diagnoseo_product_description_template" rows="3" class="regular-text"><?php echo esc_textarea( get_option( 'diagnoseo_product_description_template' ) ); ?></textarea>
										<select disabled class="choose-variable"><?php echo wp_kses( implode( '', $descr_vars ), $this->options_allowed ); ?></select> <button disabled class="button button-secondary add-variable-pro"><?php esc_html_e( 'Insert', 'diagnoseo' ); ?>
									</td>
								</tr>
							</tbody>
						</table>
					</div>
					<div class="diagnoseo-settings in-pro">
						<h2><?php esc_html_e( 'Product Categories', 'diagnoseo' ); ?> (<a href="https://diagnoseo.com/wordpress-seo-plugin/?utm_source=wp&utm_medium=link&utm_campaign=available_in_pro" target="_blank" rel="noreferrer noopener"><?php esc_html_e( 'Available in Pro', 'diagnoseo' ); ?></a>)</h2>
						<table class="form-table" role="presentation">
							<tbody>
								<tr>
									<th><label for="diagnoseo_product_category_title_template"><?php esc_html_e( 'Title tag', 'diagnoseo' ); ?></label></th>
									<td class="meta-template">
										<input disabled type="text" id="diagnoseo_product_category_title_template" name="diagnoseo_product_category_title_template" value="<?php echo esc_attr( get_option( 'diagnoseo_product_category_title_template' ) ); ?>" class="regular-text" />
										<select disabled class="choose-variable"><?php echo wp_kses( implode( '', $descr_vars ), $this->options_allowed ); ?></select> <button disabled class="button button-secondary add-variable-pro"><?php esc_html_e( 'Insert', 'diagnoseo' ); ?>
									</td>
								</tr>
								<tr>
									<th><label for="diagnoseo_product_category_description_template"><?php esc_html_e( 'Meta description', 'diagnoseo' ); ?></label></th>
									<td class="meta-template">
										<textarea disabled id="diagnoseo_product_category_description_template" name="diagnoseo_product_category_description_template" rows="3" class="regular-text"><?php echo esc_textarea( get_option( 'diagnoseo_product_category_description_template' ) ); ?></textarea>
										<select disabled class="choose-variable"><?php echo wp_kses( implode( '', $archive_descr_vars ), $this->options_allowed ); ?></select> <button disabled class="button button-secondary add-variable-pro"><?php esc_html_e( 'Insert', 'diagnoseo' ); ?>
									</td>
								</tr>
							</tbody>
						</table>
					</div>
					<div class="diagnoseo-settings in-pro">
						<h2><?php esc_html_e( 'Product Tags', 'diagnoseo' ); ?> (<a href="https://diagnoseo.com/wordpress-seo-plugin/?utm_source=wp&utm_medium=link&utm_campaign=available_in_pro" target="_blank" rel="noreferrer noopener"><?php esc_html_e( 'Available in Pro', 'diagnoseo' ); ?></a>)</h2>
						<table class="form-table" role="presentation">
							<tbody>
								<tr>
									<th><label for="diagnoseo_product_tag_title_template"><?php esc_html_e( 'Title tag', 'diagnoseo' ); ?></label></th>
									<td class="meta-template">
										<?php $def_poduct_tag_title_template = empty( $this->defaults['diagnoseo_product_tag_title_template'] ) ? '' : $this->defaults['diagnoseo_product_tag_title_template']; ?>
										<input disabled type="text" id="diagnoseo_product_tag_title_template" name="diagnoseo_product_tag_title_template" value="<?php echo esc_attr( get_option( 'diagnoseo_product_tag_title_template', $def_poduct_tag_title_template ) ); ?>" class="regular-text" />
										<select disabled class="choose-variable"><?php echo wp_kses( implode( '', $descr_vars ), $this->options_allowed ); ?></select> <button disabled class="button button-secondary add-variable-pro"><?php esc_html_e( 'Insert', 'diagnoseo' ); ?>
									</td>
								</tr>
								<tr>
									<th><label for="diagnoseo_product_tag_description_template"><?php esc_html_e( 'Meta description', 'diagnoseo' ); ?></label></th>
									<td class="meta-template">
									<?php $def_poduct_tag_description_template = empty( $this->defaults['diagnoseo_product_tag_description_template'] ) ? '' : $this->defaults['diagnoseo_product_tag_description_template']; ?>
										<textarea disabled id="diagnoseo_product_tag_description_template" name="diagnoseo_product_tag_description_template" rows="3" class="regular-text"><?php echo esc_textarea( get_option( 'diagnoseo_product_tag_description_template', $def_poduct_tag_description_template ) ); ?></textarea>
										<select disabled class="choose-variable"><?php echo wp_kses( implode( '', $archive_descr_vars ), $this->options_allowed ); ?></select> <button disabled class="button button-secondary add-variable-pro"><?php esc_html_e( 'Insert', 'diagnoseo' ); ?>
									</td>
								</tr>
							</tbody>
						</table>
					</div>
					<?php endif; ?>
					<?php if ( ! function_exists( 'diagnoseo_pro_init' ) ) : ?>
						<div class="diagnoseo-settings in-pro">
							<h2><?php esc_html_e( 'Meta referrer tag', 'diagnoseo' ); ?> (<a href="https://diagnoseo.com/wordpress-seo-plugin/?utm_source=wp&utm_medium=link&utm_campaign=available_in_pro" target="_blank" rel="noreferrer noopener"><?php esc_html_e( 'Available in Pro', 'diagnoseo' ); ?></a>)</h2>
							<table class="form-table" role="presentation">
								<tbody>
									<tr>
										<th><label for="diagnoseo_meta_referrer"><?php esc_html_e( 'Meta referrer tag content', 'diagnoseo' ); ?></label></th>
										<td>
											<select name="diagnoseo_meta_referrer" id="diagnoseo_meta_referrer" disabled>
												<option value='' <?php selected( '', get_option( 'diagnoseo_meta_referrer' ) ); ?>><?php esc_html_e( 'Do not show', 'diagnoseo' ); ?></option>
												<option value='none' <?php selected( 'none', get_option( 'diagnoseo_meta_referrer' ) ); ?>>none</option>
												<option value='none-when-downgrade' <?php selected( 'none-when-downgrade', get_option( 'diagnoseo_meta_referrer' ) ); ?>>none-when-downgrade</option>
												<option value='origin' <?php selected( 'origin', get_option( 'diagnoseo_meta_referrer' ) ); ?>>origin</option>
												<option value='origin-when-crossorigin' <?php selected( 'origin-when-crossorigin', get_option( 'diagnoseo_meta_referrer' ) ); ?>>origin-when-crossorigin</option>
												<option value='unsafe-url' <?php selected( 'unsafe-url', get_option( 'diagnoseo_meta_referrer' ) ); ?>>unsafe-url</option>
											</select>
										</td>
									</tr>
								</tbody>
							</table>
						</div>
					<?php endif; ?>
				</div>
			<?php submit_button(); ?>
			</form>
		</div>
		<?php
	}

	/**
	 * Registers options for meta tags
	 */
	public function register_settings() {
		add_option( 'diagnoseo_separator', '-' );
		register_setting(
			'diagnoseo_metatag_options',
			'diagnoseo_separator',
			array(
				'type'              => 'string',
				'description'       => __( 'Meta tag part separator', 'diagnoseo' ),
				'sanitize_callback' => 'sanitize_text_field',
				'show_in_rest'      => true,
			)
		);

		add_option( 'diagnoseo_separator', '-' );
		register_setting(
			'diagnoseo_metatag_options',
			'diagnoseo_home_title',
			array(
				'type'              => 'string',
				'description'       => __( 'The title of the home page.', 'diagnoseo' ),
				'sanitize_callback' => 'sanitize_text_field',
				'show_in_rest'      => true,
			)
		);

		add_option( 'diagnoseo_home_description', '' );
		register_setting(
			'diagnoseo_metatag_options',
			'diagnoseo_home_description',
			array(
				'type'              => 'string',
				'description'       => __( 'The description meta tag of the home page.', 'diagnoseo' ),
				'sanitize_callback' => 'sanitize_text_field',
				'show_in_rest'      => true,
			)
		);

		add_option( 'diagnoseo_post_title_template', '' );
		register_setting(
			'diagnoseo_metatag_options',
			'diagnoseo_post_title_template',
			array(
				'type'              => 'string',
				'description'       => __( 'Post title template', 'diagnoseo' ),
				'sanitize_callback' => 'sanitize_text_field',
				'show_in_rest'      => true,
			)
		);

		add_option( 'diagnoseo_post_description_template', '' );
		register_setting(
			'diagnoseo_metatag_options',
			'diagnoseo_post_description_template',
			array(
				'type'              => 'string',
				'description'       => __( 'Post meta description template.', 'diagnoseo' ),
				'sanitize_callback' => 'sanitize_text_field',
				'show_in_rest'      => true,
			)
		);

		add_option( 'diagnoseo_page_title_template', '' );
		register_setting(
			'diagnoseo_metatag_options',
			'diagnoseo_page_title_template',
			array(
				'type'              => 'string',
				'description'       => __( 'Page title template', 'diagnoseo' ),
				'sanitize_callback' => 'sanitize_text_field',
				'show_in_rest'      => true,
			)
		);

		add_option( 'diagnoseo_page_description_template', '' );
		register_setting(
			'diagnoseo_metatag_options',
			'diagnoseo_page_description_template',
			array(
				'type'              => 'string',
				'description'       => __( 'Page meta description template.', 'diagnoseo' ),
				'sanitize_callback' => 'sanitize_text_field',
				'show_in_rest'      => true,
			)
		);

		add_option( 'diagnoseo_category_title_template', '' );
		register_setting(
			'diagnoseo_metatag_options',
			'diagnoseo_category_title_template',
			array(
				'type'              => 'string',
				'description'       => __( 'Category title template', 'diagnoseo' ),
				'sanitize_callback' => 'sanitize_text_field',
				'show_in_rest'      => true,
			)
		);

		add_option( 'diagnoseo_category_description_template', '' );
		register_setting(
			'diagnoseo_metatag_options',
			'diagnoseo_category_description_template',
			array(
				'type'              => 'string',
				'description'       => __( 'Category meta description template.', 'diagnoseo' ),
				'sanitize_callback' => 'sanitize_text_field',
				'show_in_rest'      => true,
			)
		);

		add_option( 'diagnoseo_tag_title_template', '' );
		register_setting(
			'diagnoseo_metatag_options',
			'diagnoseo_tag_title_template',
			array(
				'type'              => 'string',
				'description'       => __( 'Tag title template', 'diagnoseo' ),
				'sanitize_callback' => 'sanitize_text_field',
				'show_in_rest'      => true,
			)
		);

		add_option( 'diagnoseo_tag_description_template', '' );
		register_setting(
			'diagnoseo_metatag_options',
			'diagnoseo_tag_description_template',
			array(
				'type'              => 'string',
				'description'       => __( 'Tag meta description template.', 'diagnoseo' ),
				'sanitize_callback' => 'sanitize_text_field',
				'show_in_rest'      => true,
			)
		);

		add_option( 'diagnoseo_date_title_template', '' );
		register_setting(
			'diagnoseo_metatag_options',
			'diagnoseo_date_title_template',
			array(
				'type'              => 'string',
				'description'       => __( 'Date archive title template', 'diagnoseo' ),
				'sanitize_callback' => 'wp_strip_all_tags',
				'show_in_rest'      => true,
			)
		);

		add_option( 'diagnoseo_date_description_template', '' );
		register_setting(
			'diagnoseo_metatag_options',
			'diagnoseo_date_description_template',
			array(
				'type'              => 'string',
				'description'       => __( 'Date archive meta description template.', 'diagnoseo' ),
				'sanitize_callback' => 'wp_strip_all_tags',
				'show_in_rest'      => true,
			)
		);

		add_option( 'diagnoseo_archive_title_template', '' );
		register_setting(
			'diagnoseo_metatag_options',
			'diagnoseo_archive_title_template',
			array(
				'type'              => 'string',
				'description'       => __( 'Archive title template', 'diagnoseo' ),
				'sanitize_callback' => 'sanitize_text_field',
				'show_in_rest'      => true,
			)
		);

		add_option( 'diagnoseo_archive_description_template', '' );
		register_setting(
			'diagnoseo_metatag_options',
			'diagnoseo_archive_description_template',
			array(
				'type'              => 'string',
				'description'       => __( 'Archive meta description template.', 'diagnoseo' ),
				'sanitize_callback' => 'sanitize_text_field',
				'show_in_rest'      => true,
			)
		);

		if ( class_exists( 'MultiBuilder' ) ) {
			add_option( 'diagnoseo_project_title_template', '' );
			register_setting(
				'diagnoseo_metatag_options',
				'diagnoseo_project_title_template',
				array(
					'type'              => 'string',
					'description'       => __( 'Project title template', 'diagnoseo' ),
					'sanitize_callback' => 'sanitize_text_field',
					'show_in_rest'      => true,
				)
			);
			$this->defaults['diagnoseo_project_title_template'] = '%title% %sep% %sitename%';

			add_option( 'diagnoseo_project_description_template', '' );
			register_setting(
				'diagnoseo_metatag_options',
				'diagnoseo_project_description_template',
				array(
					'type'              => 'string',
					'description'       => __( 'Project meta description template.', 'diagnoseo' ),
					'sanitize_callback' => 'sanitize_text_field',
					'show_in_rest'      => true,
					'default'           => '',
				)
			);
			$this->defaults['diagnoseo_project_description_template'] = '';

			add_option( 'diagnoseo_project_category_title_template', '' );
			register_setting(
				'diagnoseo_metatag_options',
				'diagnoseo_project_category_title_template',
				array(
					'type'              => 'string',
					'description'       => __( 'Project category title template', 'diagnoseo' ),
					'sanitize_callback' => 'sanitize_text_field',
					'show_in_rest'      => true,
					'default'           => '%title% %sep% %sitename%',
				)
			);
			$this->defaults['diagnoseo_project_category_title_template'] = '%title% %sep% %sitename%';

			add_option( 'diagnoseo_project_category_description_template', '' );
			register_setting(
				'diagnoseo_metatag_options',
				'diagnoseo_project_category_description_template',
				array(
					'type'              => 'string',
					'description'       => __( 'Project category meta description template.', 'diagnoseo' ),
					'sanitize_callback' => 'sanitize_text_field',
					'show_in_rest'      => true,
					'default'           => '',
				)
			);
			$this->defaults['diagnoseo_project_category_description_template'] = '';
		}

		do_action( 'diagnoseo_register_meta_options' );
	}
}
