<?php
/**
 * Other SEO plugin detection
 *
 * @package DiagnoSEO
 */

if ( ! defined( 'ABSPATH' ) ) {
	die;
}

/**
 * Object that detects different SEO plugins and turns them off on demand.
 */
class Diagnoseo_PluginDetector {
	/**
	 * Active plugins list
	 *
	 * @var $active_pugins
	 */
	private static $active_plugins = array();

	/**
	 * Displays a warning or deactivates plugins
	 */
	public function __construct() {
		$this->detect_seo_plugins();
		if ( isset( $_GET['diagnoseo_deactivate_plugins'] ) ) {
			check_admin_referer( 'deactivate_other_seo_plugins' );
			$this->deactivate_plugins();
		} else {
			$this->check_warning_needed();
		}
	}

	/**
	 * Checks if any other SEO plugin is active
	 */
	private function detect_seo_plugins() {
		global $slim_seo;
		self::$active_plugins = array(
			'all-in-one-seo-pack/all_in_one_seo_pack.php' => function_exists( 'aioseo' ),
			'seo-by-rank-math/rank-math.php'              => class_exists( 'RankMath' ),
			'wp-seopress/seopress.php'                    => function_exists( 'seopress_init' ),
			'slim-seo/slim-seo.php'                       => ! empty( $slim_seo ) ? method_exists( $slim_seo, 'register_services' ) : false,
			'squirrly-seo/squirrly.php'                   => class_exists( 'SQ_Classes_ObjController' ),
			'autodescription/autodescription.php'         => function_exists( 'the_seo_framework_boot' ),
			'wordpress-seo/wp-seo.php'                    => function_exists( 'wpseo_auto_load' ),
		);
	}
	/**
	 * Displays appropriate warning
	 */
	private function check_warning_needed() {
		$plugins_found = false;
		foreach ( self::$active_plugins as $plugin => $active ) {
			if ( $active ) {
				$plugins_found = true;
			}
		}

		if ( ! $plugins_found ) {
			return;
		}

		add_action( 'admin_notices', array( $this, 'display_warning' ) );
	}

	/**
	 * Displays warning about other seo plugins
	 */
	public function display_warning() {
		$url = site_url() . '/wp-admin/plugins.php?diagnoseo_deactivate_plugins=1';
		$url = wp_nonce_url( $url, 'deactivate_other_seo_plugins' );

		$content  = __( 'Your rankings and traffic may drop if you use more than one SEO plugin.', 'diagnoseo' );
		$content .= ' <a href="' . esc_url( $url ) . '">' . __( 'Deactivate redundant SEO plugins', 'diagnoseo' ) . '</a>.';
		$warn     = '<div class="notice notice-error is-dismissible" id="diagnoseo-notice-plugins"><p>' . wp_kses_post( $content ) . '</p></div>';
		echo wp_kses_post( $warn );
	}

	/**
	 * Deactivates plugins
	 */
	private function deactivate_plugins() {
		$plugins = array();
		foreach ( self::$active_plugins as $plugin => $active ) {
			if ( $active ) {
				$plugins[] = $plugin;
			}
		}
		if ( current_user_can( 'install_plugins' ) ) {
			deactivate_plugins( $plugins, false, false );
		}
	}
}
