<?php
/**
 * Post meta field import
 *
 * @package DiagnoSEO
 */

if ( ! defined( 'ABSPATH' ) ) {
	die;
}

/**
 * Post meta import page
 */
class Diagnoseo_PostMetaImport {
	/**
	 * Title/description variables for plugins
	 *
	 * @var array plugin_vars
	 */
	public $plugin_vars = array(
		'yoast'    => array(
			'%%sitename%%',
			'%%title%%',
			'%%sep%%',
			'%%page%%',
			'%%sitedesc%%',
			'%%primary_category%%',
		),
		'aioseo'   => array(
			'#post_title',
			'#separator_sa',
			'#site_title',
			'#tagline',
			'#post_excerpt',
			'#current_year',
			'#current_month',
			'#author_first_name',
			'#author_last_name',
			'#author_name',
			'#categories',
			'#category_title',
			'#current_date',
			'#current_day',
			'#custom_field',
			'#permalink',
			'#post_content',
			'#post_date',
			'#post_day',
			'#post_excerpt_only',
			'#post_month',
			'#post_year',
			'#tax_name',
		),
		'rankmath' => array(
			'%sitedesc%',
			'%search_query%',
			'%count(varname)%',
			'%filename%',
			'%currentdate%',
			'%currentday%',
			'%currenttime%',
			'%currenttime(F jS, Y)%',
			'%org_name%',
			'%org_logo%',
			'%parent_title%',
			'%excerpt_only%',
			'%url%',
			'%post_thumbnail%',
			'%date%',
			'%modified%',
			'%date(F jS, Y)%',
			'%modified(F, jS, Y)%',
			'%category%',
			'%categories%',
			'%categories(limit=3&separator= | &exclude=12,23)%',
			'%tags%',
			'%tags(limit=3&separator= | &exclude=12,23)%',
			'%term%',
			'%term_description%',
			'%customterm(taxonomy-name)%',
			'%customterm_desc(taxonomy-name)%',
			'%userid%',
			'%name%',
			'%user_description%',
			'%id%',
			'%focuskw%',
			'%keywords%',
			'%customfield(field-name)%',
			'%pagenumber%',
			'%pagetotal%',
			'%pt_single%',
			'%pt_plural%',
			'%customterm(post_format)%',
			'%group_name%',
			'%group_desc%',
			'%wc_price%',
			'%wc_sku%',
			'%wc_shortdesc%',
			'%wc_brand%',
		),
		'seopress' => array(
			'%%sitetitle%%',
			'%%post_title%%',
			'%%sep%%',
			'%%page%%',
			'%%tagline%%',
			'%%post_excerpt%%',
			'%%currentyear%%',
			'%%currentmonth%%',
			'%%post_content%%',
			'%%post_thumbnail_url%%',
			'%%post_url%%',
			'%%post_date%%',
			'%%post_modified_date%%',
			'%%post_author%%',
			'%%post_category%%',
			'%%post_tag%%',
			'%%_category_title%%',
			'%%_category_description%%',
			'%%tag_title%%',
			'%%tag_description%%',
			'%%term_title%%',
			'%%term_description%%',
			'%%search_keywords%%',
			'%%current_pagination%%',
			'%%cpt_plural%%',
			'%%archive_title%%',
			'%%archive_date%%',
			'%%archive_date_day%%',
			'%%archive_date_month%%',
			'%%archive_date_year%%',
			'%%_cf_your_custom_field_name%%',
			'%%_cf_your_custom_taxonomy_slug%%',
			'%%wc_single_cat%%',
			'%%wc_single_tag%%',
			'%%wc_single_short_desc%%',
			'%%wc_single_price%%',
			'%%wc_single_price_exc_tax%%',
			'%%wc_sku%%',
			'%%currentday%%',
			'%%currentmonth_short%%',
			'%%currentdate%%',
			'%%currenttime%%',
			'%%author_first_name%%',
			'%%author_last_name%%',
			'%%author_website%%',
			'%%author_nickname%%',
			'%%author_bio%%',
			'%%_ucf_your_user_meta%%',
			'%%currentmonth_num%%',
			'%%target_keyword%%',
		),
	);
	/**
	 * Title/description variables to replace plugin variables
	 *
	 * @var array new_vars
	 */
	public $new_vars = array(
		'yoast'    => array(
			'%sitename%',
			'%title%',
			'%sep%',
			'%page%',
			'%tagline%',
		),
		'aioseo'   => array(
			'%title%',
			'%sep%',
			'%sitename%',
			'%tagline%',
			'%excerpt%',
			'%currentyear%',
			'%currentmonth%',
		),
		'rankmath' => array(
			'%tagline%',
		),
		'seopress' => array(
			'%sitename%',
			'%title%',
			'%sep%',
			'%page%',
			'%tagline%',
			'%excerpt%',
			'%currentyear%',
			'%currentmonth%',
		),
	);

	/**
	 * Renders post meta import page
	 */
	public function render() {
		?>
		<div class="wrap">
			<h2><?php esc_html_e( 'Data import', 'diagnoseo' ); ?></h2>
			<p><?php esc_html_e( 'Import meta data (title, description) and focus keyword from other plugin settings.', 'diagnoseo' ); ?></p>
			<form id="diagnoseo-data-import" method="post" action="#diagnoseo-data-import" class="diagnoseo-data-import" onsubmit="return confirm( '<?php esc_attr_e( 'This may overwrite some post data, are you sure you want to continue?', 'diagnoseo' ); ?>' )">
				<?php wp_nonce_field( 'metatag_data_import', 'metatag_data_import_nonce' ); ?>
				<table class="form-table" role="presentation">
					<tbody>
						<tr>
							<th><label for="diagnoseo_import_postmeta_from"><?php esc_html_e( 'Import from', 'diagnoseo' ); ?></label></th>
							<td>
								<select name="diagnoseo_import_postmeta_from" id="diagnoseo_import_postmeta_from">
									<option value=""><?php esc_html_e( 'Select a plugin', 'diagnoseo' ); ?></option>
									<option value="yoast"><?php esc_html_e( 'Yoast SEO', 'diagnoseo' ); ?></option>
									<option value="aioseo"><?php esc_html_e( 'All in One SEO', 'diagnoseo' ); ?></option>
									<option value="rankmath"><?php esc_html_e( 'Rank Math SEO', 'diagnoseo' ); ?></option>
									<option value="seoframework"><?php esc_html_e( 'The SEO Framework', 'diagnoseo' ); ?></option>
									<option value="seopress"><?php esc_html_e( 'SEO Press', 'diagnoseo' ); ?></option>
									<option value="slimseo"><?php esc_html_e( 'Slim SEO', 'diagnoseo' ); ?></option>
								</select>
								<p><label for="diagnoseo_prevent_overwriting"><input type="checkbox" name="diagnoseo_prevent_overwriting" id="diagnoseo_prevent_overwriting" value="1" checked /><?php echo esc_html_e( 'Import only if meta tags are not already set by DiagnoSEO', 'diagnoseo' ); ?></label></p>
							</td>
						</tr>
					</tbody>
				</table>
				<?php
				if ( isset( $_POST['metatag_data_import_nonce'] ) && wp_verify_nonce( sanitize_text_field( wp_unslash( $_POST['metatag_data_import_nonce'] ) ), 'metatag_data_import' ) ) {
					if ( isset( $_POST['import_meta'] ) && ! empty( $_POST['diagnoseo_import_postmeta_from'] ) ) {
						$source            = sanitize_text_field( wp_unslash( $_POST['diagnoseo_import_postmeta_from'] ) );
						$prevent_overwrite = isset( $_POST['diagnoseo_prevent_overwriting'] ) ? sanitize_text_field( wp_unslash( $_POST['diagnoseo_prevent_overwriting'] ) ) : false;
						$this->import_postmeta( $source, $prevent_overwrite );
					}
				}
				?>
				<p class="submit"><button type="submit" class="button button-primary" value="import" name="import_meta" id="import_meta"><?php esc_html_e( 'Import', 'diagnoseo' ); ?></button></p>
			</form>
		</div>
		<?php
	}

	/**
	 * Decides which import function to use
	 *
	 * @param String  $source Plugin name to import from.
	 * @param Boolean $prevent_overwrite Whether not to overwrite existing values.
	 */
	private function import_postmeta( $source, $prevent_overwrite = false ) {
		$func = 'import_' . $source . '_postmeta';
		$this->$func( $prevent_overwrite );
	}

	/**
	 * Imports post meta from Yoast SEO plugin
	 *
	 * @param Boolean $prevent_overwrite Whether not to overwrite existing values.
	 */
	private function import_yoast_postmeta( $prevent_overwrite = false ) {
		$this->import_home_meta_yoast();
		$options = array(
			'post_type'      => 'any',
			'posts_per_page' => -1,
			'meta_query'     => array( //phpcs:ignore
				'relation' => 'OR',
				array(
					'key'     => '_yoast_wpseo_focuskw',
					'compare' => 'EXISTS',
				),
				array(
					'key'     => '_yoast_wpseo_title',
					'compare' => 'EXISTS',
				),
				array(
					'key'     => '_yoast_wpseo_metadesc',
					'compare' => 'EXISTS',
				),
			),
		);

		$query = new WP_Query( $options );
		if ( $query->have_posts() ) {
			while ( $query->have_posts() ) {
				$query->the_post();
				$meta = get_post_custom( get_the_ID() );
				?>
				<p>
				<?php esc_html_e( 'Importing meta data for post:', 'diagnoseo' ); ?><br>
				<?php echo esc_html( get_the_ID() . ' (' . get_the_title() . ')' ); ?>
				</p>
				<?php
				$keyword = empty( $meta['_yoast_wpseo_focuskw'] ) ? '' : $meta['_yoast_wpseo_focuskw'][0];
				$title   = empty( $meta['_yoast_wpseo_title'] ) ? '' : $meta['_yoast_wpseo_title'][0];
				$descr   = empty( $meta['_yoast_wpseo_metadesc'] ) ? '' : $meta['_yoast_wpseo_metadesc'][0];
				$title   = str_replace( $this->plugin_vars['yoast'], $this->new_vars['yoast'], $title );

				if ( ! empty( $keyword ) ) {
					$current_keyword = get_post_meta( get_the_ID(), 'diagnoseo_meta_keyword', true );
					if ( ( $prevent_overwrite && empty( $current_keyword ) ) || ! $prevent_overwrite ) {
						update_post_meta( get_the_ID(), 'diagnoseo_meta_keyword', $keyword );
					}
				}
				if ( ! empty( $title ) ) {
					$current_title = get_post_meta( get_the_ID(), 'diagnoseo_meta_title', true );
					if ( ( $prevent_overwrite && empty( $current_title ) ) || ! $prevent_overwrite ) {
						update_post_meta( get_the_ID(), 'diagnoseo_meta_title', $title );
					}
				}
				if ( ! empty( $descr ) ) {
					$current_descr = get_post_meta( get_the_ID(), 'diagnoseo_meta_description', true );
					if ( ( $prevent_overwrite && empty( $current_descr ) ) || ! $prevent_overwrite ) {
						update_post_meta( get_the_ID(), 'diagnoseo_meta_description', $descr );
					}
				}
			}
		}
	}

	/**
	 * Imports post meta from All in One SEO plugin
	 *
	 * @param Boolean $prevent_overwrite Whether not to overwrite existing values.
	 */
	private function import_aioseo_postmeta( $prevent_overwrite = false ) {
		$this->import_home_meta_aioseo();
		$options = array(
			'post_type'      => 'any',
			'posts_per_page' => -1,
			'meta_query'     => array( //phpcs:ignore
				'relation' => 'OR',
				array(
					'key'     => '_aioseo_keywords',
					'compare' => 'EXISTS',
				),
				array(
					'key'     => '_aioseo_title',
					'compare' => 'EXISTS',
				),
				array(
					'key'     => '_aioseo_description',
					'compare' => 'EXISTS',
				),
			),
		);

		$query = new WP_Query( $options );
		if ( $query->have_posts() ) {
			while ( $query->have_posts() ) {
				$query->the_post();
				$meta = get_post_custom( get_the_ID() );
				?>
				<p>
				<?php esc_html_e( 'Importing meta data for post:', 'diagnoseo' ); ?><br>
				<?php echo esc_html( get_the_ID() . ' (' . get_the_title() . ')' ); ?>
				</p>
				<?php
				global $wpdb;
				$keyword_data = $wpdb->get_results( $wpdb->prepare( 'select keyphrases from %s where post_id=%d', $wpdb->prefix . 'aioseo_posts', get_the_ID() ) ); //phpcs:ignore
				$keyword_data = json_decode( $keyword_data[0]->keyphrases );
				$keyword      = $keyword_data->focus->keyphrase;
				$title        = empty( $meta['_aioseo_title'] ) ? '' : str_replace( $this->plugin_vars['aioseo'], $this->new_vars['aioseo'], $meta['_aioseo_title'][0] );
				$descr        = empty( $meta['_aioseo_description'] ) ? '' : str_replace( $this->plugin_vars['aioseo'], $this->new_vars['aioseo'], $meta['_aioseo_description'][0] );

				if ( ! empty( $keyword ) ) {
					$current_keyword = get_post_meta( get_the_ID(), 'diagnoseo_meta_keyword', true );
					if ( ( $prevent_overwrite && empty( $current_keyword ) ) || ! $prevent_overwrite ) {
						update_post_meta( get_the_ID(), 'diagnoseo_meta_keyword', $keyword );
					}
				}
				if ( ! empty( $title ) ) {
					$current_title = get_post_meta( get_the_ID(), 'diagnoseo_meta_title', true );
					if ( ( $prevent_overwrite && empty( $current_title ) ) || ! $prevent_overwrite ) {
						update_post_meta( get_the_ID(), 'diagnoseo_meta_title', $title );
					}
				}
				if ( ! empty( $descr ) ) {
					$current_descr = get_post_meta( get_the_ID(), 'diagnoseo_meta_description', true );
					if ( ( $prevent_overwrite && empty( $current_descr ) ) || ! $prevent_overwrite ) {
						update_post_meta( get_the_ID(), 'diagnoseo_meta_description', $descr );
					}
				}
			}
		}
	}

	/**
	 * Imports post meta from Rank Math plugin
	 *
	 * @param Boolean $prevent_overwrite Whether not to overwrite existing values.
	 */
	private function import_rankmath_postmeta( $prevent_overwrite = false ) {
		$this->import_home_meta_rankmath();

		$options = array(
			'post_type'      => 'any',
			'posts_per_page' => -1,
			'meta_query'     => array( //phpcs:ignore
				'relation' => 'OR',
				array(
					'key'     => 'rank_math_focus_keyword',
					'compare' => 'EXISTS',
				),
				array(
					'key'     => 'rank_math_title',
					'compare' => 'EXISTS',
				),
				array(
					'key'     => 'rank_math_description',
					'compare' => 'EXISTS',
				),
			),
		);

		$query = new WP_Query( $options );
		if ( $query->have_posts() ) {
			while ( $query->have_posts() ) {
				$query->the_post();
				$meta = get_post_custom( get_the_ID() );
				?>
				<p>
				<?php esc_html_e( 'Importing meta data for post:', 'diagnoseo' ); ?><br>
				<?php echo esc_html( get_the_ID() . ' (' . get_the_title() . ')' ); ?>
				</p>
				<?php
				$keyword = empty( $meta['rank_math_focus_keyword'] ) ? '' : $meta['rank_math_focus_keyword'][0];
				$title   = empty( $meta['rank_math_title'] ) ? '' : str_replace( $this->plugin_vars['rankmath'], $this->new_vars['rankmath'], $meta['rank_math_title'][0] );
				$descr   = empty( $meta['rank_math_description'] ) ? '' : str_replace( $this->plugin_vars['rankmath'], $this->new_vars['rankmath'], $meta['rank_math_description'][0] );

				if ( ! empty( $keyword ) ) {
					$current_keyword = get_post_meta( get_the_ID(), 'diagnoseo_meta_keyword', true );
					if ( ( $prevent_overwrite && empty( $current_keyword ) ) || ! $prevent_overwrite ) {
						update_post_meta( get_the_ID(), 'diagnoseo_meta_keyword', $keyword );
					}
				}
				if ( ! empty( $title ) ) {
					$current_title = get_post_meta( get_the_ID(), 'diagnoseo_meta_title', true );
					if ( ( $prevent_overwrite && empty( $current_title ) ) || ! $prevent_overwrite ) {
						update_post_meta( get_the_ID(), 'diagnoseo_meta_title', $title );
					}
				}
				if ( ! empty( $descr ) ) {
					$current_descr = get_post_meta( get_the_ID(), 'diagnoseo_meta_description', true );
					if ( ( $prevent_overwrite && empty( $current_descr ) ) || ! $prevent_overwrite ) {
						update_post_meta( get_the_ID(), 'diagnoseo_meta_description', $descr );
					}
				}
			}
		}
	}

	/**
	 * Imports post meta from The SEO Framework plugin
	 *
	 * @param Boolean $prevent_overwrite Whether not to overwrite existing values.
	 */
	private function import_seoframework_postmeta( $prevent_overwrite = false ) {
		$this->import_home_meta_seoframework();

		$options = array(
			'post_type'      => 'any',
			'posts_per_page' => -1,
			'meta_query'     => array( //phpcs:ignore
				'relation' => 'OR',
				array(
					'key'     => '_genesis_title',
					'compare' => 'EXISTS',
				),
				array(
					'key'     => '_genesis_description',
					'compare' => 'EXISTS',
				),
			),
		);

		$query = new WP_Query( $options );
		if ( $query->have_posts() ) {
			while ( $query->have_posts() ) {
				$query->the_post();
				$meta = get_post_custom( get_the_ID() );
				?>
				<p>
				<?php esc_html_e( 'Importing meta data for post:', 'diagnoseo' ); ?><br>
				<?php echo esc_html( get_the_ID() . ' (' . get_the_title() . ')' ); ?>
				</p>
				<?php
				global $wpdb;
				$title = empty( $meta['_genesis_title'] ) ? '' : $meta['_genesis_title'][0];
				$descr = empty( $meta['_genesis_description'] ) ? '' : $meta['_genesis_description'][0];

				if ( ! empty( $title ) ) {
					$current_title = get_post_meta( get_the_ID(), 'diagnoseo_meta_title', true );
					if ( ( $prevent_overwrite && empty( $current_title ) ) || ! $prevent_overwrite ) {
						update_post_meta( get_the_ID(), 'diagnoseo_meta_title', $title );
					}
				}
				if ( ! empty( $descr ) ) {
					$current_descr = get_post_meta( get_the_ID(), 'diagnoseo_meta_description', true );
					if ( ( $prevent_overwrite && empty( $current_descr ) ) || ! $prevent_overwrite ) {
						update_post_meta( get_the_ID(), 'diagnoseo_meta_description', $descr );
					}
				}
			}
		}
	}

	/**
	 * Imports post meta from SEO Press
	 *
	 * @param Boolean $prevent_overwrite Whether not to overwrite existing values.
	 */
	private function import_seopress_postmeta( $prevent_overwrite = false ) {
		$this->import_home_meta_seopress();

		$options = array(
			'post_type'      => 'any',
			'posts_per_page' => -1,
			'meta_query'     => array( //phpcs:ignore
				'relation' => 'OR',
				array(
					'key'     => '_seopress_analysis_target_kw',
					'compare' => 'EXISTS',
				),
				array(
					'key'     => 'rank_math_title',
					'compare' => 'EXISTS',
				),
				array(
					'key'     => 'rank_math_description',
					'compare' => 'EXISTS',
				),
			),
		);

		$query = new WP_Query( $options );
		if ( $query->have_posts() ) {
			while ( $query->have_posts() ) {
				$query->the_post();
				$meta = get_post_custom( get_the_ID() );
				?>
				<p>
				<?php esc_html_e( 'Importing meta data for post:', 'diagnoseo' ); ?><br>
				<?php echo esc_html( get_the_ID() . ' (' . get_the_title() . ')' ); ?>
				</p>
				<?php
				$keyword = empty( $meta['_seopress_analysis_target_kw'] ) ? '' : $meta['_seopress_analysis_target_kw'][0];
				$title   = empty( $meta['_seopress_titles_title'] ) ? '' : str_replace( $this->plugin_vars['seopress'], $this->new_vars['seopress'], $meta['_seopress_titles_title'][0] );
				$descr   = empty( $meta['_seopress_titles_desc'] ) ? '' : str_replace( $this->plugin_vars['seopress'], $this->new_vars['seopress'], $meta['_seopress_titles_desc'][0] );

				if ( ! empty( $keyword ) ) {
					$current_keyword = get_post_meta( get_the_ID(), 'diagnoseo_meta_keyword', true );
					if ( ( $prevent_overwrite && empty( $current_keyword ) ) || ! $prevent_overwrite ) {
						update_post_meta( get_the_ID(), 'diagnoseo_meta_keyword', $keyword );
					}
				}
				if ( ! empty( $title ) ) {
					$current_title = get_post_meta( get_the_ID(), 'diagnoseo_meta_title', true );
					if ( ( $prevent_overwrite && empty( $current_title ) ) || ! $prevent_overwrite ) {
						update_post_meta( get_the_ID(), 'diagnoseo_meta_title', $title );
					}
				}
				if ( ! empty( $descr ) ) {
					$current_descr = get_post_meta( get_the_ID(), 'diagnoseo_meta_description', true );
					if ( ( $prevent_overwrite && empty( $current_descr ) ) || ! $prevent_overwrite ) {
						update_post_meta( get_the_ID(), 'diagnoseo_meta_description', $descr );
					}
				}
			}
		}
	}

	/**
	 * Imports post meta from Slim SEO plugin
	 *
	 * @param Boolean $prevent_overwrite Whether not to overwrite existing values.
	 */
	private function import_slimseo_postmeta( $prevent_overwrite = false ) {
		$this->import_home_meta_slimseo();

		$options = array(
			'post_type'      => 'any',
			'posts_per_page' => -1,
			'meta_query'     => array( //phpcs:ignore
				array(
					'key'     => 'slim_seo',
					'compare' => 'EXISTS',
				),
			),
		);

		$query = new WP_Query( $options );
		if ( $query->have_posts() ) {
			while ( $query->have_posts() ) {
				$query->the_post();
				$meta = get_post_custom( get_the_ID() );
				?>
				<p>
				<?php esc_html_e( 'Importing meta data for post:', 'diagnoseo' ); ?><br>
				<?php echo esc_html( get_the_ID() . ' (' . get_the_title() . ')' ); ?>
				</p>
				<?php
				global $wpdb;
				$slim_seo_data = empty( $meta['slim_seo'] ) ? '' : unserialize( $meta['slim_seo'][0] ); //phpcs:ignore
				if ( empty( $slim_seo_data ) ) {
					return;
				}
				$title = $slim_seo_data['title'];
				$descr = $slim_seo_data['description'];

				if ( ! empty( $title ) ) {
					$current_title = get_post_meta( get_the_ID(), 'diagnoseo_meta_title', true );
					if ( ( $prevent_overwrite && empty( $current_title ) ) || ! $prevent_overwrite ) {
						update_post_meta( get_the_ID(), 'diagnoseo_meta_title', $title );
					}
				}
				if ( ! empty( $descr ) ) {
					$current_descr = get_post_meta( get_the_ID(), 'diagnoseo_meta_description', true );
					if ( ( $prevent_overwrite && empty( $current_descr ) ) || ! $prevent_overwrite ) {
						update_post_meta( get_the_ID(), 'diagnoseo_meta_description', $descr );
					}
				}
			}
		}
	}

	/**
	 * Imports home page title and description from yoast
	 */
	private function import_home_meta_yoast() {
		$data = get_option( 'wpseo_titles' );
		if ( current_user_can( 'manage_options' ) ) {
			$new_vars = array( '%sitename%', '%title%', '%sep%', '%page%', '%tagline%' );

			if ( ! empty( $data['title-home-wpseo'] ) ) {
				$title = str_replace( $this->plugin_vars['yoast'], $new_vars, $data['title-home-wpseo'] );
				update_option( 'diagnoseo_home_title', $title );
			}

			if ( ! empty( $data['metadesc-home-wpseo'] ) ) {
				$descr = str_replace( $this->plugin_vars['yoast'], $new_vars, $data['metadesc-home-wpseo'] );
				update_option( 'diagnoseo_home_description', $descr );
			}
		}
	}

	/**
	 * Imports home page title and description from aioseo
	 */
	private function import_home_meta_aioseo() {
		$data  = json_decode( get_option( 'aioseo_options' ) );
		$title = $data->searchAppearance->global->siteTitle; //phpcs:ignore
		$descr = $data->searchAppearance->global->metaDescription; //phpcs:ignore

		if ( current_user_can( 'manage_options' ) ) {
			$new_vars = array( '%title%', '%sep%', '%sitename%', '%tagline%', '%excerpt%', '%currentyear%', '%currentmonth%' );

			if ( ! empty( $title ) ) {
				$title = str_replace( $this->plugin_vars['aioseo'], $new_vars, $title );
				update_option( 'diagnoseo_home_title', $title );
			}

			if ( ! empty( $descr ) ) {
				$descr = str_replace( $this->plugin_vars['aioseo'], $new_vars, $descr );
				update_option( 'diagnoseo_home_description', $descr );
			}
		}
	}

	/**
	 * Imports home page title and description from Rank Math SEO
	 */
	private function import_home_meta_rankmath() {
		$data = get_option( 'rank-math-options-titles' );

		if ( current_user_can( 'manage_options' ) ) {
			$new_vars = array( '%tagline%' );

			if ( ! empty( $data['homepage_title'] ) ) {
				$title = str_replace( $this->plugin_vars['rankmath'], $new_vars, $data['homepage_title'] );
				update_option( 'diagnoseo_home_title', $title );
			}

			if ( ! empty( $data['homepage_description'] ) ) {
				$descr = str_replace( $this->plugin_vars['rankmath'], $new_vars, $data['homepage_description'] );
				update_option( 'diagnoseo_home_description', $descr );
			}
		}
	}

	/**
	 * Imports home page title and description from The SEO Framework
	 */
	private function import_home_meta_seoframework() {
		$data = get_option( 'autodescription-site-settings' );

		if ( current_user_can( 'manage_options' ) ) {

			if ( ! empty( $data['homepage_title'] ) ) {
				update_option( 'diagnoseo_home_title', $data['homepage_title'] );
			}

			if ( ! empty( $data['homepage_description'] ) ) {
				update_option( 'diagnoseo_home_description', $data['homepage_description'] );
			}
		}
	}

	/**
	 * Imports home page title and description from SEOPress
	 */
	private function import_home_meta_seopress() {
		$data = get_option( 'seopress_titles_option_name' );

		if ( current_user_can( 'manage_options' ) ) {
			$new_vars = array(
				'%sitename%',
				'%title%',
				'%sep%',
				'%page%',
				'%tagline%',
				'%excerpt%',
				'%currentyear%',
				'%currentmonth%',
			);
			if ( ! empty( $data['seopress_titles_home_site_title'] ) ) {
				$title = str_replace( $this->plugin_vars['seopress'], $new_vars, $data['seopress_titles_home_site_title'] );
				update_option( 'diagnoseo_home_title', $title );
			}

			if ( ! empty( $data['seopress_titles_home_site_desc'] ) ) {
				$descr = str_replace( $this->plugin_vars['seopress'], '', $data['seopress_titles_home_site_desc'] );
				update_option( 'diagnoseo_home_description', $descr );
			}
		}
	}

	/**
	 * Imports home page title and description from Slim SEO
	 */
	private function import_home_meta_slimseo() {
		$data = get_option( 'slim_seo' );

		if ( current_user_can( 'manage_options' ) ) {

			if ( ! empty( $data['home_title'] ) ) {
				update_option( 'diagnoseo_home_title', $data['home_title'] );
			}

			if ( ! empty( $data['home_description'] ) ) {
				update_option( 'diagnoseo_home_description', $data['home_description'] );
			}
		}
	}


}
