<?php
/**
 * Schema settings
 *
 * @package DiagnoSEO
 */

if ( ! defined( 'ABSPATH' ) ) {
	die;
}
/**
 * Schema settings page
 */
class Diagnoseo_SchemaSettings {

	/**
	 * Default option values
	 *
	 * @var $defaults
	 */
	public $defaults = array();

	/**
	 * Hooks actions on object creation
	 *
	 * @param Array $defaults Associative array of default option values.
	 */
	public function __construct( $defaults ) {
		$this->defaults = $defaults;
		add_action( 'admin_init', array( $this, 'register_settings' ) );
		add_action( 'diagnoseo_render_schema_options', array( $this, 'render_pro_settings' ) );
		add_action( 'admin_enqueue_scripts', array( $this, 'load_media' ) );
	}

	/**
	 * Loads media library
	 */
	public function load_media() {
		wp_enqueue_media();
	}

	/**
	 * Renders schema settings page content
	 */
	public function render() {
		$helper     = new Diagnoseo_SettingsHelper();
		$post_types = Diagnoseo_SettingsHelper::get_post_types();
		?>
		<div class="wrap">
			<h1><?php esc_html_e( 'Schema and Structured Data Settings', 'diagnoseo' ); ?></h1>
			<form method="post" action="options.php" class="diagnoseo-settings-form">
			<?php
			settings_fields( 'diagnoseo_schema_options' );
			do_settings_sections( 'diagnoseo_schema_options' );
			?>

			<div class="diagnoseo-settings-section">
				<div class="diagnoseo-settings">
					<h2><?php esc_html_e( 'Site owner structured data', 'diagnoseo' ); ?></h2>
					<table class="form-table" role="presentation">
						<tbody>
							<tr>
								<th><label for="diagnoseo_site_owner_type"><?php esc_html_e( 'Who represents website (company/organization or person)?', 'diagnoseo' ); ?></label></th>
								<td>
									<?php
									$site_owner_type = get_option( 'diagnoseo_site_owner_type', $this->defaults['diagnoseo_site_owner_type'] );
									?>
									<select name="diagnoseo_site_owner_type" id="diagnoseo_site_owner_type">
										<option value=''><?php esc_html_e( 'None', 'diagnoseo' ); ?></option>
										<option value="Organization" <?php selected( $site_owner_type, 'Organization', true ); ?>><?php esc_html_e( 'Organization', 'seo-frinedly' ); ?></option>
										<option value="Person" <?php selected( $site_owner_type, 'Person', true ); ?>><?php esc_html_e( 'Person', 'seo-frinedly' ); ?></option>
									</select>
								</td>
							</tr>
							<tr>
								<th><label for="diagnoseo_site_owner_name"><?php esc_html_e( 'Name', 'diagnoseo' ); ?></label></th>
								<td>
									<input type="text" id="diagnoseo_site_owner_name" name="diagnoseo_site_owner_name" value="<?php echo esc_attr( get_option( 'diagnoseo_site_owner_name', $this->defaults['diagnoseo_site_owner_name'] ) ); ?>" class="regular-text" />
								</td>
							</tr>
							<tr>
								<th><label for="diagnoseo_site_owner_image"><?php esc_html_e( 'Image', 'diagnoseo' ); ?></label></th>
								<td class="diagnoseo-image-select">
									<?php
									$fallback_img = '';
									?>
									<button class="button button-secondary diagnoseo-img-upload"><i class="dashicons dashicons-format-image"></i> <?php esc_html_e( 'Select image', 'diagnoseo' ); ?></button> <button class="button button-secondary diagnoseo-img-remove" data-fallback-image="<?php echo esc_url( $fallback_img ); ?>"><i class="dashicons dashicons-no"></i> <?php esc_html_e( 'Remove image', 'diagnoseo' ); ?></button>
									<?php if ( ! empty( get_option( 'diagnoseo_site_owner_image', $this->defaults['diagnoseo_site_owner_image'] ) ) ) : ?>
										<p><img class="diagnoseo-img" src="<?php echo esc_url( get_option( 'diagnoseo_site_owner_image', $this->defaults['diagnoseo_site_owner_image'] ) ); ?>" /></p>
									<?php elseif ( has_custom_logo() ) : ?>
										<p><img class="diagnoseo-img" src="<?php echo esc_url( $fallback_img ); ?>" /></p>
									<?php endif; ?>
									<p><?php esc_html_e( 'Minumum image dimensions: 112px &times; 112px', 'diagnoseo' ); ?></p>
									<input class="diagnoseo-img-address" type="hidden" name="diagnoseo_site_owner_image" id="diagnoseo_site_owner_image" value="<?php echo esc_attr( get_option( 'diagnoseo_site_owner_image', $this->defaults['diagnoseo_site_owner_image'] ) ); ?>">
								</td>
							</tr>
							<tr>
								<th><label for="diagnoseo_site_owner_url"><?php esc_html_e( 'URL', 'diagnoseo' ); ?></label></th>
								<td>
									<input type="url" id="diagnoseo_site_owner_url" name="diagnoseo_site_owner_url" value="<?php echo esc_attr( get_option( 'diagnoseo_site_owner_url', $this->defaults['diagnoseo_site_owner_url'] ) ); ?>" class="regular-text" />
								</td>
							</tr>
							<tr>
								<th><label for="diagnoseo_site_owner_email"><?php esc_html_e( 'E-mail', 'diagnoseo' ); ?></label></th>
								<td>
									<input type="email" id="diagnoseo_site_owner_email" name="diagnoseo_site_owner_email" value="<?php echo esc_attr( get_option( 'diagnoseo_site_owner_email', $this->defaults['diagnoseo_site_owner_email'] ) ); ?>" class="regular-text" />
								</td>
							</tr>
							<tr>
								<th><label for="diagnoseo_site_owner_phone"><?php esc_html_e( 'Phone', 'diagnoseo' ); ?></label></th>
								<td>
									<input type="tel" id="diagnoseo_site_owner_phone" name="diagnoseo_site_owner_phone" value="<?php echo esc_attr( get_option( 'diagnoseo_site_owner_phone', $this->defaults['diagnoseo_site_owner_phone'] ) ); ?>" class="regular-text" />
								</td>
							</tr>
							<tr>
								<th><label><?php esc_html_e( 'Address', 'diagnoseo' ); ?></label></th>
								<td>
									<p><label for="diagnoseo_site_owner_street_address"><?php esc_html_e( 'Street address', 'diagnoseo' ); ?></label></p>
									<input type="text" placeholder="<?php echo esc_attr( __( 'Street address', 'diagnoseo' ) ); ?>" id="diagnoseo_site_owner_street_address" name="diagnoseo_site_owner_street_address" value="<?php echo esc_attr( get_option( 'diagnoseo_site_owner_street_address', $this->defaults['diagnoseo_site_owner_street_address'] ) ); ?>" class="regular-text" /><br />
									<p><label for="diagnoseo_site_owner_locality"><?php esc_html_e( 'Locality', 'diagnoseo' ); ?></label></p>
									<input type="text" placeholder="<?php echo esc_attr( __( 'Locality', 'diagnoseo' ) ); ?>" id="diagnoseo_site_owner_locality" name="diagnoseo_site_owner_locality" value="<?php echo esc_attr( get_option( 'diagnoseo_site_owner_locality', $this->defaults['diagnoseo_site_owner_locality'] ) ); ?>" class="regular-text" /><br />
									<p><label for="diagnoseo_site_owner_region"><?php esc_html_e( 'Region', 'diagnoseo' ); ?></label></p>
									<input type="text" placeholder="<?php echo esc_attr( __( 'Region', 'diagnoseo' ) ); ?>" id="diagnoseo_site_owner_region" name="diagnoseo_site_owner_region" value="<?php echo esc_attr( get_option( 'diagnoseo_site_owner_region', $this->defaults['diagnoseo_site_owner_region'] ) ); ?>" class="regular-text" /><br />
									<p><label for="diagnoseo_site_owner_postal_code"><?php esc_html_e( 'Postal code', 'diagnoseo' ); ?></label></p>
									<input type="text" placeholder="<?php echo esc_attr( __( 'Postal code', 'diagnoseo' ) ); ?>" id="diagnoseo_site_owner_postal_code" name="diagnoseo_site_owner_postal_code" value="<?php echo esc_attr( get_option( 'diagnoseo_site_owner_postal_code', $this->defaults['diagnoseo_site_owner_postal_code'] ) ); ?>" class="regular-text" /><br />
									<p><label for="diagnoseo_site_owner_country"><?php esc_html_e( 'Country', 'diagnoseo' ); ?></label></p>
									<input type="text" placeholder="<?php echo esc_attr( __( 'Country', 'diagnoseo' ) ); ?>" id="diagnoseo_site_owner_country" name="diagnoseo_site_owner_country" value="<?php echo esc_attr( get_option( 'diagnoseo_site_owner_country', $this->defaults['diagnoseo_site_owner_country'] ) ); ?>" class="regular-text" /><br />
								</td>
							</tr>
						</tbody>
					</table>
				</div>
			</div>

			<div class="diagnoseo-settings-section">
				<div class="diagnoseo-settings">
					<h2><?php esc_html_e( 'Structured data for post types', 'diagnoseo' ); ?></h2>
					<p><?php esc_html_e( 'Set a default structured data type for each post type', 'diagnoseo' ); ?></p>
					<table class="form-table" role="presentation">
						<tbody>
							<?php
							foreach ( $post_types as $type ) :
								$setting_name = 'diagnoseo_' . $type->name . '_schema_type'
								?>
								<tr>
									<th><label for="<?php echo esc_attr( $setting_name ); ?>"><?php echo esc_html( $type->label ); ?></label></th>
									<td>
										<select name="<?php echo esc_attr( $setting_name ); ?>" id="<?php echo esc_attr( $setting_name ); ?>">
											<option value=''><?php esc_html_e( 'None', 'diagnoseo' ); ?></option>
											<?php
											$schema_types = Diagnoseo_SettingsHelper::$post_schema_types;
											$value        = get_option( $setting_name, empty( $this->defaults[ $setting_name ] ) ? '' : $this->defaults[ $setting_name ] );
											foreach ( $schema_types as $schema_type ) :
												?>
											<option value="<?php echo esc_attr( $schema_type ); ?>" <?php selected( $schema_type, $value ); ?>>
												<?php echo esc_html( $schema_type ); ?>
											</option>
											<?php endforeach; ?>
										</select>
									</td>
								</tr>
							<?php endforeach; ?>
						</tbody>
					</table>
				</div>
			</div>

			<?php do_action( 'diagnoseo_render_schema_options' ); ?>

			<?php submit_button(); ?>
			</form>
		</div>
		<?php
	}

	/**
	 * Registers schema options
	 */
	public function register_settings() {
		$post_types = Diagnoseo_SettingsHelper::get_post_types();

		foreach ( $post_types as $type ) {
			$setting_name = 'diagnoseo_' . $type->name . '_schema_type';
			register_setting(
				'diagnoseo_schema_options',
				$setting_name,
				array(
					'type'              => 'string',
					'description'       => __( 'Schema type for ', 'diagnoseo' ) . $type->name,
					'sanitize_callback' => 'sanitize_text_field',
					'show_in_rest'      => true,
				)
			);
		}

		add_option( 'diagnoseo_site_owner_type', '' );
		register_setting(
			'diagnoseo_schema_options',
			'diagnoseo_site_owner_type',
			array(
				'type'              => 'string',
				'description'       => __( 'Schema type for site owner', 'diagnoseo' ),
				'sanitize_callback' => 'sanitize_text_field',
				'show_in_rest'      => true,
			)
		);

		add_option( 'diagnoseo_site_owner_name', '' );
		register_setting(
			'diagnoseo_schema_options',
			'diagnoseo_site_owner_name',
			array(
				'type'              => 'string',
				'description'       => __( 'Site owner name', 'diagnoseo' ),
				'sanitize_callback' => 'sanitize_text_field',
				'show_in_rest'      => true,
			)
		);

		add_option( 'diagnoseo_site_owner_image', '' );
		register_setting(
			'diagnoseo_schema_options',
			'diagnoseo_site_owner_image',
			array(
				'type'              => 'string',
				'description'       => __( 'Site owner image', 'diagnoseo' ),
				'sanitize_callback' => 'sanitize_text_field',
				'show_in_rest'      => true,
			)
		);

		add_option( 'diagnoseo_site_owner_url', '' );
		register_setting(
			'diagnoseo_schema_options',
			'diagnoseo_site_owner_url',
			array(
				'type'              => 'string',
				'description'       => __( 'Site owner url', 'diagnoseo' ),
				'sanitize_callback' => 'sanitize_text_field',
				'show_in_rest'      => true,
			)
		);

		add_option( 'diagnoseo_site_owner_email', '' );
		register_setting(
			'diagnoseo_schema_options',
			'diagnoseo_site_owner_email',
			array(
				'type'              => 'string',
				'description'       => __( 'Site owner e-mail address', 'diagnoseo' ),
				'sanitize_callback' => 'sanitize_text_field',
				'show_in_rest'      => true,
			)
		);

		add_option( 'diagnoseo_site_owner_phone', '' );
		register_setting(
			'diagnoseo_schema_options',
			'diagnoseo_site_owner_phone',
			array(
				'type'              => 'string',
				'description'       => __( 'Site owner phone number', 'diagnoseo' ),
				'sanitize_callback' => 'sanitize_text_field',
				'show_in_rest'      => true,
			)
		);

		add_option( 'diagnoseo_site_owner_street_address', '' );
		register_setting(
			'diagnoseo_schema_options',
			'diagnoseo_site_owner_street_address',
			array(
				'type'              => 'string',
				'description'       => __( 'Street address', 'diagnoseo' ),
				'sanitize_callback' => 'sanitize_text_field',
				'show_in_rest'      => true,
			)
		);

		add_option( 'diagnoseo_site_owner_locality', '' );
		register_setting(
			'diagnoseo_schema_options',
			'diagnoseo_site_owner_locality',
			array(
				'type'              => 'string',
				'description'       => __( 'Locality', 'diagnoseo' ),
				'sanitize_callback' => 'sanitize_text_field',
				'show_in_rest'      => true,
			)
		);

		add_option( 'diagnoseo_site_owner_region', '' );
		register_setting(
			'diagnoseo_schema_options',
			'diagnoseo_site_owner_region',
			array(
				'type'              => 'string',
				'description'       => __( 'Region', 'diagnoseo' ),
				'sanitize_callback' => 'sanitize_text_field',
				'show_in_rest'      => true,
			)
		);

		add_option( 'diagnoseo_site_owner_postal_code', '' );
		register_setting(
			'diagnoseo_schema_options',
			'diagnoseo_site_owner_postal_code',
			array(
				'type'              => 'string',
				'description'       => __( 'Postal code', 'diagnoseo' ),
				'sanitize_callback' => 'sanitize_text_field',
				'show_in_rest'      => true,
			)
		);

		add_option( 'diagnoseo_site_owner_country', '' );
		register_setting(
			'diagnoseo_schema_options',
			'diagnoseo_site_owner_country',
			array(
				'type'              => 'string',
				'description'       => __( 'Country', 'diagnoseo' ),
				'sanitize_callback' => 'sanitize_text_field',
				'show_in_rest'      => true,
			)
		);

		do_action( 'diagnoseo_register_schema_options' );
	}

	/**
	 * Renders setting mockup for non-pro users
	 */
	public function render_pro_settings() {
		if ( function_exists( 'diagnoseo_pro_init' ) ) {
			return;
		}
		?>
		<div class="diagnoseo-settings-section content-types in-pro">
			<h2><?php esc_html_e( 'Structured data', 'diagnoseo' ); ?> (<a href="https://diagnoseo.com/wordpress-seo-plugin/?utm_source=wp&utm_medium=link&utm_campaign=available_in_pro" target="_blank" rel="noreferrer noopener"><?php esc_html_e( 'Available in Pro', 'diagnoseo' ); ?></a>)</h2>
			<table class="form-table" role="presentation">
				<tbody>
					<tr>
						<th><?php esc_html_e( 'Schema', 'diagnoseo-pro' ); ?></th>
						<td>
							<p><label for=""><input disabled type="checkbox" checked /><?php echo esc_html_e( 'Website', 'diagnoseo' ); ?></label></p>
							<p><label for=""><input disabled type="checkbox" checked /><?php echo esc_html_e( 'Organization/Person', 'diagnoseo' ); ?></label></p>
							<p><label for=""><input disabled type="checkbox" checked /><?php echo esc_html_e( 'LocalBusiness', 'diagnoseo' ); ?></label></p>
							<p><label for=""><input disabled type="checkbox" checked /><?php echo esc_html_e( 'BreadcrumbsList', 'diagnoseo' ); ?></label></p>
						</td>
					</tr>
				</tbody>
			</table>

			<table class="form-table" role="presentation">
				<tbody>
					<tr>
						<th><?php esc_html_e( 'ReviewedBy Schema', 'diagnoseo' ); ?></th>
						<td>
							<?php
								$reviewedby_type = get_option( 'diagnoseo_reviewedby_type', '' );
								$reviewedby_name = get_option( 'diagnoseo_reviewedby_name', '' );
								$reviewedby_url  = get_option( 'diagnoseo_reviewedby_url', '' );
							?>
							<p>
								<label for="diagnoseo_reviewedby_type"><?php esc_html_e( 'Type', 'diagnoseo' ); ?>:</label>
							</p>
								<select name="diagnoseo_reviewedby_type" id="diagnoseo_reviewedby_type" disabled>
									<option value="Person"><?php esc_html_e( 'Person', 'diagnoseo' ); ?></option>
									<option value="Organization"><?php esc_html_e( 'Organization', 'diagnoseo' ); ?></option>
								</select>
							<p>
								<label for="diagnoseo_reviewedby_name"><?php esc_html_e( 'Name', 'diagnoseo' ); ?></label>
							</p>
								<input disabled type="text" class="regular-text" name="diagnoseo_reviewedby_name" id="diagnoseo_reviewedby_name">
							<p>
								<label for="diagnoseo_reviewedby_url"><?php esc_html_e( 'URL', 'diagnoseo' ); ?></label>
							</p>
								<input disabled type="url" class="regular-text" name="diagnoseo_reviewedby_url" id="diagnoseo_reviewedby_url">
						</td>
					</tr>
				</tbody>
			</table>

			<table class="form-table" role="presentation">
				<tbody>
					<tr>
						<th><?php esc_html_e( 'Social media profiles', 'diagnoseo' ); ?></th>
						<td>
						<?php
						$link_settings = array( 'Facebook', 'Twitter', 'Instagram', 'LinkedIn', 'Pinterest', 'YouTube', 'Wikipedia' );
						foreach ( $link_settings as $option ) :
							$setting_name = 'diagnoseo_pro_social_' . strtolower( $option );
							?>
							<p><label for="<?php echo esc_attr( $setting_name ); ?>"><?php echo esc_html( $option ); ?></label></p>
							<input disabled type="url" name="<?php echo esc_attr( $setting_name ); ?>" id="<?php echo esc_attr( $setting_name ); ?>" class="regular-text" value="<?php echo esc_attr( get_option( $setting_name ) ); ?>" />
							<?php
						endforeach;
						?>
						</td>
					</tr>
				</tbody>
			</table>

			<table class="form-table" role="presentation">
				<tbody>
					<tr>
						<th><?php esc_html_e( 'Local Business structured data', 'diagnoseo-pro' ); ?></th>
						<td>
							<p><label for="diagnoseo_schema_business_type"><?php esc_html_e( 'Business type', 'diagnoseo' ); ?></label></p>
							<input disabled type="text" class="regular-text" />

							<p><label for="diagnoseo_schema_business_name"><?php esc_html_e( 'Business name', 'diagnoseo' ); ?></label></p>
							<input disabled type="text" class="regular-text" />

							<p><label for="diagnoseo_schema_business_phone"><?php esc_html_e( 'Telephone', 'diagnoseo' ); ?></label></p>
							<input disabled type="text" class="regular-text" />

							<p><label for="diagnoseo_schema_business_opening_hours"><?php esc_html_e( 'Opening hours', 'diagnoseo' ); ?></label></p>
							<textarea disabled type="text" rows="5" class="regular-text"></textarea>

								<p class="description"><?php esc_html_e( "The general opening hours for a business. Opening hours can be specified as a weekly time range, starting with days, then times per day. Multiple days can be listed with commas ',' separating each day. Day or time ranges are specified using a hyphen '-'", 'diagnoseo' ); ?></p>
								<lu lclass="description">
									<li><?php esc_html_e( 'One item per line', 'diagnoseo' ); ?></li>
									<li><?php esc_html_e( 'Days are specified using the following two-letter combinations: Mo, Tu, We, Th, Fr, Sa, Su.', 'diagnoseo' ); ?></li>
									<li><?php esc_html_e( 'Times are specified using 24:00 format. For example, 3pm is specified as 15:00, 10am as 10:00.', 'diagnoseo' ); ?></li>
									<li><?php esc_html_e( 'Example: "Tu,Th 16:00-20:00" - Tuesdays and Thursdays 4-8pm', 'diagnoseo' ); ?></li>
									<li><?php esc_html_e( 'Example: "Mo-Su" - Monday through Sunday, all day', 'diagnoseo' ); ?></li>
								</ul>
							<?php $price_range = get_option( 'diagnoseo_schema_business_price_range' ); ?>
							<p><label for="diagnoseo_schema_business_price_range"><?php esc_html_e( 'Price range', 'diagnoseo' ); ?></label></p>
							<select disabled>
								<option value=""><?php esc_html_e( 'N/A', 'diagnoseo' ); ?></option>
							</select>

							<h4>Physical location</h4>
							<p><label for="diagnoseo_schema_business_location_street_address"><?php esc_html_e( 'Street address', 'diagnoseo' ); ?></label></p>
							<input type="text" disabled class="regular-text" />

							<p><label for="diagnoseo_schema_business_location_locality"><?php esc_html_e( 'Locality', 'diagnoseo' ); ?></label></p>
							<input type="text" disabled class="regular-text" />

							<p><label for="diagnoseo_schema_business_location_region"><?php esc_html_e( 'Region', 'diagnoseo' ); ?></label></p>
							<input type="text" disabled class="regular-text" />

							<p><label for="diagnoseo_schema_business_location_postalcode"><?php esc_html_e( 'Postal code', 'diagnoseo' ); ?></label></p>
							<input type="text" disabled class="regular-text" />

							<p><label for="diagnoseo_schema_business_location_country"><?php esc_html_e( 'Country', 'diagnoseo' ); ?></label></p>
							<select disabled>
								<option value=""><?php esc_html_e( 'Select country', 'diagnoseo' ); ?></option>
							</select>
						</td>
					</tr>
				</tbody>
			</table>
		</div>
		<?php
	}
}
