<?php
/**
 * Custom script settings
 *
 * @package DiagnoSEO
 */

if ( ! defined( 'ABSPATH' ) ) {
	die;
}

/**
 * Script settings page
 */
class Diagnoseo_ScriptSettings {

	/**
	 * Hooks actions on object creation
	 */
	public function __construct() {
		global $pagenow;
		if ( 'admin.php' === $pagenow || 'options.php' === $pagenow ) {
			add_action( 'admin_init', array( $this, 'register_settings' ) );
		}
	}

	/**
	 * Renders post meta import page
	 */
	public function render() {
		?>
		<div class="wrap">
			<h1><?php esc_html_e( 'Script Options', 'diagnoseo' ); ?></h1>
			<form method="post" action="options.php" class="diagnoseo-settings-form">
			<?php
			settings_fields( 'diagnoseo_script_options' );
			do_settings_sections( 'diagnoseo_script_options' );
			?>

				<p><?php esc_html_e( 'Additional scripts like analytics or Google Tag Manager.', 'diagnoseo' ); ?></p>
				<table class="form-table" role="presentation">
					<tbody>
						<tr>
							<th><label for="diagnoseo_header_scripts"><?php esc_html_e( 'Header scripts', 'diagnoseo' ); ?></label></th>
							<td><textarea id="diagnoseo_header_scripts" name="diagnoseo_header_scripts" class="regular-text" rows="8"><?php echo esc_textarea( get_option( 'diagnoseo_header_scripts' ) ); ?></textarea></td>
						</tr>
						<tr>
							<th><label for="diagnoseo_body_scripts"><?php esc_html_e( 'Body scripts', 'diagnoseo' ); ?></label></th>
							<td><textarea id="diagnoseo_body_scripts" name="diagnoseo_body_scripts" class="regular-text" rows="8"><?php echo esc_textarea( get_option( 'diagnoseo_body_scripts' ) ); ?></textarea></td>
						</tr>
						<tr>
							<th><label for="diagnoseo_footer_scripts"><?php esc_html_e( 'Footer scripts', 'diagnoseo' ); ?></label></th>
							<td><textarea id="diagnoseo_footer_scripts" name="diagnoseo_footer_scripts" class="regular-text" rows="8"><?php echo esc_textarea( get_option( 'diagnoseo_footer_scripts' ) ); ?></textarea></td>
						</tr>

					</tbody>
				</table>

			<?php submit_button(); ?>
			</form>
		</div>
		<?php
	}

	/**
	 * Registers script settings
	 */
	public function register_settings() {
		add_option( 'diagnoseo_header_scripts', '' );
		register_setting(
			'diagnoseo_script_options',
			'diagnoseo_header_scripts',
			array(
				'type'        => 'string',
				'description' => __( 'Scripts in header.', 'diagnoseo' ),
				'default'     => '',
			)
		);
		add_option( 'diagnoseo_body_scripts', '' );
		register_setting(
			'diagnoseo_script_options',
			'diagnoseo_body_scripts',
			array(
				'type'        => 'string',
				'description' => __( 'Scripts in body.', 'diagnoseo' ),
				'default'     => '',
			)
		);
		add_option( 'diagnoseo_footer_scripts', '' );
		register_setting(
			'diagnoseo_script_options',
			'diagnoseo_footer_scripts',
			array(
				'type'        => 'string',
				'description' => __( 'Scripts in footer.', 'diagnoseo' ),
				'default'     => '',
			)
		);
	}
}
