<?php
/**
 * Sitemap settings
 *
 * @package DiagnoSEO
 */

if ( ! defined( 'ABSPATH' ) ) {
	die;
}

/**
 * Sitemap settings page
 */
class Diagnoseo_SitemapSettings {

	/**
	 * Adds actions to hooks on object creation
	 */
	public function __construct() {
		global $pagenow;
		if ( 'admin.php' === $pagenow || 'options.php' === $pagenow ) {
			add_action( 'admin_init', array( $this, 'register_settings' ) );
		}
	}

	/**
	 * Renders post meta import page
	 */
	public function render() {
		?>
		<div class="wrap">
			<h1><?php esc_html_e( 'Sitemap Options', 'diagnoseo' ); ?></h1>
			<form method="post" action="options.php" class="diagnoseo-settings-form">
			<?php
			settings_fields( 'diagnoseo_sitemap_options' );
			do_settings_sections( 'diagnoseo_sitemap_options' );
			?>

				<table class="form-table" role="presentation">
					<tbody>
						<tr>
							<th><?php esc_html_e( 'Last modified date', 'diagnoseo-pro' ); ?></th>
							<td>
								<p><label for="diagnoseo_sitemap_lastmod"><input type="checkbox" name="diagnoseo_sitemap_lastmod" id="diagnoseo_sitemap_lastmod" value="1" <?php checked( 1, get_option( 'diagnoseo_sitemap_lastmod', true ) ); ?> /><?php echo esc_html_e( 'Show last modified date for posts in site map', 'diagnoseo' ); ?></label></p>
							</td>
						</tr>
					</tbody>
				</table>

			<?php submit_button(); ?>
			</form>
		</div>


		<form id="diagnoseo-sitemap-ping" method="post" action="#diagnoseo-sitemap-ping" class="diagnoseo-sitemap-ping">
			<?php wp_nonce_field( 'diagnoseo_submit_sitemap', 'diagnoseo_submit_sitemap_nonce' ); ?>
			<h2><?php esc_html_e( 'Ping the sitemap to search engines', 'diagnoseo-pro' ); ?></h2>
			<p><b><?php esc_html_e( 'Warning!', 'diagnoseo' ); ?></b> <?php esc_html_e( 'If you use this function too often it may have a negative impact, so male sure every click is justified by valid changes to the sitemap.', 'diagnoseo' ); ?></p>
			<p class="submit"><button type="submit" class="button button-primary" value="ping" name="submit_sitemap" id="submit_sitemap"><?php esc_html_e( 'Ping now', 'diagnoseo' ); ?></button></p>
			<?php
			if ( isset( $_POST['diagnoseo_submit_sitemap_nonce'] ) && wp_verify_nonce( sanitize_text_field( wp_unslash( $_POST['diagnoseo_submit_sitemap_nonce'] ) ), 'diagnoseo_submit_sitemap' ) ) {
				if ( isset( $_POST['submit_sitemap'] ) && 'ping' === $_POST['submit_sitemap'] ) {
					?>
					<p><?php esc_html_e( 'Sending sitemap to search engines...', 'diagnoseo' ); ?></p>
					<?php
					$sitemap_url = get_bloginfo( 'wpurl' ) . '/wp-sitemap.xml';
					$google_data = wp_remote_get( 'http://www.google.com/webmasters/sitemaps/ping?sitemap=' . $sitemap_url );
					$msbing_data = wp_remote_get( 'http://www.bing.com/webmaster/ping.aspx?siteMap=' . $sitemap_url );

					if ( ! empty( $google_data ) ) {
						?>
						<div>
							<h3>Google</h3>
							<?php echo wp_kses_post( $google_data['body'] ); ?>
						</div>
						<?php
					}
					if ( ! empty( $msbing_data ) ) {
						?>
						<div>
							<h3>Bing</h3>
							<?php echo wp_kses_post( $msbing_data['body'] ); ?>
						</div>
						<?php
					}
				}
			}
			?>
		</form>
		<?php
	}

	/**
	 * Registers script settings
	 */
	public function register_settings() {

		add_option( 'diagnoseo_sitemap_lastmod', true );
		register_setting(
			'diagnoseo_sitemap_options',
			'diagnoseo_sitemap_lastmod',
			array(
				'type'        => 'boolean',
				'description' => __( 'Add post last modified date to WP sitemap', 'diagnoseo' ),
				'default'     => true,
			)
		);
	}
}
