<?php
/**
 * Social/OpenGraph settings
 *
 * @package DiagnoSEO
 */

if ( ! defined( 'ABSPATH' ) ) {
	die;
}
/**
 * Schema settings page
 */
class Diagnoseo_SocialSettings {

	/**
	 * Hooks actions on object creation
	 */
	public function __construct() {
		global $pagenow;
		if ( 'admin.php' === $pagenow || 'options.php' === $pagenow ) {
			add_action( 'admin_init', array( $this, 'register_settings' ) );
			add_action( 'admin_enqueue_scripts', 'wp_enqueue_media' );
		}
	}

	/**
	 * Renders schema settings page content
	 */
	public function render() {
		?>
		<div class="wrap">
			<h1><?php esc_html_e( 'OpenGraph and social networks settings', 'diagnoseo' ); ?></h1>
			<form method="post" action="options.php" class="diagnoseo-settings-form">
			<?php
			settings_fields( 'diagnoseo_social_options' );
			do_settings_sections( 'diagnoseo_social_options' );
			$image_placeholder_text = __( 'Upload image. Recommended size: 1200 x 628 px', 'paula' );
			?>
			<div class="diagnoseo-settings-section">
				<div class="diagnoseo-settings">
					<h2><?php esc_html_e( 'OpenGraph meta tags', 'diagnoseo' ); ?></h2>
					<table class="form-table" role="presentation">
						<tbody>
							<tr>
								<th><label for="diagnoseo_facebook_image"><?php esc_html_e( 'Default Facebook image', 'diagnoseo' ); ?></label></th>
								<td class="diagnoseo-image-select">
									<button class="button button-secondary diagnoseo-img-upload"><i class="dashicons dashicons-format-image"></i> <?php esc_html_e( 'Select image', 'diagnoseo' ); ?></button> <button class="button button-secondary diagnoseo-img-remove"><i class="dashicons dashicons-no"></i> <?php esc_html_e( 'Remove image', 'diagnoseo' ); ?></button>
									<div class="diagnoseo-social-image" data-placeholder-text="<?php echo esc_attr( $image_placeholder_text ); ?>">
										<?php
										$fb_image = get_option( 'diagnoseo_facebook_image', '' );
										if ( empty( $fb_image ) ) :
											?>
										<div class="social-image-placeholder">
											<p><?php echo esc_html( $image_placeholder_text ); ?></p>
										</div>
										<?php else : ?>
											<img class="diagnoseo-img" src="<?php echo esc_url( $fb_image ); ?>" />
										<?php endif; ?>
									</div>
									<p><?php esc_html_e( 'Suggested image dimensions: 1200px &times; 628px', 'diagnoseo' ); ?></p>
									<input class="diagnoseo-img-address" type="hidden" name="diagnoseo_facebook_image" id="diagnoseo_facebook_image" value="<?php echo esc_attr( $fb_image ); ?>">
								</td>
							</tr>
							<tr>
								<th><label for="diagnoseo_twitter_image"><?php esc_html_e( 'Default Twitter image', 'diagnoseo' ); ?></label></th>
								<td class="diagnoseo-image-select">
									<button class="button button-secondary diagnoseo-img-upload"><i class="dashicons dashicons-format-image"></i> <?php esc_html_e( 'Select image', 'diagnoseo' ); ?></button> <button class="button button-secondary diagnoseo-img-remove"><i class="dashicons dashicons-no"></i> <?php esc_html_e( 'Remove image', 'diagnoseo' ); ?></button>
									<div class="diagnoseo-social-image" data-placeholder-text="<?php echo esc_attr( $image_placeholder_text ); ?>">
										<?php
										$tt_image = get_option( 'diagnoseo_twitter_image', '' );
										if ( empty( $tt_image ) ) :
											?>
										<div class="social-image-placeholder">
											<p><?php echo esc_html( $image_placeholder_text ); ?></p>
										</div>
										<?php else : ?>
											<img class="diagnoseo-img" src="<?php echo esc_url( $tt_image ); ?>" />
										<?php endif; ?>
									</div>
									<p><?php esc_html_e( 'Suggested image dimensions: 1200px &times; 628px', 'diagnoseo' ); ?></p>
									<input class="diagnoseo-img-address" type="hidden" name="diagnoseo_twitter_image" id="diagnoseo_twitter_image" value="<?php echo esc_attr( $tt_image ); ?>">
								</td>
							</tr>
							<tr>
								<th><label for="diagnoseo_twitter_card"><?php esc_html_e( 'Twitter card type', 'diagnoseo' ); ?></th>
								<td>
									<select name="diagnoseo_twitter_card" id="diagnoseo_twitter_card">
										<option value="summary" <?php selected( 'summary', get_option( 'diagnoseo_twitter_card' ) ); ?>>summary</option>
										<option value="summary_large_image" <?php selected( 'summary_large_image', get_option( 'diagnoseo_twitter_card' ) ); ?>>summary_large_image</option>
									</select>
								</td>
							</tr>
						</tbody>
					</table>
				</div>
			</div>

			<?php do_action( 'diagnoseo_render_social_options' ); ?>

			<?php submit_button(); ?>
			</form>
		</div>
		<?php
	}

	/**
	 * Registers schema options
	 */
	public function register_settings() {

		add_option( 'diagnoseo_facebook_image', '' );
		register_setting(
			'diagnoseo_social_options',
			'diagnoseo_facebook_image',
			array(
				'type'              => 'string',
				'description'       => __( 'Default image for Facebook posts', 'diagnoseo' ),
				'sanitize_callback' => 'sanitize_text_field',
				'show_in_rest'      => true,
				'default'           => '',
			)
		);

		add_option( 'diagnoseo_twitter_image', '' );
		register_setting(
			'diagnoseo_social_options',
			'diagnoseo_twitter_image',
			array(
				'type'              => 'string',
				'description'       => __( 'Default image for Twitter posts', 'diagnoseo' ),
				'sanitize_callback' => 'sanitize_text_field',
				'show_in_rest'      => true,
				'default'           => '',
			)
		);

		add_option( 'diagnoseo_twitter_card', 'summary' );
		register_setting(
			'diagnoseo_social_options',
			'diagnoseo_twitter_card',
			array(
				'type'              => 'string',
				'description'       => __( 'Twitter card type', 'diagnoseo' ),
				'sanitize_callback' => 'sanitize_text_field',
				'show_in_rest'      => true,
				'default'           => 'summary',
			)
		);

		do_action( 'diagnoseo_register_social_options' );
	}
}
