<?php
/**
 * CSS variables
 *
 * @package DiagnoSEO
 */

if ( ! defined( 'ABSPATH' ) ) {
	die;
}

/**
 * Creates a style containing css variables for the plugin
 */
function diagnoseo_css_vars() {
	$css = ":root {\n";

	/* breadcrumbs */
	$breadcrumb_text_color = get_theme_mod( 'diagnoseo_breadcrumbs_color', DIAGNOSEO_BREADCRUMBS_COLOR );
	if ( $breadcrumb_text_color ) {
		$css .= '--bc-text-color: ' . esc_attr( $breadcrumb_text_color ) . ";\n";
	}

	$breadcrumb_link_color = get_theme_mod( 'diagnoseo_breadcrumbs_link_color', DIAGNOSEO_BREADCRUMBS_LINK_COLOR );
	if ( $breadcrumb_link_color ) {
		$css .= '--bc-link-color: ' . esc_attr( $breadcrumb_link_color ) . ";\n";
	}

	$breadcrumb_link_hover_color = get_theme_mod( 'diagnoseo_breadcrumbs_link_hover_color', DIAGNOSEO_BREADCRUMBS_LINK_HOVER_COLOR );
	if ( $breadcrumb_link_hover_color ) {
		$css .= '--bc-link-hover-color: ' . esc_attr( $breadcrumb_link_hover_color ) . ";\n";
	}

	$breadcrumb_bg_color = get_theme_mod( 'diagnoseo_breadcrumbs_bg_color', '#ffffff' );

	$css .= '--bc-background-color: ' . esc_attr( $breadcrumb_bg_color ) . ";\n";

	$breadcrumb_bg_image = get_theme_mod( 'diagnoseo_breadcrumbs_bg_image', false );
	if ( $breadcrumb_bg_image ) {
		$breadcrumb_bg_image = 'none';
	}
	if ( 'none' !== $breadcrumb_bg_image ) {
		$breadcrumb_bg_image = 'url( ' . esc_url( $breadcrumb_bg_image ) . ' )';
	}
	$css .= '--bc-background-image: ' . esc_attr( $breadcrumb_bg_image ) . ";\n";

	$breadcrumb_bg_size = get_theme_mod( 'diagnoseo_breadcrumbs_bg_size', 'auto' );

	$css .= '--bc-background-size: ' . esc_attr( $breadcrumb_bg_size ) . ";\n";

	$breadcrumb_bg_repeat = get_theme_mod( 'diagnoseo_breadcrumbs_bg_repeat', 'repeat' );

	$css .= '--bc-background-repeat: ' . esc_attr( $breadcrumb_bg_repeat ) . ";\n";

	$css .= '}';

	if ( function_exists( 'add_inline_style' ) ) {
		add_inline_style( 'diagnoseo-css-vars', $css );
	} else {
		wp_styles()->add_inline_style( 'diagnoseo-css-vars', $css );
	}

	return $css;
}

add_action( 'wp_enqueue_scripts', 'diagnoseo_css_vars', 1 );
