<?php
/**
 * Customizer settings: breadcrumbs
 *
 * @package DiagnoSEO
 */

/**
 * Registers customizer settings for breadcrumbs
 *
 * @param object $wp_customize Customizer object.
 */
function diagnoseo_customize_register_breadcrumbs( $wp_customize ) {
	$wp_customize->add_section(
		'diagnoseo_breadcrumbs',
		array(
			'title'    => __( 'DiagnoSEO: Breadcrumbs', 'diagnoseo' ),
			'priority' => 70,
		)
	);
	diagnoseo_register_text_setting( 'diagnoseo_breadcrumbs_home', __( 'Home page URL', 'diagnoseo' ), 'diagnoseo_breadcrumbs' );
	diagnoseo_register_text_setting( 'diagnoseo_breadcrumbs_home_label', __( 'Home page label', 'diagnoseo' ), 'diagnoseo_breadcrumbs' );

	diagnoseo_register_checkbox_setting( 'diagnoseo_show_breadcrumbs', __( 'Show breadcrumbs', 'diagnoseo' ), 'diagnoseo_breadcrumbs', __( 'may be overwritten by post/page settings', 'diagnoseo' ) );
	diagnoseo_register_checkbox_setting( 'diagnoseo_show_breadcrumbs_home', __( 'Show breadcrumbs on home page', 'diagnoseo' ), 'diagnoseo_breadcrumbs' );
	diagnoseo_register_checkbox_setting( 'diagnoseo_breadcrumbs_title', __( 'Show current page title', 'diagnoseo' ), 'diagnoseo_breadcrumbs' );
	diagnoseo_register_checkbox_setting( 'diagnoseo_breadcrumbs_border', __( 'Show border', 'diagnoseo' ), 'diagnoseo_breadcrumbs' );

	/* breadcrumb color */
	diagnoseo_register_color_setting( 'diagnoseo_breadcrumbs_color', __( 'Breadcrumbs text color', 'diagnoseo' ), 'diagnoseo_breadcrumbs', '' );

	/* breadcrumb link color */
	diagnoseo_register_color_setting( 'diagnoseo_breadcrumbs_link_color', __( 'Breadcrumbs link color', 'diagnoseo' ), 'diagnoseo_breadcrumbs', '' );
	diagnoseo_register_color_setting( 'diagnoseo_breadcrumbs_link_hover_color', __( 'Breadcrumbs link hover color', 'diagnoseo' ), 'diagnoseo_breadcrumbs', '' );

	/* background color */
	diagnoseo_register_color_setting( 'diagnoseo_breadcrumbs_bg_color', __( 'Breadcrumbs background color', 'diagnoseo' ), 'diagnoseo_breadcrumbs', '', 'postMessage' );

	/* background image */
	$wp_customize->add_setting(
		'diagnoseo_breadcrumbs_bg_image',
		array(
			'sanitize_callback' => 'diagnoseo_sanitize_image',
			'transport'         => 'postMessage',
		)
	);
	$wp_customize->add_control(
		new WP_Customize_Image_Control(
			$wp_customize,
			'diagnoseo_breadcrumbs_bg_image',
			array(
				'label'    => __( 'Breadcrumbs background image', 'diagnoseo' ),
				'section'  => 'diagnoseo_breadcrumbs',
				'settings' => 'diagnoseo_breadcrumbs_bg_image',
			)
		)
	);

	/* background image size */
	$wp_customize->add_setting(
		'diagnoseo_breadcrumbs_bg_size',
		array(
			'default'           => DIAGNOSEO_BREADCRUMBS_BG_SIZE,
			'sanitize_callback' => 'sanitize_text_field',
			'transport'         => 'postMessage',
		)
	);
	$wp_customize->add_control(
		'diagnoseo_breadcrumbs_bg_size',
		array(
			'label'    => __( 'Background image size', 'diagnoseo' ),
			'section'  => 'diagnoseo_breadcrumbs',
			'settings' => 'diagnoseo_breadcrumbs_bg_size',
			'type'     => 'select',
			'choices'  => array(
				'auto'    => __( 'Auto', 'diagnoseo' ),
				'cover'   => __( 'Cover', 'diagnoseo' ),
				'contain' => __( 'Contain', 'diagnoseo' ),
			),
		)
	);

	/* background image repeat */
	$wp_customize->add_setting(
		'diagnoseo_breadcrumbs_bg_repeat',
		array(
			'default'           => DIAGNOSEO_BREADCRUMBS_BG_REPEAT,
			'sanitize_callback' => 'sanitize_text_field',
			'transport'         => 'postMessage',
		)
	);
	$wp_customize->add_control(
		'diagnoseo_breadcrumbs_bg_repeat',
		array(
			'label'    => __( 'Repeat background image', 'diagnoseo' ),
			'section'  => 'diagnoseo_breadcrumbs',
			'settings' => 'diagnoseo_breadcrumbs_bg_repeat',
			'type'     => 'select',
			'choices'  => array(
				'repeat'    => __( 'Repeat', 'diagnoseo' ),
				'repeat-x'  => __( 'Repeat horizontally', 'diagnoseo' ),
				'repeat-y'  => __( 'Repeat vertically', 'diagnoseo' ),
				'no-repeat' => __( 'Don\'t repeat', 'diagnoseo' ),
			),
		)
	);

	$wp_customize->add_setting(
		'diagnoseo_breadcrumbs_separator',
		array(
			'sanitize_callback' => 'sanitize_text_field',
			'default'           => DIAGNOSEO_BREADCRUMBS_SEPARATOR,
		)
	);
	$wp_customize->add_control(
		'diagnoseo_breadcrumbs_separator',
		array(
			'label'       => __( 'Breadcrumbs separator', 'diagnoseo' ),
			'section'     => 'diagnoseo_breadcrumbs',
			'settings'    => 'diagnoseo_breadcrumbs_separator',
			'description' => __( 'Examples: >, /, etc.', 'diagnoseo' ),
		)
	);
}

add_action( 'customize_register', 'diagnoseo_customize_register_breadcrumbs' );
