<?php
/**
 * Functions and custom controls for customizer
 *
 * @package DiagnoSEO
 */

?>
<?php

/**
 * Registers color setting
 *
 * @param string $name Setting name.
 * @param string $label Control label text.
 * @param string $section Customizer section slug.
 * @param string $description Control description text.
 * @param string $transport Use 'postMessage' value to avoid reloading on change.
 */
function diagnoseo_register_color_setting( $name, $label, $section, $description = '', $transport = 'refresh' ) {
	global $wp_customize;
	$wp_customize->add_setting(
		$name,
		array(
			'sanitize_callback' => 'sanitize_hex_color',
			'default'           => constant( strtoupper( $name ) ),
			'transport'         => $transport,
		)
	);
	$setting_data = array(
		'label'    => $label,
		'section'  => $section,
		'settings' => $name,
	);

	if ( ! empty( $description ) ) {
		$setting_data['description'] = $description;
	}
	$wp_customize->add_control(
		new WP_Customize_Color_Control(
			$wp_customize,
			$name,
			$setting_data
		)
	);
}

/**
 * Registers checkbox setting
 *
 * @param String $name Setting name.
 * @param String $label Control label text.
 * @param String $section Customizer section slug.
 * @param String $description Control description text.
 */
function diagnoseo_register_checkbox_setting( $name, $label, $section, $description = '' ) {
	global $wp_customize;
	$wp_customize->add_setting(
		$name,
		array(
			'sanitize_callback' => 'diagnoseo_sanitize_checkbox',
			'default'           => constant( strtoupper( $name ) ),
		)
	);
	$wp_customize->add_control(
		$name,
		array(
			'label'       => $label,
			'section'     => $section,
			'settings'    => $name,
			'type'        => 'checkbox',
			'description' => $description,
		)
	);
}

/**
 * Registers text setting
 *
 * @param String $name Setting name.
 * @param String $label Control label text.
 * @param String $section Customizer section slug.
 * @param String $description Control description text.
 */
function diagnoseo_register_text_setting( $name, $label, $section, $description = '' ) {
	global $wp_customize;
	$wp_customize->add_setting(
		$name,
		array(
			'sanitize_callback' => 'sanitize_text_field',
			'default'           => constant( strtoupper( $name ) ),
		)
	);
	$wp_customize->add_control(
		$name,
		array(
			'label'       => $label,
			'section'     => $section,
			'settings'    => $name,
			'description' => $description,
		)
	);
}

/**
 * Sanitizes checkbox value
 *
 * @param boolean $checked Checkbox value.
 */
function diagnoseo_sanitize_checkbox( $checked ) {
	return isset( $checked ) && ( true === $checked || 1 === $checked );
}

/**
 * Sanitizes image value
 *
 * @param string $image Image url.
 * @param object $setting Setting object.
 */
function diagnoseo_sanitize_image( $image, $setting ) {
	$mimes = array(
		'jpg|jpeg|jpe' => 'image/jpeg',
		'gif'          => 'image/gif',
		'png'          => 'image/png',
		'ico'          => 'image/x-icon',
	);
	$file  = wp_check_filetype( $image, $mimes );
	return ( $file['ext'] ? $image : $setting->default );
}
