<?php
/**
 * Content watcher sidebar in editor
 *
 * @package DiagnoSEO
 */

if ( ! defined( 'ABSPATH' ) ) {
	die;
}

/**
 * Registers the content watcher editor sidebar
 */
function diagnoseo_register_editor_sidebar() {
	$debug_suffix = WP_DEBUG ? '?v=' . time() : '';

	register_post_meta(
		'',
		'diagnoseo_meta_keyword',
		array(
			'auth_callback'     => function() {
				return current_user_can( 'edit_posts' );
			},
			'sanitize_callback' => 'sanitize_text_field',
			'show_in_rest'      => true,
			'single'            => true,
			'type'              => 'string',
		)
	);

	register_post_meta(
		'',
		'diagnoseo_meta_additional_keywords',
		array(
			'auth_callback'     => function() {
				return current_user_can( 'edit_posts' );
			},
			'sanitize_callback' => 'sanitize_text_field',
			'show_in_rest'      => true,
			'single'            => true,
			'type'              => 'string',
		)
	);

	register_post_meta(
		'',
		'diagnoseo_meta_title',
		array(
			'show_in_rest' => true,
			'single'       => true,
			'type'         => 'string',
		)
	);

	register_post_meta(
		'',
		'diagnoseo_meta_description',
		array(
			'show_in_rest' => true,
			'single'       => true,
			'type'         => 'string',
		)
	);

	register_post_meta(
		'',
		'diagnoseo_check_result',
		array(
			'show_in_rest' => true,
			'single'       => true,
			'type'         => 'string',
		)
	);

	register_post_meta(
		'',
		'diagnoseo_optimal_word_number',
		array(
			'show_in_rest' => true,
			'single'       => true,
			'type'         => 'string',
		)
	);
	register_post_meta(
		'',
		'diagnoseo_optimal_heading_number',
		array(
			'show_in_rest' => true,
			'single'       => true,
			'type'         => 'string',
		)
	);
	register_post_meta(
		'',
		'diagnoseo_optimal_image_number',
		array(
			'show_in_rest' => true,
			'single'       => true,
			'type'         => 'string',
		)
	);
	register_post_meta(
		'',
		'diagnoseo_optimal_keyword_density',
		array(
			'show_in_rest' => true,
			'single'       => true,
			'type'         => 'string',
		)
	);

	register_post_meta(
		'',
		'diagnoseo_og_image',
		array(
			'show_in_rest' => true,
			'single'       => true,
			'type'         => 'string',
		)
	);
}
add_action( 'init', 'diagnoseo_register_editor_sidebar' );

/**
 * Enqueues sidebar scripts
 */
function diagnoseo_enqueue_sidebar() {

	$debug_suffix = WP_DEBUG ? '?v=' . time() : '';

	wp_register_script(
		'diagnoseo-check-config',
		DIAGNOSEO_PLUGIN_URL . 'js/diagnoseo-checks.min.js' . $debug_suffix,
		array( 'wp-i18n' ),
		1,
		true
	);
	wp_register_script(
		'diagnoseo-content-watcher',
		DIAGNOSEO_PLUGIN_URL . 'js/build/index.js' . $debug_suffix,
		array( 'diagnoseo-check-config', 'wp-plugins', 'wp-edit-post', 'wp-element', 'wp-components', 'wp-data', 'wp-compose', 'wp-i18n', 'wp-core-data' ),
		1,
		true
	);

	wp_enqueue_script(
		'diagnoseo-check-config'
	);
	wp_enqueue_script(
		'diagnoseo-content-watcher'
	);
	$ok = wp_localize_script(
		'diagnoseo-content-watcher',
		'diagnoseo_settings',
		array(
			'api_key' => get_option( 'diagnoseo_api_key' ),
			'locale'  => get_locale(),
		)
	);
}

add_action( 'enqueue_block_editor_assets', 'diagnoseo_enqueue_sidebar' );
