<?php
/**
 * IndexNow scripts
 *
 * @package DiagnoSEO
 */

if ( ! defined( 'ABSPATH' ) ) {
	die;
}

/**
 * Submits the post to search engines
 *
 * @param Integer $post_id The ID of the post to submit.
 * @param Object  $post The post object.
 * @param Boolean $is_update Whether this is an update or new post.
 */
function diagnoseo_indexnow_submit( $post_id, $post, $is_update ) {
	$api_key  = get_option( 'diagnoseo_indexnow_apikey' );
	$post_url = get_the_permalink( $post_id );

	if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) {
		return;
	}
	if ( ! isset( $_POST['index_now_submit_nonce'] ) || ! wp_verify_nonce( sanitize_text_field( wp_unslash( $_POST['index_now_submit_nonce'] ) ), 'index_now_submit' ) ) {
		return;
	}
	if ( empty( $_POST['post_type'] ) || 'page' === $_POST['post_type'] ) {
		if ( ! current_user_can( 'edit_page', $post_id ) ) {
			return;
		}
	} else {
		if ( ! current_user_can( 'edit_post', $post_id ) ) {
			return;
		}
	}

	if ( ! isset( $_POST['diagnoseo_index_now'] ) || empty( $_POST['diagnoseo_index_now'] ) || empty( $api_key ) ) {
		return;
	}

	$search_engines = array(
		'https://bing.com',
		'https://yandex.com',
	);

	foreach ( $search_engines as $engine ) {
		$url = $engine . '/indexnow?url=' . get_the_permalink( $post_id ) . '&key=' . $api_key;
		$ok  = wp_remote_get( $url );
	}
}

add_action( 'save_post', 'diagnoseo_indexnow_submit', 90, 3 );
