<?php
/**
 * Post SEO options metabox
 *
 * @package DiagnoSEO
 */

if ( ! defined( 'ABSPATH' ) ) {
	die;
}

add_action( 'add_meta_boxes', 'diagnoseo_seo_settings_metabox', 0, 2 );
add_action( 'save_post', 'diagnoseo_save_seo_settings_metabox' );
add_action( 'init', 'diagnoseo_register_social_fields' );

/**
 * Adds SEO metabox to post edit page
 */
function diagnoseo_seo_settings_metabox() {
	$post_types    = get_post_types( array(), 'names' );
	$metabox_title = function_exists( 'diagnoseo_pro_init' ) ? esc_html( 'DiagnoSEO Pro' ) : esc_html( 'DiagnoSEO' );
	add_meta_box( 'seo-options', $metabox_title, 'diagnoseo_draw_post_metabox', $post_types, 'normal', 'high' );
}

/**
 * Displays the SEO options metabox
 *
 * @param StdClass $post Post object.
 */
function diagnoseo_draw_post_metabox( $post ) {
	global $post;
	$data                 = get_post_custom( $post->ID );
	$title                = isset( $data['diagnoseo_meta_title'] ) ? $data['diagnoseo_meta_title'][0] : '';
	$description          = isset( $data['diagnoseo_meta_description'] ) ? $data['diagnoseo_meta_description'][0] : '';
	$canonical            = isset( $data['diagnoseo_meta_canonical'] ) ? $data['diagnoseo_meta_canonical'][0] : '';
	$robots_index         = isset( $data['diagnoseo_meta_robots_index'] ) ? $data['diagnoseo_meta_robots_index'][0] : '';
	$robots_follow        = isset( $data['diagnoseo_meta_robots_follow'] ) ? $data['diagnoseo_meta_robots_follow'][0] : '';
	$exclude_postlist     = isset( $data['diagnoseo_meta_exclude_postlist'] ) ? $data['diagnoseo_meta_exclude_postlist'][0] : '';
	$exclude_search       = isset( $data['diagnoseo_meta_exclude_search'] ) ? $data['diagnoseo_meta_exclude_search'][0] : '';
	$slug                 = $post->post_name;
	$twitter_title        = isset( $data['diagnoseo_meta_twitter_title'] ) ? $data['diagnoseo_meta_twitter_title'][0] : '';
	$twitter_description  = isset( $data['diagnoseo_meta_twitter_description'] ) ? $data['diagnoseo_meta_twitter_description'][0] : '';
	$twitter_card_type    = isset( $data['diagnoseo_meta_twitter_card'] ) ? $data['diagnoseo_meta_twitter_card'][0] : '';
	$facebook_title       = isset( $data['diagnoseo_meta_facebook_title'] ) ? $data['diagnoseo_meta_facebook_title'][0] : '';
	$facebook_description = isset( $data['diagnoseo_meta_facebook_description'] ) ? $data['diagnoseo_meta_facebook_description'][0] : '';

	wp_nonce_field( 'diagnoseo_seo_nonce', 'seo_nonce' );
	?>
	<div class="diagnoseo-post-meta">
		<div class="diagnoseo-meta-form">
			<div class="components-base-control">
				<div class="components-base-control__field">
					<div class="diagnoseo-label label-title">
						<label for="seo-title" class="components-base-control__label"><?php esc_html_e( 'Title', 'diagnoseo' ); ?></label>
						<span class	="info">Width: <span class="info-width info-title-width">0</span>px, Characters: <span class="info-chars info-title-chars">0</span></span>
					</div>

					<div class="diagnoseo-progress seo-title-progress">
						<div class="diagnoseo-progress-fill"></div>
					</div>
					<div class="diagnoseo-var-input">
						<textarea name="seo-title" id="seo-title" rows="2" cols="30" class="components-textarea-control__input widefat var-input" placeholder="<?php echo esc_attr( diagnoseo_get_title_template() ); ?>"><?php echo esc_textarea( $title ); ?></textarea>
						<select id="seo-title-vars" class="var-select">
							<option value=""><?php esc_html_e( 'Select variable', 'diagnoseo' ); ?></option>
							<option value="%sep%"><?php esc_html_e( 'Separator', 'diagnoseo' ); ?></option>
							<option value="%title%"><?php esc_html_e( 'Post/page title', 'diagnoseo' ); ?></option>
							<option value="%page%"><?php esc_html_e( 'Page number', 'diagnoseo' ); ?></option>
							<option value="%sitename%"><?php esc_html_e( 'Site title', 'diagnoseo' ); ?></option>
							<option value="%tagline%"><?php esc_html_e( 'Tagline', 'diagnoseo' ); ?></option>
							<option value="%currentyear%"><?php esc_html_e( 'Current year', 'diagnoseo' ); ?></option>
							<option value="%currentmonth%"><?php esc_html_e( 'Current month', 'diagnoseo' ); ?></option>
						</select><button class="var-button button"><?php esc_html_e( 'Insert', 'diagnoseo' ); ?></button>
					</div>
				</div>
				<div class="components-base-control__field">
					<div class="diagnoseo-label">
						<label for="seo-description" class="components-base-control__label"><?php esc_html_e( 'Description', 'diagnoseo' ); ?></label>
						<span class	="info">Width: <span class="info-width info-descr-width">0</span>px, Characters: <span class="info-chars info-descr-chars">0</span></span>
					</div>
					<div class="diagnoseo-progress seo-descr-progress">
						<div class="diagnoseo-progress-fill"></div>
					</div>
					<div class="diagnoseo-var-input">
						<textarea name="seo-description" id="seo-description" rows="6" cols="30" class="components-textarea-control__input widefat var-input" placeholder="<?php echo esc_attr( diagnoseo_get_description_template() ); ?>"><?php echo esc_textarea( $description ); ?></textarea>
						<select id="seo-descr-vars" class="var-select">
							<option value=""><?php esc_html_e( 'Select variable', 'diagnoseo' ); ?></option>
							<option value="%excerpt%"><?php esc_html_e( 'Excerpt', 'diagnoseo' ); ?></option>
							<option value="%sep%"><?php esc_html_e( 'Separator', 'diagnoseo' ); ?></option>
							<option value="%title%"><?php esc_html_e( 'Post/page title', 'diagnoseo' ); ?></option>
							<option value="%sitename%"><?php esc_html_e( 'Site title', 'diagnoseo' ); ?></option>
							<option value="%tagline%"><?php esc_html_e( 'Tagline', 'diagnoseo' ); ?></option>
							<option value="%currentyear%"><?php esc_html_e( 'Current year', 'diagnoseo' ); ?></option>
							<option value="%currentmonth%"><?php esc_html_e( 'Current month', 'diagnoseo' ); ?></option>
						</select><button class="var-button button"><?php esc_html_e( 'Insert', 'diagnoseo' ); ?></button>
					</div>
				</div>
				<div class="components-base-control__field">
					<div class="diagnoseo-label label-slug">
						<label for="seo-slug" class="components-base-control__label"><?php esc_html_e( 'URL slug', 'diagnoseo' ); ?></label>
						<span class	="info">Characters: <span class="info-chars info-slug-chars">0</span></span>
					</div>
					<div class="diagnoseo-progress seo-slug-progress">
						<div class="diagnoseo-progress-fill"></div>
					</div>

					<input name="seo-slug" id="seo-slug" class="components-textarea-control__input widefat" value="<?php echo esc_textarea( $slug ); ?>" />
					<?php if ( ! empty( get_option( 'diagnoseo_indexnow_apikey' ) ) ) : ?>
						<?php wp_nonce_field( 'index_now_submit', 'index_now_submit_nonce' ); ?>
					<label><input type="checkbox" name="diagnoseo_index_now" id="diagnoseo_index_now" value="1" /> <b><?php esc_html_e( 'IndexNow', 'diagnoseo' ); ?></b> <?php esc_html_e( 'Check this to make search engines crawl this page sooner. Search engines supporting the IndexNow protocol will prioritize this URL over other addresses they know.', 'diagnoseo' ); ?> <a href="https://www.indexnow.org" target="_blank"><?php esc_html_e( 'More info on IndexNow protocol', 'diagnoseo' ); ?></a></label>
					<?php endif; ?>
				</div>
			</div>
		</div>
		<?php
		$post_title           = $post->post_title;
		$post_type            = $post->post_type;
		$excerpt              = $post->post_excerpt;
		$site_title           = get_bloginfo( 'name' );
		$title_fallback       = $post_title ? 'Untitled - ' . $site_title : $post_title . ' - ' . $site_title;
		$description_fallback = $excerpt;
		$canonical_fallback   = wp_get_canonical_url( $post );
		$separator            = get_option( 'diagnoseo_separator', '-' );
		$post_list_title      = isset( $data['diagnoseo_postlist_title'] ) ? $data['diagnoseo_postlist_title'][0] : '';
		?>
		<div class="diagnoseo-preview"
			data-excerpt="<?php echo esc_attr( $excerpt ); ?>"
			data-separator="<?php echo esc_attr( $separator ); ?>"
			data-post-title="<?php echo esc_attr( $post_title ); ?>"
			data-site="<?php echo esc_attr( get_bloginfo( 'name' ) ); ?>"
			data-site-tagline="<?php echo esc_attr( get_bloginfo( 'description' ) ); ?>"
			data-post-list-title="<?php echo esc_attr( $post_list_title ); ?>"
		>
			<?php
			$preview_title = $title ? $title : $title_fallback;
			$preview_descr = $description ? $description : $description_fallback;
			?>
			<h4><?php esc_html_e( 'Desktop Snippet Preview', 'diagnoseo' ); ?></h4>
			<div class="search-results">
				<div class="search-result">
					<div class="search-result-url"><?php echo wp_kses_post( diagnoseo_canonical_preview( $canonical_fallback ) ); ?></div>
					<div class="search-result-title" data-fallback="<?php echo esc_attr( $title_fallback ); ?>"><?php echo esc_html( $preview_title ); ?></div>
					<div class="search-result-descr" data-fallback="<?php echo esc_attr( $description_fallback ); ?>"><?php echo esc_html( diagnoseo_truncate_text( $preview_descr, 158 ) ); ?></div>
				</div>
				<div class="text-measuring">
					<div class="title-sample"><?php echo esc_html( $preview_title ); ?></div>
					<div class="description-sample"><?php echo esc_html( $preview_descr ); ?></div>
				</div>
			</div>
			<h4><?php esc_html_e( 'Mobile Snippet Preview', 'diagnoseo' ); ?></h4>
			<div class="search-results">
				<div class="search-result mobile">
					<div class="search-result-url"><img src="<?php echo esc_url( DIAGNOSEO_PLUGIN_URL ); ?>/assets/favicon.png" class="url-icon" width="16" height="16" /><?php echo wp_kses_post( diagnoseo_canonical_preview( $canonical_fallback ) ); ?></div>
					<div class="search-result-title" data-fallback="<?php echo esc_attr( $title_fallback ); ?>"><?php echo esc_html( $preview_title ); ?></div>
					<div class="search-result-descr" data-fallback="<?php echo esc_attr( $description_fallback ); ?>"><?php echo esc_html( diagnoseo_truncate_text( $preview_descr, 158 ) ); ?></div>
				</div>
			</div>
		</div>

		<div class="toggle">
			<a class="toggle-trigger" href="#"><?php esc_html_e( 'Advanced SEO settings', 'diagnoseo' ); ?></a>
			<div class="toggle-content diagnoseo-form">
				<div class="components-base-control__field">
					<label for="seo-canonical" class="components-base-control__label"><?php esc_html_e( 'Canonical', 'diagnoseo' ); ?></label>
					<input name="seo-canonical" id="seo-canonical" class="components-textarea-control__input widefat" value="<?php echo esc_textarea( $canonical ); ?>" placeholder="<?php echo esc_url( $canonical_fallback ); ?>" />
				</div>

				<div class="components-base-control__field">
					<label class="components-base-control__label"><?php esc_html_e( 'Meta robots (index)', 'diagnoseo' ); ?></label>
					<select name="seo-robots-index" id="seo-robots-index">
						<option value="" <?php selected( empty( $robots_index ), true ); ?>><?php esc_html_e( 'Default', 'diagnoseo' ); ?> (<?php echo esc_html( get_option( 'diagnoseo_' . $post_type . '_index', 'index' ) ); ?>)</option>
						<option value="index" <?php selected( 'index', $robots_index ); ?>><?php esc_html_e( 'index', 'diagnoseo' ); ?></option>
						<option value="noindex" <?php selected( 'noindex', $robots_index ); ?>><?php esc_html_e( 'noindex', 'diagnoseo' ); ?></option>
					</select>
				</div>
				<div class="components-base-control__field">
					<label class="components-base-control__label"><?php esc_html_e( 'Meta robots (follow)', 'diagnoseo' ); ?></label>
					<select name="seo-robots-follow" id="seo-robots-follow">
						<option value="" <?php selected( empty( $robots_follow ), true ); ?>><?php esc_html_e( 'Default', 'diagnoseo' ); ?> (<?php echo esc_html( get_option( 'diagnoseo_' . $post_type . '_follow', 'follow' ) ); ?>)</option>
						<option value="follow" <?php selected( 'follow', $robots_follow ); ?>><?php esc_html_e( 'follow', 'diagnoseo' ); ?></option>
						<option value="nofollow" <?php selected( 'nofollow', $robots_follow ); ?>><?php esc_html_e( 'nofollow', 'diagnoseo' ); ?></option>
					</select>
				</div>
				<div class="components-base-control__field">
					<label class="components-base-control__label">
						<input type="checkbox" value="1" name="seo-exclude-postlist" id="seo-exclude-postlist" <?php checked( false, empty( $exclude_postlist ) ); ?> />
						<?php esc_html_e( 'Exclude post/page from archives and home page', 'diagnoseo' ); ?></label>
				</div>
				<div class="components-base-control__field">
					<label class="components-base-control__label">
						<input type="checkbox" value="1" name="seo-exclude-search" id="seo-exclude-search" <?php checked( false, empty( $exclude_search ) ); ?> />
						<?php esc_html_e( 'Exclude post/page from search', 'diagnoseo' ); ?></label>
				</div>

				<?php if ( ! function_exists( 'diagnoseo_pro_init' ) ) : ?>
					<div class="components-base-control__field">
						<label for="postlist-title" class="components-base-control__label"><?php esc_html_e( 'Anchor text used in post lists', 'diagnoseo' ); ?> <b>(<a href="https://diagnoseo.com/wordpress-seo-plugin/?utm_source=wp&utm_medium=link&utm_campaign=available_in_pro" target="_blank" rel="noreferrer noopener"><?php esc_html_e( 'Available in Pro', 'diagnoseo' ); ?></a>)</b></label>
						<input disabled type="text" class="components-textarea-control__input widefat" placeholder="<?php echo esc_attr( $post_title ); ?>" />
					</div>
					<div class="components-base-control__field">
						<label for="redirect-to" class="components-base-control__label"><?php esc_html_e( 'Redirect to URL:', 'diagnoseo' ); ?> <b>(<a href="https://diagnoseo.com/wordpress-seo-plugin/?utm_source=wp&utm_medium=link&utm_campaign=available_in_pro" target="_blank" rel="noreferrer noopener"><?php esc_html_e( 'Available in Pro', 'diagnoseo' ); ?></a>)</b></label>
						<input disabled type="url" class="components-textarea-control__input widefat" />
						<label for="redirect-to-status" class="components-base-control__label"><?php esc_html_e( 'Redirection status', 'diagnoseo' ); ?></label>
						<select disabled class="widefat">
							<option value="301">301 - Moved permanently</option>
						</select>
					</div>
				<?php endif; ?>

				<?php do_action( 'diagnoseo_after_advanced_seo_settings' ); ?>
			</div>
		</div>
		<div class="toggle">
			<a class="toggle-trigger" href="#"><?php esc_html_e( 'Social settings', 'diagnoseo' ); ?></a>
			<div class="toggle-content diagnoseo-form">
				<?php
					$social_placeholder_text  = __( 'Upload post featured image. Recommended size: 1200 x 628 px', 'paula' );
					$social_title_placeholder = $title ? $title : diagnoseo_get_title_template();
					$social_descr_placeholder = $description ? $description : diagnoseo_get_description_template();
				?>
				<div class="diagnoseo-social-settings">
					<div class="diagnoseo-social-form-fields">
						<div class="components-base-control__field">
							<label for="facebook-title" class="components-base-control__label"><?php esc_html_e( 'Facebook title', 'diagnoseo' ); ?></label>
							<input name="facebook-title" id="facebook-title" class="components-textarea-control__input widefat diagnoseo-social-meta" data-custom-field="diagnoseo_meta_facebook_title" value="<?php echo esc_textarea( $facebook_title ); ?>" placeholder="<?php echo esc_attr( $social_title_placeholder ); ?>" />
						</div>
						<div class="components-base-control__field">
							<label for="facebook-description" class="components-base-control__label"><?php esc_html_e( 'Facebook description', 'diagnoseo' ); ?></label>
							<textarea name="facebook-description" id="facebook-description" rows="4" cols="30" class="components-textarea-control__input widefat diagnoseo-social-meta" data-custom-field="diagnoseo_meta_facebook_description" placeholder="<?php echo esc_attr( $social_descr_placeholder ); ?>"><?php echo esc_textarea( $facebook_description ); ?></textarea>
						</div>
					</div>
					<div class="diagnoseo-social-preview preview-facebook"
						data-default-image="<?php echo esc_url( get_option( 'diagnoseo_facebook_image', '' ) ); ?>"
						data-placeholder-text="<?php echo esc_attr( $social_placeholder_text ); ?>"
						data-facebook-title="<?php echo esc_attr( $facebook_title ); ?>"
						data-facebook-descr="<?php echo esc_attr( $facebook_description ); ?>"
					>
						<div class="facebook-post">
							<div class="facebook-post-header">
								<div class="avatar"></div>
								<div class="facebook-post-meta">
									<div class="user">
										<?php
										$user = wp_get_current_user();
										echo esc_html( $user->display_name );
										?>
									</div>
									<div class="time">
										<span>2 hrs</span>
										<span><i class="dashicons dashicons-admin-site"></i></span>
									</div>
								</div>
							</div>

							<div class="facebook-post-image preview-image">
								<?php
								if ( has_post_thumbnail() ) {
									the_post_thumbnail( array( 1200, 628 ) );
								} else {
									?>
									<div class="social-image-placeholder">
										<p><?php echo esc_html( $social_placeholder_text ); ?></p>
									</div>
									<?php
								}
								?>
							</div>
							<div class="facebook-post-content">
								<?php if ( isset( $_SERVER['SERVER_NAME'] ) ) : ?>
								<h4 class="publisher"><?php echo esc_html( sanitize_text_field( wp_unslash( $_SERVER['SERVER_NAME'] ) ) ); ?></h4>
								<?php endif; ?>
								<h3 class="facebook-post-title"><?php echo empty( $facebook_title ) ? esc_html( $post->post_title ) : esc_html( $facebook_title ); ?></h3>
								<div class="facebook-post-description"><?php echo wp_kses_post( $facebook_description ); ?></div>
							</div>
						</div>
					</div>
				</div>

				<div class="diagnoseo-social-settings">
					<div class="diagnoseo-social-form-fields">
						<div class="components-base-control__field">
							<label for="twitter-title" class="components-base-control__label"><?php esc_html_e( 'Twitter title', 'diagnoseo' ); ?></label>
							<input name="twitter-title" id="twitter-title" class="components-textarea-control__input widefat diagnoseo-social-meta" data-custom-field="diagnoseo_meta_twitter_title" value="<?php echo esc_textarea( $twitter_title ); ?>" placeholder="<?php echo esc_attr( $social_title_placeholder ); ?>" />
						</div>
						<div class="components-base-control__field">
							<label for="twitter-description" class="components-base-control__label"><?php esc_html_e( 'Twitter description', 'diagnoseo' ); ?></label>
							<textarea name="twitter-description" id="twitter-description" rows="4" cols="30" class="components-textarea-control__input widefat diagnoseo-social-meta" data-custom-field="diagnoseo_meta_twitter_description" placeholder="<?php echo esc_attr( $social_descr_placeholder ); ?>"><?php echo esc_textarea( $twitter_description ); ?></textarea>
						</div>
					</div>
					<div class="diagnoseo-social-preview preview-twitter"
						data-default-image="<?php echo esc_url( get_option( 'diagnoseo_twitter_image', '' ) ); ?>"
						data-placeholder-text="<?php echo esc_attr( $social_placeholder_text ); ?>"
						data-twitter-title="<?php echo esc_attr( $twitter_title ); ?>"
						data-twitter-descr="<?php echo esc_attr( $twitter_description ); ?>"
					>
					<div class="twitter-post">
						<div class="twitter-post-header">
							<div class="avatar"></div>
							<div class="twitter-post-meta">
								<div class="user">
									<span class="screen-name">
									<?php
									$user = wp_get_current_user();
									echo esc_html( $user->display_name );
									?>
									</span> <span class="twitter-username">@username</span> &middot; <span class="time">2h</span>
								</div>
								<div class="social-text"><?php esc_html_e( 'The Twitter card for your page will look like this:', 'diagnoseo' ); ?></div>
							</div>
						</div>

						<div class="twitter-post-content">
							<div class="twitter-post-image preview-image">
								<?php
								if ( has_post_thumbnail() ) {
									the_post_thumbnail( array( 1200, 628 ) );
								} else {
									?>
									<div class="social-image-placeholder">
										<p><?php echo esc_html( $social_placeholder_text ); ?></p>
									</div>
									<?php
								}
								?>
							</div>
							<h3 class="twitter-post-title"><?php echo empty( $twitter_title ) ? esc_html( $post->post_title ) : esc_html( $twitter_title ); ?></h3>
							<div class="twitter-post-description"><?php echo wp_kses_post( $twitter_description ); ?></div>
							<div class="publisher"><i class="dashicons dashicons-admin-links"></i> <?php echo esc_html( sanitize_text_field( wp_unslash( $_SERVER['SERVER_NAME'] ) ) ); ?></div>
							</div>
						</div>
					</div>
				</div>

				<?php do_action( 'diagnoseo_after_social_seo_settings' ); ?>
			</div>
		</div>
		<div class="toggle">
			<a class="toggle-trigger" href="#"><?php esc_html_e( 'Schema', 'diagnoseo' ); ?></a>
			<div class="toggle-content diagnoseo-form">
			<?php
				$post_type        = get_post_type( $post->ID );
				$post_schema_type = isset( $data['diagnoseo_schema_type'] ) ? $data['diagnoseo_schema_type'][0] : '';
				$post_schema_data = isset( $data['diagnoseo_schema_data'] ) ? $data['diagnoseo_schema_data'][0] : '';
				$schema_types     = Diagnoseo_SettingsHelper::$post_schema_types;

				$def_schema_type = get_option( 'diagnoseo_' . $post_type . '_schema_type', '' );
			?>
				<div class="diagnoseo-schema-generator" data-schema-data="<?php echo esc_attr( $post_schema_data ); ?>" data-default-schema-type="<?php echo esc_attr( $def_schema_type ); ?>">
					<div class="components-base-control">
						<div class="components-base-control__field">
							<label for="schema-type" class="components-base-control__label"><?php esc_html_e( 'Schema type', 'diagnoseo' ); ?></label>
							<select id="schema-type" name="schema-type" class="widefat">
								<?php
								$def_schema_type_caption = $def_schema_type ? $def_schema_type : __( 'None', 'diagnoseo' );
								?>
								<option value=""><?php esc_html_e( 'Default', 'diagnoseo' ); ?> (<?php echo esc_html( $def_schema_type_caption ); ?>)</option>
								<option value="none"><?php esc_html_e( 'None', 'diagnoseo' ); ?></option>
								<?php foreach ( $schema_types as $type ) : ?>
									<option value="<?php echo esc_attr( $type ); ?>" <?php selected( $type, $post_schema_type ); ?>><?php echo esc_html( $type ); ?></option>
								<?php endforeach; ?>
							</select>
							<input type="hidden" name="schema-data" id="schema-data" value="<?php echo esc_attr( $post_schema_data ); ?>" />
						</div>
					</div>
					<?php $is_pro = function_exists( 'diagnoseo_pro_init' ) ? 1 : 0; ?>
					<div class="diagnoseo-schema-fields" data-pro="<?php echo esc_attr( $is_pro ); ?>">

					</div>
				</div>
			</div>
		</div>
		<?php do_action( 'diagnoseo_after_post_meta_toggles' ); ?>
	</div>
	<?php
}

/**
 * Saves data entered in the metabox form
 *
 * @param Integer $post_id ID of the currently edited post.
 */
function diagnoseo_save_seo_settings_metabox( $post_id ) {
	if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) {
		return;
	}
	if ( ! isset( $_POST['seo_nonce'] ) || ! wp_verify_nonce( sanitize_text_field( wp_unslash( $_POST['seo_nonce'] ) ), 'diagnoseo_seo_nonce' ) ) {
		return;
	}
	if ( ! current_user_can( 'edit_pages', $post_id ) ) {
		return;
	}

	if ( isset( $_POST['seo-title'] ) ) {
		diagnoseo_save_meta_text( $post_id, 'diagnoseo_meta_title', sanitize_text_field( wp_unslash( $_POST['seo-title'] ) ) );
	}

	if ( isset( $_POST['seo-description'] ) ) {
		diagnoseo_save_meta_text( $post_id, 'diagnoseo_meta_description', sanitize_text_field( wp_unslash( $_POST['seo-description'] ) ) );
	}

	if ( isset( $_POST['seo-canonical'] ) ) {
		diagnoseo_save_meta_text( $post_id, 'diagnoseo_meta_canonical', sanitize_text_field( wp_unslash( $_POST['seo-canonical'] ) ) );
	}

	if ( isset( $_POST['seo-robots-index'] ) ) {
		diagnoseo_save_meta_text( $post_id, 'diagnoseo_meta_robots_index', sanitize_title( wp_unslash( $_POST['seo-robots-index'] ) ) );
	}

	if ( isset( $_POST['seo-robots-follow'] ) ) {
		diagnoseo_save_meta_text( $post_id, 'diagnoseo_meta_robots_follow', sanitize_title( wp_unslash( $_POST['seo-robots-follow'] ) ) );
	}

	if ( isset( $_POST['seo-exclude-postlist'] ) ) {
		update_post_meta( $post_id, 'diagnoseo_meta_exclude_postlist', 1 );
	} else {
		delete_post_meta( $post_id, 'diagnoseo_meta_exclude_postlist' );
	}

	if ( isset( $_POST['seo-exclude-search'] ) ) {
		update_post_meta( $post_id, 'diagnoseo_meta_exclude_search', 1 );
	} else {
		delete_post_meta( $post_id, 'diagnoseo_meta_exclude_search' );
	}

	if ( isset( $_POST['twitter-title'] ) ) {
		diagnoseo_save_meta_text( $post_id, 'diagnoseo_meta_twitter_title', sanitize_text_field( wp_unslash( $_POST['twitter-title'] ) ) );
	}

	if ( isset( $_POST['twitter-card-type'] ) ) {
		diagnoseo_save_meta_text( $post_id, 'diagnoseo_meta_twitter_card', sanitize_text_field( wp_unslash( $_POST['twitter-card-type'] ) ) );
	}

	if ( isset( $_POST['twitter-description'] ) ) {
		diagnoseo_save_meta_text( $post_id, 'diagnoseo_meta_twitter_description', sanitize_text_field( wp_unslash( $_POST['twitter-description'] ) ) );
	}

	if ( isset( $_POST['facebook-title'] ) ) {
		diagnoseo_save_meta_text( $post_id, 'diagnoseo_meta_facebook_title', sanitize_text_field( wp_unslash( $_POST['facebook-title'] ) ) );
	}

	if ( isset( $_POST['facebook-description'] ) ) {
		diagnoseo_save_meta_text( $post_id, 'diagnoseo_meta_facebook_description', sanitize_text_field( wp_unslash( $_POST['facebook-description'] ) ) );
	}

	if ( isset( $_POST['schema-type'] ) ) {
		diagnoseo_save_meta_text( $post_id, 'diagnoseo_schema_type', sanitize_text_field( wp_unslash( $_POST['schema-type'] ) ) );
	}
	if ( isset( $_POST['schema-data'] ) ) {
		diagnoseo_save_meta_text( $post_id, 'diagnoseo_schema_data', sanitize_text_field( wp_unslash( $_POST['schema-data'] ) ) );
	}

	do_action( 'diagnoseo_after_saving_post_meta' );
}

/**
 * Retrieves title template for post
 */
function diagnoseo_get_title_template() {
	global $post;

	$type   = get_post_type( $post->ID );
	$option = 'diagnoseo_' . $type . '_title_template';
	$value  = get_option( $option, '' );
	return $value;
}

/**
 * Retrieves description template for post
 */
function diagnoseo_get_description_template() {
	global $post;

	$type   = get_post_type( $post->ID );
	$option = 'diagnoseo_' . $type . '_description_template';
	$value  = get_option( $option, '' );
	return $value;
}

/**
 * Registers custom fields used in social meta tags
 */
function diagnoseo_register_social_fields() {
	register_post_meta(
		'',
		'diagnoseo_meta_facebook_title',
		array(
			'show_in_rest' => true,
			'single'       => true,
			'type'         => 'string',
		)
	);

	register_post_meta(
		'',
		'diagnoseo_meta_facebook_description',
		array(
			'show_in_rest' => true,
			'single'       => true,
			'type'         => 'string',
		)
	);

	register_post_meta(
		'',
		'diagnoseo_meta_twitter_title',
		array(
			'show_in_rest' => true,
			'single'       => true,
			'type'         => 'string',
		)
	);

	register_post_meta(
		'',
		'diagnoseo_meta_twitter_description',
		array(
			'show_in_rest' => true,
			'single'       => true,
			'type'         => 'string',
		)
	);
}

/**
 * Saves text metabox value
 *
 * @param integer $post_id ID of currently edited post.
 * @param string  $meta_key The name of a custom field to save the value to.
 * @param string  $value The new value of the custom field.
 */
function diagnoseo_save_meta_text( $post_id, $meta_key, $value ) {
	if ( '' === $value && get_post_meta( $post_id, $meta_key, true ) ) {
		delete_post_meta( $post_id, $meta_key );
	}
	if ( '' !== $value ) {
		update_post_meta( $post_id, $meta_key, sanitize_text_field( wp_unslash( $value ) ) );
	}
}
