<?php
/**
 * Post list queries
 *
 * @package DiagnoSEO
 */

if ( ! defined( 'ABSPATH' ) ) {
	die;
}

/**
 * Excludes posts from search queries
 *
 * @param WP_Query $query Current WP_Query object.
 */
function diagnoseo_exclude_from_search( $query ) {
	if ( is_admin() || ! $query->is_main_query() ) {
		return;
	}

	if ( is_search() ) {
		$query->set(
			'meta_query',
			array(
				array(
					'key'     => 'diagnoseo_meta_exclude_search',
					'compare' => 'NOT EXISTS',
					'value'   => '',
				),
			)
		);
	}
}
add_action( 'pre_get_posts', 'diagnoseo_exclude_from_search', 1 );

/**
 * Excludes posts from archive and home page queries
 *
 * @param WP_Query $query Current WP_Query object.
 */
function diagnoseo_exclude_from_postlist( $query ) {
	if ( is_admin() || ! $query->is_main_query() ) {
		return;
	}

	if ( is_archive() || is_home() ) {
		$query->set(
			'meta_query',
			array(
				array(
					'key'     => 'diagnoseo_meta_exclude_postlist',
					'compare' => 'NOT EXISTS',
					'value'   => '',
				),
			)
		);
	}
}
add_action( 'pre_get_posts', 'diagnoseo_exclude_from_postlist', 1 );
