<?php
/**
 * Site Map functions
 *
 * @package DiagnoSEO
 */

if ( ! defined( 'ABSPATH' ) ) {
	die;
}

/**
 * Excludes posts with robots=noindex from sitemap
 *
 * @param Array  $args WP_Query arguments.
 * @param String $post_type Post type - ignored.
 */
function diagnoseo_sitemap_exclusions( $args, $post_type ) {
	$options = array(
		'meta_key'   => 'diagnoseo_meta_robots_index', //phpcs:ignore
		'meta_value' => 'noindex', //phpcs:ignore
	);

	$query = new WP_Query( $options );
	if ( $query->have_posts() ) {
		while ( $query->have_posts() ) {
			$query->the_post();
			$args['post__not_in'][] = get_the_id();
		}
	}

	return $args;
}
add_filter( 'wp_sitemaps_posts_query_args', 'diagnoseo_sitemap_exclusions', 10, 2 );

/**
 * Excludes post types that were marked for no indexing from the sitemap
 *
 * @param Array $post_types Array containing post types.
 */
function diagnoseo_sitemap_remove_post_type( $post_types ) {
	$types = get_post_types( array(), 'objects' );
	foreach ( $types as $k => $type ) {
		if ( ! is_post_type_viewable( $type ) ) {
			unset( $types[ $k ] );
		}
	}
	foreach ( $types as $type ) {
		$setting_name = 'diagnoseo_dont_index_' . $type->name;
		$excluded     = get_option( $setting_name );
		if ( $excluded ) {
			unset( $post_types[ $type->name ] );
		}
	}
	return $post_types;
}
add_filter( 'wp_sitemaps_post_types', 'diagnoseo_sitemap_remove_post_type' );

/**
 * Adds a lastmod field to sitemap for posts
 *
 * @param Array  $entry Sitemap entry.
 * @param Object $post Post object.
 */
function diagnoseo_sitemap_add_lastmod( $entry, $post ) {
	$show_lastmod = get_option( 'diagnoseo_sitemap_lastmod' );
	if ( $show_lastmod ) {
		$entry['lastmod'] = get_post_modified_time( 'c', false, $post->ID );
	}
	return $entry;
}
add_filter( 'wp_sitemaps_posts_entry', 'diagnoseo_sitemap_add_lastmod', 10, 2 );
