<?php
/**
 * Various utility functions
 *
 * @package DiagnoSEO
 */

if ( ! defined( 'ABSPATH' ) ) {
	die;
}

/**
 * Limits given text to a limit but keeps words unbroken
 *
 * @param string  $text Text to truncate.
 * @param integer $limit Limit - number of characters.
 */
function diagnoseo_truncate_text( $text, $limit ) {
	$text   = wp_strip_all_tags( $text );
	$words  = explode( ' ', $text );
	$output = '';

	foreach ( $words as $word ) {
		$old_output = $output;
		$output    .= ' ' . $word;
		if ( strlen( $output ) > $limit ) {
			$output = $old_output . ' ...';
			break;
		}
	}

	return $output;
}

/**
 * Splits the canonical for the SERP
 *
 * @param String $url Canonical url.
 */
function diagnoseo_canonical_preview( $url ) {
	if ( substr( $url, -1 ) === '/' ) {
		$url = substr( $url, 0, -1 );
	}
	if ( strpos( $url, '//' ) !== false ) {
		$url = substr( $url, strpos( $url, '//' ) + 2 );
	}
	if ( strpos( $url, '/' ) !== false ) {
		$domain = substr( $url, 0, strpos( $url, '/' ) );
		$rest   = substr( $url, strpos( $url, '/' ) + 1 );
		if ( ! empty( $rest ) ) {
			$rest = str_replace( '/', ' › ', $rest );
		}
	} else {
		$domain = $url;
		$rest   = '';
	}

	if ( ! empty( $rest ) ) {
		$rest = ' › ' . $rest;
	}

	return '<span class="domain">' . esc_html( $domain ) . '</span> ' . esc_html( $rest );
}

/**
 * Checks if array contains any values
 *
 * @param Array $arr Array to search for values in.
 */
function diagnoseo_any_value_exists( $arr ) {
	foreach ( $arr as $k => $v ) {
		if ( ! empty( $v ) ) {
			return true;
		}
	}
	return false;
}
